@@ -40,22 +40,36 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IVTK_4
 #endif
 
+#if (VTK_MAJOR_VERSION==5 && VTK_MINOR_VERSION==0 && VTK_BUILD_VERSION<2)
+#define IVTK_501
+#endif
+
 #ifdef IVTK_4
 
 class vtkSource;
-typedef vtkSource vtkFilter;
+typedef vtkSource ivtkFilter;
+class vtkDataSetToPolyDataFilter;
+typedef vtkDataSetToPolyDataFilter ivtkPolyDataFilter;
+
 #define IVTK_QUAD_ORDER 0
 
 #else
 
 class vtkAlgorithm;
-typedef vtkAlgorithm vtkFilter;
+typedef vtkAlgorithm ivtkFilter;
+class vtkPolyDataAlgorithm;
+typedef vtkPolyDataAlgorithm ivtkPolyDataFilter;
+
 #define IVTK_QUAD_ORDER 3
 
 #ifdef VTK_USE_VIDEO_FOR_WINDOWS
 #define IVTK_SUPPORTS_AVI
 #endif
 
+#ifdef VTK_USE_MPEG2_ENCODER
+#define IVTK_SUPPORTS_MPEG
+#endif
+
 #endif
 
 #endif // IVTK_H
