@@ -57,7 +57,7 @@ iActor* iActor::New(bool scaled)
 }
 
 
-iActor::iActor(bool scaled) : mSubjects(iActorSubjectPointer())
+iActor::iActor(bool scaled)
 {
 	mBasicScale = mAxisScale[0] = mAxisScale[1] = mAxisScale[2] = 1.0;
 	mScaled = scaled;
