@@ -102,7 +102,6 @@ IOBJECT_DEFINE_KEY(iAnimator,LoadScriptFile,ls,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoFile,lf,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoOpacity,lo,Float,1);
 IOBJECT_DEFINE_KEY(iAnimator,LogoPosition,lp,Int,1);
-IOBJECT_DEFINE_KEY(iAnimator,Mode,m,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfBlendedFrames,nb,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfFrames,nf,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfCameraPathHandles,nph,Int,1);
@@ -110,13 +109,14 @@ IOBJECT_DEFINE_KEY(iAnimator,NumberOfCameraPathSteps,nps,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfTransitionFrames,nt,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,PositionOnPath,pop,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,RestoreCamera,rc,Bool,1);
+IOBJECT_DEFINE_KEY(iAnimator,Style,s,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,ScriptFileName,sfn,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,StopOnPath,sop,Bool,1);
-IOBJECT_DEFINE_KEY(iAnimator,SlideSpeed,ss,Float,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfTitlePageBlendedFrames,tbf,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,TitlePageFile,tf,String,1);
 IOBJECT_DEFINE_KEY(iAnimator,NumberOfTitlePageFrames,tnf,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,UseScript,us,Bool,1);
+IOBJECT_DEFINE_KEY(iAnimator,CrossSectionSpeed,xs,Float,1);
 
 IOBJECT_DEFINE_KEY(iAnimator,DebugFlag,-df,Int,1);
 IOBJECT_DEFINE_KEY(iAnimator,Debugging,-dd,Bool,1); // need a bool key for GUI shell
@@ -207,7 +207,7 @@ void iAnimator::Animate()
 {
 	this->Start();
 	while(this->Continue());
-	this->Finish();
+	this->Stop();
 }
 
 
@@ -242,7 +242,7 @@ void iAnimator::Start()
 	}
 
 	this->GetViewModule()->GetWriter()->Start();
-	mAnimatorScript->Start();
+	mAnimatorScript->StartExecute();
 
 	mStarted = true;
 	this->ClearCache();
@@ -265,17 +265,17 @@ bool iAnimator::Continue()
 
 	this->GetErrorStatus()->Monitor(mAnimatorScript->GetErrorStatus());
 	this->ClearCache();
-	return mAnimatorScript->Continue();
+	return mAnimatorScript->ExecuteOneLine();
 }
 
 
 //
-//  Finish animation
+//  Stop animation
 //
-void iAnimator::Finish()
+void iAnimator::Stop()
 {
 	int i;
-	for(i=0; i<mFollowers.Size(); i++) mFollowers[i]->Finish();
+	for(i=0; i<mFollowers.Size(); i++) mFollowers[i]->Stop();
 
 	if(!mStarted)
 	{
@@ -284,7 +284,7 @@ void iAnimator::Finish()
 	}
 
 	this->GetViewModule()->GetWriter()->Finish();
-	mAnimatorScript->Finish();
+	mAnimatorScript->StopExecute();
 
 	if(!mUseScript)
 	{
@@ -461,12 +461,13 @@ void iAnimator::CopyState(iAnimator *anim)
 }
 
 
-void iAnimator::SetMode(int ma)
+void iAnimator::SetStyle(int ma)
 { 
 	if(ma>=0 && ma<=4) 
 	{
 		mState.mode = ma; 
-		mCameraPath->SetEnabled(ma == 4); 
+		mCameraPath->SetEnabled(ma == 4);
+		this->Reset();
 		this->ClearCache();
 	}
 }
@@ -1257,7 +1258,7 @@ void iAnimator::PackStateBody(iString &s) const
 	this->PackValue(s,KeyRestoreCamera(),mRestoreCamera);
 	this->PackValue(s,KeyInheritSettings(),mInheritSettings);
 
-	this->PackValue(s,KeyMode(),mState.mode);
+	this->PackValue(s,KeyStyle(),mState.mode);
 	this->PackValue(s,KeyNumberOfFrames(),mState.nframes);
 	this->PackValue(s,KeyNumberOfBlendedFrames(),mState.nBlendedFrames);
 	this->PackValue(s,KeyNumberOfTransitionFrames(),mState.nTransitionFrames);
@@ -1266,7 +1267,7 @@ void iAnimator::PackStateBody(iString &s) const
 	this->PackValue(s,KeyTheta(),mState.dtheta);
 	this->PackValue(s,KeyRoll(),mState.droll);
 	this->PackValue(s,KeyZoom(),mState.dscale);
-	this->PackValue(s,KeySlideSpeed(),mState.slideSpeed);
+	this->PackValue(s,KeyCrossSectionSpeed(),mState.slideSpeed);
 	this->PackValue(s,KeyFlybySpeed(),mState.flybySpeed);
 
 	this->PackValue(s,KeyTitlePageFile(),mState.titlePageFile);
@@ -1281,34 +1282,20 @@ void iAnimator::PackStateBody(iString &s) const
 	this->PackValue(s,KeyNumberOfCameraPathHandles(),this->GetNumberOfCameraPathHandles());
 	this->PackValue(s,KeyNumberOfCameraPathSteps(),mNumPathSteps);
 
-	int i, n = mCameraPath->GetNumberOfHandles();
-	double x[3];
+	int n = mCameraPath->GetNumberOfHandles();
 
 	float *x1 = new float[n]; IERROR_ASSERT(x1);
 	float *x2 = new float[n]; IERROR_ASSERT(x2);
 	float *x3 = new float[n]; IERROR_ASSERT(x3);
 
-	for(i=0; i<n; i++)
-	{
-		mCameraPath->GetCameraPathHandlePosition(i,x);
-		x1[i] = x[0];
-		x2[i] = x[1];
-		x3[i] = x[2];
-	}
-
+	mCameraPath->GetCameraPathHandlePositions(x1,x2,x3);
 	this->PackValue(s,KeyCameraPathX(),x1,n);
 	this->PackValue(s,KeyCameraPathY(),x2,n);
 	this->PackValue(s,KeyCameraPathZ(),x3,n);
 
 	if(this->GetFocalPathEnabled())
 	{
-		for(i=0; i<n; i++)
-		{
-			mCameraPath->GetFocalPathHandlePosition(i,x);
-			x1[i] = x[0];
-			x2[i] = x[1];
-			x3[i] = x[2];
-		}
+		mCameraPath->GetFocalPathHandlePositions(x1,x2,x3);
 		this->PackValue(s,KeyFocalPathX(),x1,n);
 		this->PackValue(s,KeyFocalPathY(),x2,n);
 		this->PackValue(s,KeyFocalPathZ(),x3,n);
@@ -1340,7 +1327,7 @@ void iAnimator::UnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyTheta(),f)) this->SetTheta(f);
 	if(this->UnPackValue(s,KeyRoll(),f)) this->SetRoll(f);
 	if(this->UnPackValue(s,KeyZoom(),f)) this->SetZoom(f);
-	if(this->UnPackValue(s,KeySlideSpeed(),f)) this->SetSlideSpeed(f);
+	if(this->UnPackValue(s,KeyCrossSectionSpeed(),f)) this->SetCrossSectionSpeed(f);
 	if(this->UnPackValue(s,KeyFlybySpeed(),f)) this->SetFlybySpeed(f);
 
 	if(this->UnPackValue(s,KeyTitlePageFile(),ss)) this->SetTitlePageFile(ss);
@@ -1356,39 +1343,52 @@ void iAnimator::UnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyNumberOfCameraPathSteps(),i)) this->SetNumberOfCameraPathSteps(i);
 
 	int n = mCameraPath->GetNumberOfHandles();
-	double x[3];
+	float *x1 = new float[n]; IERROR_ASSERT(x1);
+	float *x2 = new float[n]; IERROR_ASSERT(x2);
+	float *x3 = new float[n]; IERROR_ASSERT(x3);
 
-	float *xc = new float[n]; IERROR_ASSERT(xc);
-	float *yc = new float[n]; IERROR_ASSERT(yc);
-	float *zc = new float[n]; IERROR_ASSERT(zc);
-
-	if(this->UnPackValue(s,KeyCameraPathX(),xc,n) && this->UnPackValue(s,KeyCameraPathY(),yc,n) && this->UnPackValue(s,KeyCameraPathZ(),zc,n))
+	mCameraPath->GetCameraPathHandlePositions(x1,x2,x3);
+	if(this->UnPackValue(s,KeyCameraPathX(),x1,n))
 	{
-		for(i=0; i<n; i++)
+		mCameraPath->SetCameraPathHandlePositions(0,x1);
+		this->ClearCache();
+	}
+	if(this->UnPackValue(s,KeyCameraPathY(),x2,n))
+	{
+		mCameraPath->SetCameraPathHandlePositions(1,x2);
+		this->ClearCache();
+	}
+	if(this->UnPackValue(s,KeyCameraPathZ(),x3,n))
+	{
+		mCameraPath->SetCameraPathHandlePositions(2,x3);
+		this->ClearCache();
+	}
+
+	if(this->GetFocalPathEnabled())
+	{
+		mCameraPath->GetFocalPathHandlePositions(x1,x2,x3);
+		if(this->UnPackValue(s,KeyCameraPathX(),x1,n))
 		{
-			x[0] = xc[i];
-			x[1] = yc[i];
-			x[2] = zc[i];
-			mCameraPath->SetCameraPathHandlePosition(i,x);
+			mCameraPath->SetFocalPathHandlePositions(0,x1);
+			this->ClearCache();
+		}
+		if(this->UnPackValue(s,KeyCameraPathY(),x2,n))
+		{
+			mCameraPath->SetFocalPathHandlePositions(1,x2);
+			this->ClearCache();
+		}
+		if(this->UnPackValue(s,KeyCameraPathZ(),x3,n))
+		{
+			mCameraPath->SetFocalPathHandlePositions(2,x3);
+			this->ClearCache();
 		}
 	}
 
-	if(this->GetFocalPathEnabled() && this->UnPackValue(s,KeyCameraPathX(),xc,n) && this->UnPackValue(s,KeyCameraPathY(),yc,n) && this->UnPackValue(s,KeyCameraPathZ(),zc,n))
-	{
-		for(i=0; i<n; i++)
-		{
-			x[0] = xc[i];
-			x[1] = yc[i];
-			x[2] = zc[i];
-			mCameraPath->SetFocalPathHandlePosition(i,x);
-		}
-	}
+	delete [] x1;
+	delete [] x2;
+	delete [] x3;
 
-	delete [] xc;
-	delete [] yc;
-	delete [] zc;
-
-	if(this->UnPackValue(s,KeyMode(),i)) this->SetMode(i);
+	if(this->UnPackValue(s,KeyStyle(),i)) this->SetStyle(i);
 	
 	//
 	//  Action keys
