@@ -93,29 +93,29 @@ public:
 	static iAnimator* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 		
-	IOBJECT_DECLARE_GETSET(Mode,mState.mode,int);
-	//virtual void SetMode(int ma);
-	//inline int GetMode() const { return mState.mode; }
+	IOBJECT_DECLARE_GETSET(Style,mState.mode,int);
+	//virtual void SetStyle(int ma);
+	//inline int GetStyle() const { return mState.mode; }
 
 	IOBJECT_DECLARE_GETSET(NumberOfFrames,mState.nframes,int);
 	//virtual void SetNumberOfFrames(int na);
 	//inline int GetNumberOfFrames() const { return mState.nframes; }
 
 	IOBJECT_DECLARE_GETSET(Phi,mState.dphi,float);
-	//virtual void SetDPhi(float va);
-	//inline float GetDPhi() const { return mState.dphi; }
+	//virtual void SetPhi(float va);
+	//inline float GetPhi() const { return mState.dphi; }
 
 	IOBJECT_DECLARE_GETSET(Theta,mState.dtheta,float);
-	//virtual void SetDTheta(float va);
-	//inline float GetDTheta() const { return mState.dtheta; }
+	//virtual void SetTheta(float va);
+	//inline float GetTheta() const { return mState.dtheta; }
 
 	IOBJECT_DECLARE_GETSET(Zoom,mState.dscale,float);
-	//virtual void SetDZoom(float va);
-	//inline float GetDZoom() const { return mState.dscale; }
+	//virtual void SetZoom(float va);
+	//inline float GetZoom() const { return mState.dscale; }
 
 	IOBJECT_DECLARE_GETSET(Roll,mState.droll,float);
-	//virtual void SetDRoll(float va);
-	//inline float GetDRoll() const { return mState.droll; }
+	//virtual void SetRoll(float va);
+	//inline float GetRoll() const { return mState.droll; }
 
 	IOBJECT_DECLARE_GETSET(FlybySpeed,mState.flybySpeed,float);
 	//virtual void SetFlybySpeed(float va);
@@ -209,9 +209,9 @@ public:
 	inline const iImage& GetLogoImage() const { return mLogoImage; }
 	static const iObjectKey& KeyLogoImage();
 
-	virtual void SetSlideSpeed(float va);
-	inline float GetSlideSpeed() const { return (float)fabs(mState.slideSpeed); }
-	static const iObjectKey& KeySlideSpeed();
+	virtual void SetCrossSectionSpeed(float va);
+	inline float GetCrossSectionSpeed() const { return (float)fabs(mState.slideSpeed); }
+	static const iObjectKey& KeyCrossSectionSpeed();
 
 	static const iObjectKey& KeyCameraPathX();
 	static const iObjectKey& KeyCameraPathY();
@@ -226,7 +226,7 @@ public:
 	//
 	void Animate();
 	virtual void Start();
-	virtual void Finish();
+	virtual void Stop();
 	virtual bool Continue();
 
 	void AddFollower(iAnimator *f);
@@ -344,7 +344,7 @@ inline void iAnimator::SetRoll(float va)
 }
 
 
-inline void iAnimator::SetSlideSpeed(float va)
+inline void iAnimator::SetCrossSectionSpeed(float va)
 {
 	mState.slideSpeed = va; 
 	this->ClearCache();
