@@ -129,7 +129,7 @@ namespace iAnimatorScript_Private
 	//
 	//  focal point & camera location
 	//
-	bool CameraSetFocalPoint(iScript *self, short at, int num, const double *value, int index = -1)
+	bool CameraSetFocalPoint(iScript *self, short at, int num, const double *value, int index)
 	{
 		VECTOR_HELPER_ASSERT(3);
 
@@ -143,7 +143,7 @@ namespace iAnimatorScript_Private
 		return true;
 	}
 
-	bool CameraSetPosition(iScript *self, short at, int num, const double *value, int index = -1)
+	bool CameraSetPosition(iScript *self, short at, int num, const double *value, int index)
 	{
 		VECTOR_HELPER_ASSERT(3);
 
@@ -157,7 +157,7 @@ namespace iAnimatorScript_Private
 		return true;
 	}
 
-	bool CameraSetViewUp(iScript *self, short at, int num, const double *value, int index = -1)
+	bool CameraSetViewUp(iScript *self, short at, int num, const double *value, int index)
 	{
 		VECTOR_HELPER_ASSERT(3);
 
