@@ -72,7 +72,7 @@ private:
 	static bool Reset(iScript *self);
 	static bool Render(iScript *self, short at, int n);
 	static bool RenderAll(iScript *self, short at, int n);
-	static bool RenderSet(iScript *self, short at, int num, const int *v, int index = -1);
+	static bool RenderSet(iScript *self, short at, int num, const int *v, int index);
 
 	static bool ExecuteControlScript(iScript *self, const iString& filename);
 	static bool EmbedControlScript(iScript *self, const iString &text);
