@@ -45,7 +45,8 @@ class iBoundedDiskSource : public iBoundedPolyDataSource
 
 public:
 	
-	static iBoundedDiskSource* New(iViewSubject *vo);
+	vtkTypeMacro(iBoundedDiskSource,iBoundedPolyDataSource);
+	static iBoundedDiskSource* New(iViewSubject *vo = 0);
 
 	void SetWithArrow(bool s);
 	inline bool GetWithArrow() const { return mWithArrow; }
@@ -60,6 +61,8 @@ protected:
 	virtual void AddObserverToSource(unsigned long e, vtkCommand *c, float priority);
 	virtual float GetSourceMemorySize() const;
 
+private:
+
 	//
 	//  VTK stuff
 	//
