@@ -173,16 +173,8 @@ void iBoundedPolyDataSource::ProduceOutput()
 
 	this->UpdateBoundaryConditions();
 
-	if(this->GetLimits()==0 || !this->GetLimits()->IsBoxPeriodic())
-	{
-		mFilter->Update();
-		output->ShallowCopy(mFilter->GetOutput());
-	}
-	else
-	{
-		mClipper->Update();
-		output->ShallowCopy(mClipper->GetOutput());
-	}
+	mClipper->Update();
+	output->ShallowCopy(mClipper->GetOutput());
 }
 
 
