@@ -32,28 +32,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define ICAMERA_H
 
 
-#include <vtkCamera.h>
 #include "iobject.h"
-#include "iviewmodulecomponent.h"
 
 
 #include "iposition.h"
 
+class iEventObserver;
 class iRenderTool;
 
+class vtkCamera;
 
-class iCamera : public vtkCamera, public iObject, public iViewModuleComponent
+
+class iCamera : public iObject
 {
 
 	friend class iExtensionFactory;
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 
-	IOBJECT_DECLARE_SELF(iCamera,iObject);
-
+	vtkTypeMacro(iCamera,iObject);
 	static const iObjectType& Type();
-
-	static iCamera* New(iRenderTool *rt);
+	static iCamera* New(iRenderTool *rt = 0);
 
 	IOBJECT_DECLARE_GETSET_POSITION(Position,mPosition); 
 	//virtual void SetPosition(const iPosition &p);
@@ -74,6 +75,8 @@ public:
 	static const iObjectKey& KeyEyeAngle();
 	static const iObjectKey& KeyClippingRange();
 	static const iObjectKey& KeyClippingRangeAuto();
+	static const iObjectKey& KeySyncProjections();
+
 	//
 	//  action keys
 	//
@@ -87,27 +90,28 @@ public:
 	static const iObjectKey& KeyReset();
 
 	void Reset();
+	void Update();
+	void OrthogonalizeView();
+	void ShiftTo(const iPosition& pos);
 
-	//
-	//  Inherited members
-	//
-	virtual void Render(vtkRenderer *ren);
-	virtual void UpdateViewport(vtkRenderer *ren);
-	virtual void Modified();
+	vtkCamera* GetDevice() const { return mDevice; }
 
 protected:
 
-	iCamera(iRenderTool *rt);
 	virtual ~iCamera();
 
-	void UpdateDevice();
-	void UpdatePositions();
-
 	virtual void PackStateBody(iString &s) const;
 	virtual void UnPackStateBody(const iString &s);
 
-	bool mNeedsSceneReset;
+private:
+
+	iCamera(iRenderTool *rt);
+
+	void SyncProjections();
+
+	bool mSyncProjections;
 	vtkCamera *mDevice;
+	iEventObserver *mObserver;
 	iRenderTool *mRenderTool;
 	iPosition mPosition, mFocalPoint;
 };
