@@ -31,10 +31,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkCaptionActor2D.h>
-#include "ioverlaybase.h"
 
 
+#include "ipointermacro.h"
+
 class iActor;
+class iOverlayHelper;
+class iRenderTool;
 
 class vtkActor2D;
 class vtkPolyData;
@@ -42,16 +45,19 @@ class vtkPolyDataMapper2D;
 class vtkTextMapper;
 
 
-class iCaption: public vtkCaptionActor2D, public iOverlayBase
+class iCaption: public vtkCaptionActor2D
 {
 	
+	IPOINTER_AS_USER(OverlayHelper);
+
 public:
 	
-	static iCaption* New(const iRenderTool *rv);
+	vtkTypeMacro(iCaption,vtkCaptionActor2D);
+	static iCaption* New(iRenderTool *rt = 0);
 	
-	virtual int RenderOverlay(vtkViewport*);
-	virtual int RenderOpaqueGeometry(vtkViewport*);
-	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
+	virtual int RenderOverlay(vtkViewport *vp);
+	virtual int RenderOpaqueGeometry(vtkViewport *vp);
+	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
 	
 	virtual void ReleaseGraphicsResources(vtkWindow *win);
 
@@ -60,10 +66,11 @@ public:
 
 protected:
 	
-	iCaption(const iRenderTool *rv);
 	virtual ~iCaption();
 	
 private:
+	
+	iCaption(iRenderTool *rv);
 
 	float mUnmagx1[2], mUnmagx2[2];
 	bool mLeader3D;
