@@ -49,16 +49,22 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iCaptionInteractorStyle* iCaptionInteractorStyle::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iCaptionInteractorStyle(vm);
 }
 
 
-iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : iViewModuleComponent(vm)
+iCaptionInteractorStyle::iCaptionInteractorStyle(iViewModule *vm) : mViewModule(vm)
 {
 	mInteractionCaption = 0;
 }
 
 
+iCaptionInteractorStyle::~iCaptionInteractorStyle()
+{
+}
+
+
 void iCaptionInteractorStyle::FindPickedActor(int x, int y)
 {
 	int i;
