@@ -76,6 +76,10 @@ public:
 	//virtual void SetSideOffset(float v);
 	//float GetSideOffset() const;
 
+	IOBJECT_DECLARE_GETSET2(Size,float);
+	//virtual void SetSize(float v);
+	//float GetSize() const;
+
 	IOBJECT_DECLARE_GETSET1(Automatic,bool);
 	//virtual void SetAutomatic(bool);
 	//inline bool GetAutomatic() const { return mAutomatic; }
