@@ -44,6 +44,10 @@ iCommandInterpreter::iCommandInterpreter(iShell *s) : mShell(s)
 {
 	mBreakFlag = mExecFlag = mWorkFlag = false;
 	mReturnState = 0;
+
+#ifdef I_DEBUG
+	mKeepVars = true;
+#endif
 }
 
 
@@ -79,7 +83,6 @@ int iCommandInterpreter::Exec()
 		//
 		line.Clear();
 		this->ReadLineOfText(line);
-		line.ReduceWhiteSpace();
 
 		this->ExecLineBody(line);
 	}
@@ -100,26 +103,29 @@ void iCommandInterpreter::ExecLine(iString &line)
 }
 
 
-void iCommandInterpreter::ExecLineBody(iString &line)
+void iCommandInterpreter::ExecLineBody(const iString &line0)
 {
 	//
 	//  Clear the error status
 	//
 	this->Script()->GetErrorStatus()->Clear();
 
+	iString line(line0);
+
 	//
 	//  Is this an exec line?
 	//
 	mExecFlag = false;
 	mWorkFlag = false;
-	if(line[line.Length()-1] == ';')
+	iString w(line);
+	w.ReduceWhiteSpace();
+	if(w.EndsWith(";"))
 	{
 		mExecFlag = true;
 		//
 		//  Remove the semi-colon
 		//
-		line = line.Part(0,line.Length()-1);
-		line.ReduceWhiteSpace();
+		line.Replace(";","");
 	}
 
 	//
@@ -135,7 +141,7 @@ void iCommandInterpreter::ExecLineBody(iString &line)
 	//
 	//  Redirection sign reads from an external file
 	//
-	if(line[0] == '<')
+	if(!line.IsEmpty() && line[0]=='<')
 	{
 		iString s = line.Part(1);
 		s.ReduceWhiteSpace();
@@ -174,7 +180,8 @@ void iCommandInterpreter::ExecLineBody(iString &line)
 	{
 		mExecFlag = false;
 		mWorkFlag = true;
-		this->Script()->Run(line,false,false); // do not reset the script!!!
+		this->Script()->SetText(line);
+		this->Script()->Execute(true); // do not reset the script!!!
 		if(!this->Script()->GetErrorStatus()->Message().IsEmpty())
 		{
 			this->DislayLineOfText("ERROR: "+this->Script()->GetErrorStatus()->Message(),_CommandInterpreterTextTypeError);
@@ -185,15 +192,19 @@ void iCommandInterpreter::ExecLineBody(iString &line)
 	//
 	// Form a script
 	//
-	if(!line.IsEmpty()) mScriptText += line + "\n";
-	if(mScriptText.IsEmpty()) mExecFlag = false;
+	mScriptText += line + "\n";
 	if(mExecFlag)
 	{
 		//
 		//  Execute the script - must mutex it since it is called from a thread
 		//
 		mWorkFlag = true;
-		this->Script()->Run(mScriptText,false,false); // do not reset the script!!!
+		this->Script()->SetText(mScriptText);
+#ifdef I_DEBUG
+		this->Script()->Execute(mKeepVars);
+#else
+		this->Script()->Execute(true); // do not reset the script!!!
+#endif
 		mLastExecutedScriptText = mScriptText;
 		mScriptText.Clear();
 		if(this->Script()->GetErrorStatus()->IsError())
@@ -229,12 +240,12 @@ bool iCommandInterpreter::IsHelpRequest(const iString &line) const
 {
 	return (line.Part(0,4)=="help" && (line.Length()==4 || line[4]==' ')) ||
 		line.Part(0,5)=="list " ||
-		line.Part(0,6)=="print " ||
+//		line.Part(0,6)=="print " ||
 		(line.Part(0,2)==".h" && (line.Length()==2 || line[2]==' ')) ||
 		line.Part(0,4)==".hp " || 
 		line.Part(0,4)==".ho " || 
+//		line.Part(0,3)==".p " ||
 		line.Part(0,4)==".lp " || 
-		(line.Part(0,3)==".lo" && (line.Length()==3 || line[3]==' ')) ||
-		line.Part(0,3)==".p ";
+		(line.Part(0,3)==".lo" && (line.Length()==3 || line[3]==' '));
 }
 
