@@ -72,7 +72,7 @@ protected:
 	iCommandInterpreter(iShell *s);
 	virtual ~iCommandInterpreter();
 
-	void ExecLineBody(iString &line);
+	void ExecLineBody(const iString &line);
 
 	virtual bool IsHelpRequest(const iString &line) const;
 
@@ -83,6 +83,10 @@ protected:
 	virtual void CheckBreak() = 0;
 	virtual void Finalize() = 0;
 
+#ifdef I_DEBUG
+	bool mKeepVars;
+#endif
+
 private:
 
 	//
