@@ -29,18 +29,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icontourfilter.h"
 
 
-#include "ivtk.h"
-
+#include <vtkContourFilter.h>
 #include <vtkFloatArray.h>
 #include <vtkPointData.h>
+#include <vtkPolyDataNormals.h>
 #include <vtkToolkits.h>
 
-#if defined(VTK_USE_PATENTED) || !defined(IVTK_4)
-#include <vtkMarchingContourFilter.h>
-#define IVTK_CONTOURFILTER		vtkMarchingContourFilter
+#if defined(IVTK_4) && !defined(VTK_USE_PATENTED)
+#define vtkMarchingContourFilter vtkContourFilter
 #else
-#include <vtkContourFilter.h>
-#define IVTK_CONTOURFILTER		vtkContourFilter
+#include <vtkMarchingContourFilter.h>
 #endif
 
 
@@ -52,30 +50,61 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iContourFilter::iContourFilter(iViewSubject *vo) : iGenericFilter<vtkDataSetToPolyDataFilter,vtkDataSet,vtkPolyData>(vo,1,true,false)
 {
+	mMethod = 0;
 	mCurVar = 0;
 
-	IVTK_CONTOURFILTER *w = IVTK_CONTOURFILTER::New(); IERROR_ASSERT(w);
-	w->UseScalarTreeOn();
-	w->ComputeNormalsOn();
-	w->ComputeScalarsOff();
-	w->ComputeGradientsOff();
-
+	vtkContourFilter *w0 = vtkContourFilter::New(); IERROR_ASSERT(w0);
+#ifndef IVTK_4
+	w0->UseScalarTreeOn();
+#endif
+	w0->ComputeNormalsOn();
+	w0->ComputeScalarsOff();
+	w0->ComputeGradientsOff();
 	if(vo->IsCreatingMainPipeline())
 	{
-		w->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetAbortRenderEventObserver());
+		w0->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetAbortRenderEventObserver());
 	}
 	else
 	{
-		w->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetSlaveAbortRenderEventObserver());
+		w0->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetSlaveAbortRenderEventObserver());
 	}
 
-	mWorker = w;
+	vtkMarchingContourFilter *w1 = vtkMarchingContourFilter::New(); IERROR_ASSERT(w1);
+#if !defined(IVTK_4) || defined(VTK_USE_PATENTED)
+	w1->UseScalarTreeOn();
+#endif
+	w1->ComputeNormalsOn();
+	w1->ComputeScalarsOff();
+	w1->ComputeGradientsOff();
+	if(vo->IsCreatingMainPipeline())
+	{
+		w1->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetAbortRenderEventObserver());
+	}
+	else
+	{
+		w1->AddObserver(vtkCommand::ProgressEvent,vo->GetViewModule()->GetSlaveAbortRenderEventObserver());
+	}
+
+	mWorkers[0] = w0;
+	mWorkers[1] = w1;
 }
 
 
 iContourFilter::~iContourFilter()
 {
-	mWorker->Delete();
+	mWorkers[0]->Delete();
+	mWorkers[1]->Delete();
+}
+
+
+void iContourFilter::SetMethod(int n)
+{ 
+	if(n>=0 && n<2 && n!=mMethod)
+	{
+		mWorkers[mMethod]->GetOutput()->Initialize();  // erase old data
+		mMethod = n;
+		this->Modified();
+	}
 }
 
 
@@ -91,13 +120,14 @@ void iContourFilter::SetCurrentVar(int n)
 
 float iContourFilter::GetLevel() const
 {
-	return iRequiredCast<IVTK_CONTOURFILTER>(mWorker)->GetValue(0);
+	return iRequiredCast<vtkContourFilter>(INFO,mWorkers[0])->GetValue(0);
 }
 
 
 void iContourFilter::SetLevel(float v)
 {
-	iRequiredCast<IVTK_CONTOURFILTER>(mWorker)->SetValue(0,v);
+	iRequiredCast<vtkContourFilter>(INFO,mWorkers[0])->SetValue(0,v);
+	iRequiredCast<vtkMarchingContourFilter>(INFO,mWorkers[1])->SetValue(0,v);
 	this->Modified();
 }
 
@@ -121,18 +151,33 @@ void iContourFilter::ProduceOutput()
 	vtkDataSet *newInput = input->NewInstance(); IERROR_ASSERT(newInput);
 	newInput->ShallowCopy(input);
 
-	vtkFloatArray *scalars = iRequiredCast<vtkFloatArray>(input->GetPointData()->GetScalars());
+	vtkFloatArray *scalars = iRequiredCast<vtkFloatArray>(INFO,input->GetPointData()->GetScalars());
 	vtkFloatArray *newScalars = vtkFloatArray::New(); IERROR_ASSERT(newScalars);
 	newScalars->SetNumberOfComponents(numComp);
 	newScalars->SetArray(scalars->GetPointer(mCurVar),scalars->GetSize(),1);
 	newInput->GetPointData()->SetScalars(newScalars);
 	newScalars->Delete();
 
-	iRequiredCast<IVTK_CONTOURFILTER>(mWorker)->SetInput(newInput);
+	mWorkers[mMethod]->SetInput(newInput);
 	newInput->Delete();
 
-	iRequiredCast<IVTK_CONTOURFILTER>(mWorker)->Update();
+	mWorkers[mMethod]->Update();
 
-	output->ShallowCopy(iRequiredCast<IVTK_CONTOURFILTER>(mWorker)->GetOutput());
+	//
+	//  Are there normals? Not all combinations of inputs/filters/VTK versions create those
+	//
+	if(mWorkers[mMethod]->GetOutput()->GetPointData()->GetNormals()==0 || mWorkers[mMethod]->GetOutput()->GetPointData()->GetNormals()->GetNumberOfTuples()==0)
+	{
+		vtkPolyDataNormals *nf = vtkPolyDataNormals::New(); IERROR_ASSERT(nf);
+		nf->ConsistencyOn();
+		nf->ComputePointNormalsOn(); 
+		nf->ComputeCellNormalsOff();
+		nf->SetInput(mWorkers[mMethod]->GetOutput());
+		nf->Update();
+		mWorkers[mMethod]->GetOutput()->GetPointData()->SetNormals(nf->GetOutput()->GetPointData()->GetNormals());
+		nf->Delete();
+	}
+
+	output->ShallowCopy(mWorkers[mMethod]->GetOutput());
 }
 
