@@ -34,13 +34,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkDataSetToPolyDataFilter.h>
 
 
+#include "ivtk.h"
+
+
 class iContourFilter : public iGenericFilter<vtkDataSetToPolyDataFilter,vtkDataSet,vtkPolyData>
 {
 	
-	IGENERICFILTER_DECLARE(iContourFilter);
+	IGENERICFILTER_DECLARE(iContourFilter,vtkDataSetToPolyDataFilter);
 
 public:
 
+	inline int GetMethod() const { return mCurVar; }
+	void SetMethod(int n);
+
 	inline int GetCurrentVar() const { return mCurVar; }
 	void SetCurrentVar(int n);
 	
@@ -53,8 +59,10 @@ protected:
 
 	virtual void ProduceOutput();
 
-	int mCurVar;
-	vtkObject *mWorker;
+private:
+
+	int mCurVar, mMethod;
+	ivtkPolyDataFilter *mWorkers[2];
 };
 
 #endif // ICONTOURFILTER_H
