@@ -190,6 +190,14 @@ namespace iControlModule_Private
 		F.Close();
 		return false;
 	}
+
+	bool OnQueryFailed()
+	{
+#ifdef I_DEBUG
+		int ooo = 0;
+#endif
+		return false;
+	}
 };
 
 
@@ -988,7 +996,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iFunctionMapping* &f, int
 { 
 	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	iViewModule *module = mViewModules->GetMember(mod);
-	if(module == 0) return 0;
+	if(module == 0) return OnQueryFailed();
 
 	if(key.Type().IsMatch(iParticleGroup::Type()))
 	{
@@ -1021,7 +1029,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iFunctionMapping* &f, int
 	}
 
 	f = 0;
-	return false;
+	return OnQueryFailed();
 }
 
 
@@ -1032,7 +1040,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iRangeMapping* &f, int mo
 { 
 	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	iViewModule *module = mViewModules->GetMember(mod);
-	if(module == 0) return 0;
+	if(module == 0) return OnQueryFailed();
 
 	if(key.Type().IsMatch(iParticlesViewSubject::Type()))
 	{
@@ -1044,7 +1052,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iRangeMapping* &f, int mo
 	}
 
 	f = 0;
-	return false;
+	return OnQueryFailed();
 }
 
 
@@ -1055,7 +1063,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iImage &im, int mod, int
 { 
 	if(mod == -1) mod = mViewModules->GetCurrentMemberIndex();
 	iViewModule *module = mViewModules->GetMember(mod);
-	if(module == 0) return 0;
+	if(module == 0) return OnQueryFailed();
 
 	if(key.Type().IsMatch(iAnimator::Type()))
 	{
@@ -1071,7 +1079,7 @@ bool iControlModule::QueryValue(const iObjectKey &key, iImage &im, int mod, int
 		}
 	}
 
-	return false;
+	return OnQueryFailed();
 }
 
 
@@ -1098,9 +1106,9 @@ bool iControlModule::QueryValueAsString(const iObjectKey &key, iString &val, int
 			}
 			return true;
 		}
-		else return false;
+		else return OnQueryFailed();
 	}
-	else return false;
+	else return OnQueryFailed();
 }
 
 
@@ -1118,13 +1126,13 @@ bool iControlModule::QueryValueAsString(const iObjectKey &key, iString &val, int
 			iObject::ReportMissingKeys(false); \
 			bool ret = o->UnPackValue(ws,key,val,n); \
 			iObject::ReportMissingKeys(true); \
-			return ret; \
+			return (ret?true:OnQueryFailed()); \
 		} \
-		else return false; \
+		else return OnQueryFailed(); \
 	} \
 	bool iControlModule::QueryValue(const iObjectKey &key, int index, _type_ &val, int n, int mod, int obj) \
 	{ \
-		if(index<0 || index>=n) return false; \
+		if(index<0 || index>=n) return OnQueryFailed(); \
 		iObject *o = this->FindObject(key,mod,obj); \
 		if(o != 0) \
 		{ \
@@ -1136,9 +1144,9 @@ bool iControlModule::QueryValueAsString(const iObjectKey &key, iString &val, int
 			iObject::ReportMissingKeys(true); \
 			val = tmp[index]; \
 			delete [] tmp; \
-			return ret; \
+			return (ret?true:OnQueryFailed()); \
 		} \
-		else return false; \
+		else return OnQueryFailed(); \
 	} 
 
 
@@ -1655,6 +1663,8 @@ bool iControlModule::UnPackValuePalette(const iString &s, iPalette *p)
 		ok = tmpObject->UnPackValuePiecewiseFunction(ws,keyRed,r) && 
 		 	tmpObject->UnPackValuePiecewiseFunction(ws,keyGreen,g) &&
 			tmpObject->UnPackValuePiecewiseFunction(ws,keyBlue,b);
+
+		if(ok) p->Update();
 	}
 
 	iObjectKeyRegistry::ReleaseTempKey(keyRed);
