@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ioverlayhelper.h"
 
 #include <vtkAxisActor2D.h>
 #include <vtkProperty2D.h>
@@ -38,30 +39,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkViewport.h>
 
 	
-iCubeAxesActor* iCubeAxesActor::New(const iRenderTool *rv)
+iCubeAxesActor* iCubeAxesActor::New(iRenderTool *rt)
 {
-	return new iCubeAxesActor(rv);
+	IERROR_ASSERT(rt);
+	return new iCubeAxesActor(rt);
 }
 
 
-iCubeAxesActor::iCubeAxesActor(const iRenderTool *rv) : iOverlayBase(rv)
+iCubeAxesActor::iCubeAxesActor(iRenderTool *rt) : mOverlayHelper(rt)
 {
-	FontFactor = 1.2;
-
-	this->AxisLabelTextProperty->BoldOn();
-	this->AxisLabelTextProperty->ItalicOff();
-	this->AxisLabelTextProperty->ShadowOn();
-	this->AxisLabelTextProperty->SetFontFamilyToArial();
-	this->AxisTitleTextProperty->BoldOn();
-	this->AxisTitleTextProperty->ItalicOff();
-	this->AxisTitleTextProperty->ShadowOn();
-	this->AxisTitleTextProperty->SetFontFamilyToArial();
-	this->XAxis->SetLabelTextProperty(AxisLabelTextProperty);
-	this->YAxis->SetLabelTextProperty(AxisLabelTextProperty);
-	this->ZAxis->SetLabelTextProperty(AxisLabelTextProperty);
-	this->XAxis->SetTitleTextProperty(AxisTitleTextProperty);
-	this->YAxis->SetTitleTextProperty(AxisTitleTextProperty);
-	this->ZAxis->SetTitleTextProperty(AxisTitleTextProperty);
+	this->XAxis->SetLabelTextProperty(this->AxisLabelTextProperty);
+	this->YAxis->SetLabelTextProperty(this->AxisLabelTextProperty);
+	this->ZAxis->SetLabelTextProperty(this->AxisLabelTextProperty);
+	this->XAxis->SetTitleTextProperty(this->AxisTitleTextProperty);
+	this->YAxis->SetTitleTextProperty(this->AxisTitleTextProperty);
+	this->ZAxis->SetTitleTextProperty(this->AxisTitleTextProperty);
 
 	this->SetFlyModeToOuterEdges();
 	this->SetLabelFormat("%6.2g");
@@ -74,6 +66,11 @@ iCubeAxesActor::iCubeAxesActor(const iRenderTool *rv) : iOverlayBase(rv)
 }
 
 
+iCubeAxesActor::~iCubeAxesActor()
+{
+}
+
+
 int iCubeAxesActor::RenderOverlay(vtkViewport *viewport)
 {
 	return vtkCubeAxesActor2D::RenderOverlay(viewport);
@@ -91,23 +88,25 @@ int iCubeAxesActor::RenderOpaqueGeometry(vtkViewport *viewport)
 	}
 
 	int renderedSomething = 0;
-	int mag = this->GetRenderingMagnification();
-	this->XAxis->SetFontFactor(FontFactor*this->GetFontSize(viewport,mag));
-	this->YAxis->SetFontFactor(FontFactor*this->GetFontSize(viewport,mag));
-	this->ZAxis->SetFontFactor(FontFactor*this->GetFontSize(viewport,mag));
+	int mag = mOverlayHelper->GetRenderingMagnification();
+	//
+	//  Scale fonts
+	//
+	this->AxisLabelTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag));
+	this->AxisTitleTextProperty->SetFontSize(mOverlayHelper->GetFontSize(viewport,mag));
+	this->FontFactor = mOverlayHelper->GetFontSize(viewport,mag)/10.0;
+
+	mOverlayHelper->UpdateTextProperty(this->AxisLabelTextProperty);
+	mOverlayHelper->UpdateTextProperty(this->AxisTitleTextProperty);
+
 	if(mag == 1)
 	{
 		//
 		//  Set colors (needed for VTK 5)
 		//
-		this->AxisLabelTextProperty->SetColor(this->GetProperty()->GetColor());
-		this->AxisTitleTextProperty->SetColor(this->GetProperty()->GetColor());
+		this->AxisLabelTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
+		this->AxisTitleTextProperty->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 
-		//
-		//  Scale fonts
-		//
-		this->AxisLabelTextProperty->SetFontSize(this->GetFontSize(viewport));
-		this->AxisTitleTextProperty->SetFontSize(this->GetFontSize(viewport));
 		//
 		//  Render and save axes positions
 		//
@@ -127,7 +126,7 @@ int iCubeAxesActor::RenderOpaqueGeometry(vtkViewport *viewport)
 		//  compute shifts
 		//
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
 		//
 		//  shift positions: positions are in viewport coordinates, so need to scale
 		//  winij appropriately
