@@ -31,24 +31,36 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkCubeAxesActor2D.h>
-#include "ioverlaybase.h"
 
 
+#include "ipointermacro.h"
+
+class iOverlayHelper;
+class iRenderTool;
+
 class vtkViewport;
 
 
-class iCubeAxesActor: public vtkCubeAxesActor2D, public iOverlayBase
+class iCubeAxesActor: public vtkCubeAxesActor2D
 {
 
+	IPOINTER_AS_USER(OverlayHelper);
+
 public:
 
-	static iCubeAxesActor* New(const iRenderTool *rv);
+	vtkTypeMacro(iCubeAxesActor,vtkCubeAxesActor2D);
+	static iCubeAxesActor* New(iRenderTool *rt = 0);
+
 	virtual int RenderOpaqueGeometry(vtkViewport *viewport);
 	virtual int RenderOverlay(vtkViewport *viewport);
 
+protected:
+
+	virtual ~iCubeAxesActor();
+
 private:
 
-	iCubeAxesActor(const iRenderTool *rv);
+	iCubeAxesActor(iRenderTool *rv);
 
 	double mPos1X[3], mPos1Y[3], mPos1Z[3];
 	double mPos2X[3], mPos2Y[3], mPos2Z[3];
