@@ -33,17 +33,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IDATACONSUMER_H
 
 
-#include "iviewmodulecomponent.h"
-
-
 #include "iarray.h"
 #include "iparameter.h"
 #include "istring.h"
 
+#include "ipointermacro.h"
+
 class iDataHandler;
 class iDataInfo;
 class iDataType;
-class iView;
+class iViewModule;
 
 class vtkDataSet;
 
@@ -73,12 +72,14 @@ private:
 };
 
 
-class iDataConsumer : public iViewModuleComponent
+class iDataConsumer
 {
 
 	friend class iDataHandler;
 	friend class iViewModule;
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 
 	static void SetGlobalOptimizationMode(int mode);
@@ -92,7 +93,7 @@ public:
 	inline bool IsOptimizedForQuality() const { return this->GetOptimizationMode() == iParameter::_DataConsumerOptimizeForQuality; }
 
 	virtual const iDataType& GetDataType() const;
-	virtual bool IsDataPresent() const;
+	virtual bool IsThereData() const;
 	bool IsUsingData(const iDataInfo &info, bool onlyprimary) const;
 
 	void AddSecondaryDataType(const iDataType &type);
@@ -119,6 +120,9 @@ protected:
 	virtual void SyncWithDataBody(const iDataSyncRequest &r) = 0;
 
 	iDataInfo *mPrimaryDataInfo, *mSecondaryDataInfo;
+
+private:
+
 	iDataSyncRequest mRequest;
 
 	iPointerArray<iDataHandler> mDataHandlers;
