@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
+#include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatasubject.h"
@@ -58,17 +59,19 @@ IOBJECT_DEFINE_TYPE(iDataExplorer,DataExplorer,-de,iObjectType::_Helper);  // he
 
 iDataExplorer* iDataExplorer::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iDataExplorer(vm);
 }
 
 
-iDataExplorer::iDataExplorer(iViewModule *vm) : iMultiTypeDataConsumer(vm,iData::Any())
+iDataExplorer::iDataExplorer(iViewModule *vm) : iMultiTypeDataConsumer(vm,iDataInfo::Any())
 {
 	mHistogramMaker = 0;
 	mMTime = 0;
 	mComputeRangeOnly = false;
 	
 	mComponent = 0;
+	mStretch = 0;
 }
 
 
@@ -109,17 +112,21 @@ const iDataExplorer::Info& iDataExplorer::GetInfo(bool rangeonly)
 	{
 		mHistogramMaker = this->GetViewModule()->GetReader()->GetSubject(this->GetDataType())->CreateHistogramMaker();
 		IERROR_ASSERT(mHistogramMaker);
-		mHistogramMaker->SetDataRank(this->GetDataType().GetRank());
-		mHistogramMaker->SetInput(this->GetData(),mComponent);
+		mHistogramMaker->SetFullResolution(true);
 	}
 
-	mHistogramMaker->SetInputComponent(mComponent);
-	mHistogramMaker->SetStretch(mStretch);
-	mHistogramMaker->GetInput()->Update();
-	if(mHistogramMaker->GetInput()->GetMTime() > mMTime)
+	if(this->IsThereData())
 	{
-		mComputeRangeOnly = rangeonly;
-		this->Execute();
+		iDataHelper h(this->GetData());
+		mHistogramMaker->SetDataRank(h.GetDataRank());
+		mHistogramMaker->SetInput(this->GetData(),mComponent);
+		mHistogramMaker->SetStretch(mStretch);
+		mHistogramMaker->GetInput()->Update();
+		if(mHistogramMaker->GetInput()->GetMTime() > mMTime)
+		{
+			mComputeRangeOnly = rangeonly;
+			this->Execute();
+		}
 	}
 	return mInfo;
 }
@@ -127,8 +134,11 @@ const iDataExplorer::Info& iDataExplorer::GetInfo(bool rangeonly)
 
 void iDataExplorer::SetStretch(int v)
 {
-	mStretch = v;
-	mMTime = 0;
+	if(mStretch != v)
+	{
+		mStretch = v;
+		mMTime = 0;
+	}
 }
 
 
@@ -137,6 +147,7 @@ void iDataExplorer::SetInputComponent(int c)
 	if(c>=0 && c<this->GetNumberOfInputComponents() && c!=mComponent)
 	{
 		mComponent = c;
+		mMTime = 0;
 	}
 }
 
@@ -186,53 +197,53 @@ void iDataExplorer::Execute()
 
 	mMTime = mHistogramMaker->GetInput()->GetMTime();
 
-	float max = h->GetMaxValue();
-	float min = h->GetMinValue();
-
-	//
-	//  make sure Min is less than Max
-	//
-	float s = iMath::_FloatTolerance;
-	while(max<min+s && s<iMath::_LargeFloat) 
-	{
-		max += s; 
-		s *= 2;
-	}
-
-	double sum0 = 0.0, sum1 = 0.0, sum2 = 0.0;
-	
-	for(j=0; j<h->N(); j++)
-	{
-		sum0 += h->Y(j);
-		sum1 += h->Y(j)*h->X(j);
-		sum2 += h->Y(j)*h->X(j)*h->X(j);
-	}
-
+	float max = mHistogramMaker->ApplyStretch(h->GetMaxValue(),true);
+	float min = mHistogramMaker->ApplyStretch(h->GetMinValue(),false);
 	float avg, dis, med;
-	if(sum0 > 0.0)
+
+	if(max > min) 
 	{
-		avg = min + sum1/sum0*(max-min);
-		dis = sqrt(sum2/sum0-pow(sum1/sum0,2.0))*(max-min);
-		med = 0.0;
-		sum1 = 0.0;
+		double sum0 = 0.0, sum1 = 0.0, sum2 = 0.0;
+
 		for(j=0; j<h->N(); j++)
 		{
-			if(sum1<0.5*sum0 && (sum1+=h->Y(j))>=0.5*sum0)
+			sum0 += h->Y(j);
+			sum1 += h->Y(j)*h->X(j);
+			sum2 += h->Y(j)*h->X(j)*h->X(j);
+		}
+
+		if(sum0 > 0.0)
+		{
+			avg = min + sum1/sum0*(max-min);
+			dis = sqrt(sum2/sum0-pow(sum1/sum0,2.0))*(max-min);
+			med = 0.0;
+			sum1 = 0.0;
+			for(j=0; j<h->N(); j++)
 			{
-				med = min + h->X(j)*(max-min);
-				break;
+				if(sum1<0.5*sum0 && (sum1+=h->Y(j))>=0.5*sum0)
+				{
+					med = min + h->X(j)*(max-min);
+					break;
+				}
 			}
 		}
+		else
+		{
+			avg = dis = med = 0.5*(max+min);
+		}
 	}
 	else
 	{
-		avg = dis = med = 0.5*(max+min);
+		avg = med = min = max = 0.5*(max+min);
+		dis = 0.0;
 	}
 
 	mInfo.Histogram = h;
-	mInfo.Maximum = max;
-	mInfo.Minimum = min;
-	mInfo.Median = med;
-	mInfo.Average = avg;
-	mInfo.Dispersion = dis;
+	mInfo.Maximum = h->GetMaxValue();
+	mInfo.Minimum = h->GetMinValue();
+	mInfo.Median = mHistogramMaker->ResetStretch(med);
+	mInfo.Average = mHistogramMaker->ResetStretch(avg);
+	mInfo.Dispersion = mHistogramMaker->ResetStretch(dis);
+
+	this->Modified();
 }
