@@ -116,6 +116,7 @@ protected:
 		float LowerLimit, UpperLimit;
 		int Stretch, Class;
 		iString Name, Unit, ClassName;
+		bool IsAtMin, IsAtMax;
 	};
 
 	virtual void NotifyDependencies(int var);
@@ -135,6 +136,8 @@ protected:
 
 private:
 
+	void SetMinMax(int n, float vMin, float vMax);
+
 	//
 	//  For internal testing
 	//
