@@ -31,15 +31,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iextendableobject.h"
-#include "iviewmodulecomponent.h"
-#include "ierrorstatusholder.h"
-#include "ideletable.h"
 
 
 #include "iarray.h"
 
-
-class iBasicParticlesDataSubject;
+class iBasicParticlesFileLoader;
 class iDataInfo;
 class iDataLimits;
 class iDataReaderHelper;
@@ -47,33 +43,34 @@ class iDataSubject;
 class iDataType;
 class iDirectory;
 class iFile;
+class iFileLoader;
 class iProgressEventObserver;
-class iUniformScalarsDataSubject;
-class iUniformVectorsDataSubject;
-class iUniformTensorsDataSubject;
+class iUniformScalarsFileLoader;
+class iUniformVectorsFileLoader;
+class iUniformTensorsFileLoader;
 
 class vtkDataSet;
 class vtkPolyData;
 class vtkStructuredPoints;
 
 
-class iDataReader : public iExtendableObject, public iErrorStatusHolder, public iViewModuleComponent, public iDeletable
+class iDataReader : public iExtendableObject
 {
 
 	friend class iDataReaderHelper;
-	friend class iExtensionFactory;
+
+	IPOINTER_AS_PART(ViewModule);
 
 public:
 
-	IOBJECT_DECLARE_SELF(iDataReader,iExtendableObject);
-
 	struct VisitedFile
 	{
 		iString Name;
-		const iDataSubject *Subject;
+		const iFileLoader *Loader;
 	};
 
-	static iDataReader* New(iViewModule *vm);
+	vtkTypeMacro(iDataReader,iExtendableObject);
+	static iDataReader* New(iViewModule *vm = 0);
 	static const iObjectType& Type();
 	
 	//
@@ -83,30 +80,6 @@ public:
 	//virtual void SetScaledDimension(int v);
 	//inline int GetScaledDimension() const { return mScaledDim; }
 
-	IOBJECT_DECLARE_GETSET1(CellToPointMode,int);
-	//virtual void SetCellToPointMode(int m);
-	//inline int GetCellToPointMode() const { return mCellToPointMode; }
-
-	IOBJECT_DECLARE_GETSET2(ParticlesOrderInFileIsAttribute,bool);
-	//virtual void SetParticlesOrderInFileIsAttribute(bool s);
-	//bool GetParticlesOrderInFileIsAttribute() const;
-
-	IOBJECT_DECLARE_GETSET2(ScalarFieldCalculatorFunction,const iString&);
-	//virtual void SetScalarFieldCalculatorFunction(const iString &s);
-	//const iString& GetScalarFieldCalculatorFunction() const;
-
-	IOBJECT_DECLARE_GETSET2(ScalarFieldCalculatorOutputVariable,int);
-	//virtual void SetScalarFieldCalculatorOutputVariable(int n);
-	//int GetScalarFieldCalculatorOutputVariable() const;
-
-	IOBJECT_DECLARE_GETSET2(ParticlesDownsampleMode,int);
-	//virtual void SetParticlesDownsampleMode(int v);
-	//int GetParticlesDownsampleMode() const;
-
-	IOBJECT_DECLARE_GETSET2(ParticlesDownsampleFactor,int);
-	//virtual void SetParticlesDownsampleFactor(int v);
-	//int GetParticlesDownsampleFactor() const;
-
 	IOBJECT_DECLARE_GETSET1(VoxelLocation,int);
 	//virtual void SetVoxelLocation(int s);
 	//inline bool GetVoxelLocation() const { return mVoxelLocation; }
@@ -130,7 +103,7 @@ public:
 	//
 	static const iObjectKey& KeyErrorMessage();
 
-	inline bool IsSet() const { return mSetSubjects.Size() > 0; }
+	inline bool IsSet() const { return mSetLoaders.Size() > 0; }
 	static const iObjectKey& KeyIsSet();
 
 	//
@@ -146,24 +119,19 @@ public:
 	bool IsThereData(const iDataInfo &info) const;
 
 	void EraseData(const iDataType &type);
-	void DetachData(const iDataType &type);
 	void ReloadData(const iDataType &type);
 
+	void SetTwoCopies(bool s);
+
 	void ResetPipeline();
 
 	iDataSubject* GetSubject(const iDataType &type) const;
 	iDataLimits* GetLimits(const iDataType &type) const;
 
 	//
-	//  Access to included DataType(s)
+	//  Generic GetData
 	//
-	inline int GetNumberOfDataTypes() const { return mSubjects.Size(); }
-	const iDataType& GetDataType(int i) const;
-
-	//
-	//  Generic GetOutput
-	//
-	vtkDataSet* GetOutput(const iDataType &type) const;
+	vtkDataSet* GetData(const iDataType &type) const;
 
 	inline bool IsFileAnimatable() const { return (mCurrentRecord >= 0); }
 	inline int GetRecordNumber() const { return mCurrentRecord; }
@@ -185,30 +153,36 @@ public:
 	inline const iString& GetLastFileName() const { return mLastFileName; }
 	inline const iString& GetLastAttemptedFileName() const { return mLastAttemptedFileName; }
 
-	inline const VisitedFile* GetVisitedFilesList() const { return &(mVisitedFilesList[0]); }
-	inline int GetNumberOfVisitedFiles() const { return mVisitedFilesList.Size(); }
+	inline const iArray<VisitedFile>& GetVisitedFilesList() const { return mVisitedFilesList; }
 
 	virtual iProgressEventObserver* GetProgressEventObserver(const iDataType &type);
 
 	virtual void PackCompleteState(iString &s) const;
 	virtual void UnPackCompleteState(const iString &s);
 
-	void LoadFileByStringKey(const iDataType &type, int envkey, iString ws[2]);
+	//
+	//  Hidden (undocumented) keys
+	//
+	static const iObjectKey& KeyRecordLength(); 
+	inline int GetRecordLength() const { return mRecordLength; }
 
 protected:
-	
-	iDataReader(iViewModule *vm);
+
 	virtual ~iDataReader();
 
 	virtual void ExtendableObjectPackStateBody(iString &s) const;
 	virtual void ExtendableObjectUnPackStateBody(const iString &s);
 
-	void InsertIntoVisitedFilesList(const iDataSubject *subject, const iString &file);
+private:
+	
+	iDataReader(iViewModule *vm);
+
+	void LoadFile(iFileLoader *loader, const iString &fname, bool dryrun, bool savename);
+
+	void InsertIntoVisitedFilesList(const iFileLoader *loader, const iString &name);
 	void BreakSet();
 	bool IsAborted(const iDataType &type) const;
-	bool IsSetLeader(const iDataSubject *subject) const;
-
-	void InsertStringIntoVisitedFilesList(const iDataSubject *subject, const iString &string);
+	bool IsSetLeader(const iFileLoader *loader) const;
 
 	bool mTwoCopies, mInExtensionUpdate;
 	int mCellToPointMode;
@@ -217,15 +191,15 @@ protected:
 	iString mMode;
 	int mScaledDim, mVoxelLocation, mBoundaryConditions;
 
-	iDataSubject *mPeriodicityLeader;
-	iSearchableArray<iDataSubject*> mSetSubjects;
-	iArray<iDataSubject*> mSubjects;
-	iUniformScalarsDataSubject *mUniformScalarsSubject;
-	iUniformVectorsDataSubject *mUniformVectorsSubject;
-	iUniformTensorsDataSubject *mUniformTensorsSubject;
-	iBasicParticlesDataSubject *mBasicParticlesSubject;
+	iFileLoader *mPeriodicityLeader;
+	iSearchableArray<iFileLoader*> mSetLoaders;
+	iArray<iFileLoader*> mLoaders;
+	iUniformScalarsFileLoader *mUniformScalarsLoader;
+	iUniformVectorsFileLoader *mUniformVectorsLoader;
+	iUniformTensorsFileLoader *mUniformTensorsLoader;
+	iBasicParticlesFileLoader *mBasicParticlesLoader;
 
-	int mCurrentRecord;
+	int mCurrentRecord, mRecordLength;
 
 	iString mLastFileName, mLastAttemptedFileName;
 	iArray<VisitedFile> mVisitedFilesList;
@@ -240,16 +214,22 @@ class iDataReaderExtension : public iObjectExtension
 
 public:
 
-	iDataSubject* AddNewSubject();
+	inline iDataReader* GetReader() const { return mRealOwner; }
 
-	virtual void AfterLoadFile(const iDataType &type, const iString &fname, bool dryrun = false) = 0;
-	virtual bool IsUsingData(const iDataType &type) const = 0;
+	virtual iFileLoader* GetLoader(int n) const = 0;
+
+	//
+	//  It is a good idea to keep track of the last file read.
+	//
+	inline const iString& GetLastFileName() const { return mLastFileName; }
+
+	void AfterLoadFile(iFileLoader *loader, const iString &fname, bool dryrun);
 
 protected:
 
-	virtual iDataSubject* CreateSubject(int n) const = 0;
+	virtual void AfterLoadFileBody(iFileLoader *loader, const iString &fname, bool dryrun);
 
-	int mNextSubjectToCreate;
+	iString mLastFileName;
 };
 
 #endif
