@@ -40,29 +40,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iarraytemplate.h"
 
 
-iDirectory::iDirectory() : mFiles(iString())
+iDirectory::iDirectory()
 {
 }
 
 
-bool iDirectory::Open(const iString &name)
+bool iDirectory::Open(const iString &fname)
 {
 	vtkDirectory *d = vtkDirectory::New(); IERROR_ASSERT(d);
 
-	if(d->Open(name.ToCharPointer()) == 0)
+	if(d->Open(fname.ToCharPointer()) == 0)
 	{
 		//
 		//  Is the file name attached?
 		//
-		if(d->Open(name.Section("/",0,-2).ToCharPointer()) == 0) return false; else
+		if(d->Open(fname.Section("/",0,-2).ToCharPointer()) == 0) return false; else
 		{
-			mDirectory = name.Section("/",0,-2) + "/";
+			mDirectory = fname.Section("/",0,-2) + "/";
 		}
 	}
 	else
 	{
-		mDirectory = name;
-		if(name[-1] != '/') mDirectory += "/";
+		mDirectory = fname;
+		if(fname[-1] != '/') mDirectory += "/";
 	}
 
 	mFiles.Clear();
@@ -93,19 +93,18 @@ const iString iDirectory::GetFile(int i, bool prefixed) const
 }
 
 
-const iString iDirectory::GetFile(const iString & file, int skip) const
+const iString iDirectory::GetFile(const iString &name, int skip) const
 {
-	iString fname;
 	bool prefixed;
 
-	if(file.Contains(mDirectory))
+	iString fname(name);
+	if(fname.Contains(mDirectory))
 	{
-		fname = file.Part(mDirectory.Length());	
+		fname = fname.Part(mDirectory.Length());	
 		prefixed = true; 
 	}
 	else
 	{
-		fname = file;
 		prefixed = false;
 	}
 
@@ -124,3 +123,38 @@ bool iDirectory::Make(const iString &name)
 #endif
 }
 
+
+const iString& iDirectory::Separator()
+{
+	static const iString sep("/");
+	return sep;
+}
+
+
+const iString& iDirectory::Current()
+{
+	static const iString cur("./");
+	return cur;
+}
+
+
+void iDirectory::ExpandFileName(iString& fname, const iString &path)
+{
+#ifdef _WIN32
+	//
+	//  Make sure we are Windows compatible
+	//
+	fname.Replace("\\",iDirectory::Separator());
+#endif
+
+	//
+	//  Apply standard expansion of the plus sign
+	//
+	if(!path.IsEmpty() && fname[0]=='+') fname.Replace(0,1,path);
+
+	//
+	//  Is this an unprefixed file name?
+	//
+	if(fname.Contains(iDirectory::Separator()) == 0) fname = iDirectory::Current() + fname;
+}
+
