@@ -29,8 +29,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "igenericfilter.h"
 
 
+#include "icommoneventobservers.h"
 #include "ierror.h"
-#include "ieventobserver.h"
 #include "iviewmodule.h"
 #include "iviewsubject.h"
 
@@ -60,7 +60,13 @@ iGenericSource<Source,OutputType>::iGenericSource(iViewSubject *vo, bool usesLim
 
 
 template<class Source, class OutputType>
-void iGenericSource<Source,OutputType>::ExecuteData(vtkDataObject *)
+iGenericSource<Source,OutputType>::~iGenericSource()
+{
+}
+
+
+template<class Source, class OutputType>
+void iGenericSource<Source,OutputType>::ExecuteData(vtkDataObject * )
 {
 	OutputType *output = this->GetOutput();
 	IERROR_ASSERT(output);
@@ -131,7 +137,7 @@ void iGenericSource<Source,OutputType>::ExecuteParent()
 		}
 	default:
 		{
-			IERROR_REPORT("Invalid ExecuteMethod.");
+			IERROR_LOW("Invalid ExecuteMethod.");
 		}
 	}
 }
@@ -202,7 +208,13 @@ iGenericFilter<Filter,InputType,OutputType>::iGenericFilter(iViewSubject *vo, in
 
 
 template<class Filter, class InputType, class OutputType>
-void iGenericFilter<Filter,InputType,OutputType>::ExecuteData(vtkDataObject *)
+iGenericFilter<Filter,InputType,OutputType>::~iGenericFilter()
+{
+}
+
+
+template<class Filter, class InputType, class OutputType>
+void iGenericFilter<Filter,InputType,OutputType>::ExecuteData(vtkDataObject * )
 {
 	InputType *input = InputType::SafeDownCast(this->GetInput());
 	OutputType *output = this->GetOutput();
@@ -215,8 +227,8 @@ void iGenericFilter<Filter,InputType,OutputType>::ExecuteData(vtkDataObject *)
 	}
 
 	mExecuteMethod = 0;
-#ifdef I_DEVEL
-	iConsole::Instance()->OutputDebugMessage((iString("Executing filter ")+Filter::GetClassName()+" by method 0.").ToCharPointer());
+#ifdef I_DEBUG
+	iConsole::PrintDebugMessage(iString("Executing filter ")+Filter::GetClassName()+" by method 0.");
 #endif
 	this->ProduceOutput();
 
@@ -341,8 +353,8 @@ int iGenericFilter<Filter,InputType,OutputType>::RequestData(vtkInformation* req
 	}
 
 	mExecuteMethod = 1;
-#ifdef I_DEVEL
-	iConsole::Instance()->OutputDebugMessage((iString("Executing filter ")+Filter::GetClassName()+" by method 1.").ToCharPointer());
+#ifdef I_DEBUG
+	iConsole::PrintDebugMessage(iString("Executing filter ")+Filter::GetClassName()+" by method 1.");
 #endif
 	this->SaveRequest(request,inInfo,outInfo);
 	this->ProduceOutput();
@@ -372,7 +384,7 @@ void iGenericFilter<Filter,InputType,OutputType>::ExecuteParent()
 		}
 	default:
 		{
-			IERROR_REPORT("Invalid ExecuteMethod.");
+			IERROR_LOW("Invalid ExecuteMethod.");
 		}
 	}
 }
