@@ -29,6 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ihistogrammaker.h"
 
 
+#include "icommoneventobservers.h"
 #include "idatalimits.h"
 #include "ierror.h"
 #include "ihistogram.h"
@@ -49,23 +50,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //------------------------------------------------------------------------------
 iHistogramMaker* iHistogramMaker::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iHistogramMaker(vm);
 }
 
 
 // Construct object to extract all of the input data.
-iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParallelManager()), iViewModuleComponent(vm)
+iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParallelManager()), mViewModule(vm), mLowResBins(256), mLowResSize(mLowResBins*mLowResBins)
 {
 	mHisto = iHistogram::New(this->GetViewModule(),this); IERROR_ASSERT(mHisto);
 
 	mNumProcs = mNumBins = 0;
 
 	mDataRank = 0U;
+	mFullResolution = mSupportsFullResolution = false;
 
 	mRanges = 0;
 	mValues = 0;
 	mComponent = -1;
-	mStretch = 0;
 
 	mAttached = true;
 
@@ -74,6 +76,10 @@ iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParal
 #else
 	this->SetNumberOfInputConnections(0,1);
 #endif
+
+	this->AddObserver(vtkCommand::StartEvent,vm->GetProgressEventObserver());
+	this->AddObserver(vtkCommand::ProgressEvent,vm->GetProgressEventObserver());
+	this->AddObserver(vtkCommand::EndEvent,vm->GetProgressEventObserver());
 }
 
 
@@ -103,15 +109,18 @@ void iHistogramMaker::AttachHistogram(bool s)
 
 void iHistogramMaker::SetInput(vtkDataSet *input, int c)
 {
-	mComponent = c;
 	this->SetNthInput(0,input);
+	this->SetInputComponent(c);
 }
 
 
 void iHistogramMaker::SetInputComponent(int c)
 {
-	mComponent = c;
-	this->Modified();
+	if(c != mComponent)
+	{
+		mComponent = c;
+		this->Modified();
+	}
 }
 
 
@@ -123,7 +132,7 @@ void iHistogramMaker::OnStretchChanged()
 
 vtkDataSet* iHistogramMaker::GetInput()
 {
-	return vtkDataSet::SafeDownCast(this->Inputs[0]);
+	if(this->Inputs == 0) return 0; else return vtkDataSet::SafeDownCast(this->Inputs[0]);
 }
 
 
@@ -137,9 +146,43 @@ void iHistogramMaker::SetDataRank(unsigned int r)
 }
 
 
+void iHistogramMaker::SetFullResolution(bool s)
+{
+	if(mFullResolution != s)
+	{
+		mFullResolution = s;
+		this->Modified();
+	}
+}
+
+
 int iHistogramMaker::GetEstimatedNumberOfBins()
 { 
-	if(this->GetInput() == 0) return 0; else return round(1.0+sqrt((float)this->GetNumberOfCells())); 
+	if(this->GetInput() == 0)
+	{
+		mSupportsFullResolution = false;
+		return 0;
+	}
+	else
+	{
+		int nb = round(1.0+sqrt((float)this->GetNumberOfCells()));
+		if(nb > mLowResBins)
+		{
+			mSupportsFullResolution = true;
+			if(!mFullResolution) nb = mLowResBins;
+		}
+		else mSupportsFullResolution = false;
+		return nb;
+	}
+}
+
+
+void iHistogramMaker::Update()
+{
+	//
+	//  Force to recompute if needed
+	//
+	this->GetHistogram();
 }
 
 
@@ -254,11 +297,10 @@ const iHistogram* iHistogramMaker::GetHistogram(int nBins)
 const iHistogram* iHistogramMaker::GetHistogram(int nBins, float vMin, float vMax)
 {
 	int i, j;
-	float v;
 
 	if(!this->IsDataPresent()) return 0;
 
-	if(nBins<-1 || nBins>1000000 || vMin>=vMax || this->GetInput()==0) return 0;
+	if(nBins<-1 || nBins>1000000 || vMin>vMax || this->GetInput()==0) return 0;
 
 	//
 	//  No need to recompute
@@ -295,7 +337,7 @@ const iHistogram* iHistogramMaker::GetHistogram(int nBins, float vMin, float vMa
 		{
 			return 0;
 		}
-		memset(mValues,0,mNumProcs*sizeof(float*));
+		memset(mValues,0,mNumProcs*sizeof(float *));
 		for(i=0; i<mNumProcs; i++)
 		{
 			mValues[i] = new float[nBins]; 
@@ -306,21 +348,16 @@ const iHistogram* iHistogramMaker::GetHistogram(int nBins, float vMin, float vMa
 	mNumBins = nBins;
 	mHisto->mValMin = vMin;
 	mHisto->mValMax = vMax;
-	mHisto->mStretch = mStretch;
+	mHisto->mStretch = this->GetStretch();
 
 	if(!this->PrepareForPass()) return 0;
 	this->ParallelExecute(2);
 
-	mHisto->Reset();
-	mHisto->MovePoint(0,0.0,0.0);
-	mHisto->MovePoint(1,1.0,0.0);
-	
 	for(i=0; i<mNumBins; i++) 
 	{
-		v = 0.0f;
-		for(j=0; j<mNumProcs; j++) v += mValues[j][i];
-		mHisto->AddPoint((i+0.5)/mNumBins,v);
+		for(j=1; j<mNumProcs; j++) mValues[0][i] += mValues[j][i];
 	}
+	mHisto->SetData(mNumBins,mValues[0]);
 
 	return mHisto;
 }
@@ -330,19 +367,27 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 {
 	if(p.NumProcs != mNumProcs) 
 	{
-		IERROR_REPORT("Error calling iHistogramMaker in parallel.");
+		IERROR_LOW("Error calling iHistogramMaker in parallel.");
 		return -1;
 	}
 
 	vtkIdType ntup = this->GetNumberOfCells();
 
-	vtkIdType l, lbeg, lend, lstp;
+	vtkIdType l, lbeg, lend, lstp, linc = 1;
 	float v, vmin, vmax;
+	int ret = 999;
 
 	//
 	//  Distribute data
 	//
 	iParallel::SplitRange(p,ntup,lbeg,lend,lstp);
+	if(!mFullResolution) linc = (lend-lbeg+mLowResSize-1)/mLowResSize;
+
+	if(mFullResolution && this->IsMaster(p))
+	{
+		this->GetViewModule()->GetProgressEventObserver()->SetMode(iProgressEventObserver::_Computing);
+		this->InvokeEvent(vtkCommand::StartEvent);
+	}
 
 	//	
 	//  Recompute the limits
@@ -351,11 +396,26 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 	{
 		vtkIdType lmin, lmax;
 		
-		vmin = vmax = this->GetValue(lbeg);
-		lmin = lmax = lbeg;
-		for(l=lbeg+1; l<lend; l++) if(this->IsValidIndex(l))
+		for(l=lbeg; l<lend; l+=linc) if(this->IsValidIndex(l))
 		{
-			if(this->IsMaster(p) && this->GetAbortExecute()) break;
+			vmin = vmax = this->GetValue(l);
+			lmin = lmax = l;
+			break;
+		}
+
+		l += linc;
+
+		for(; l<lend; l+=linc) if(this->IsValidIndex(l))
+		{
+			if(l%1000 == 0)
+			{
+				if(mFullResolution && this->IsMaster(p))
+				{
+					double p = double(l-lbeg)/(lend-lbeg);
+					this->InvokeEvent(vtkCommand::ProgressEvent,&p);
+				}
+				if(this->GetAbortExecute()) break;
+			}
 
 			v = this->GetValue(l);
 			if(v < vmin)
@@ -374,7 +434,7 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 		mRanges[p.ThisProc].CellMin = lmin;
 		mRanges[p.ThisProc].CellMax = lmax;
 		
-		return 0;
+		ret = 0;
 	}
 
 	//	
@@ -392,9 +452,17 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 		float *d = mValues[p.ThisProc];
 		memset(d,0,sizeof(float)*mNumBins);
 
-		for(l=lbeg; l<lend; l++) if(this->IsValidIndex(l))
+		for(l=lbeg; l<lend; l+=linc) if(this->IsValidIndex(l))
 		{
-			if(this->IsMaster(p) && this->GetAbortExecute()) break;
+			if(l%1000 == 0)
+			{
+				if(mFullResolution && this->IsMaster(p))
+				{
+					double p = double(l-lbeg)/(lend-lbeg);
+					this->InvokeEvent(vtkCommand::ProgressEvent,&p);
+				}
+				if(this->GetAbortExecute()) break;
+			}
 			
 			v = this->ApplyStretch(this->GetValue(l),false);
 
@@ -405,10 +473,12 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 			} 
 		}
 
-		return 0;
+		ret = 0;
 	}
 
-	return 999;
+	if(mFullResolution && this->IsMaster(p)) this->InvokeEvent(vtkCommand::EndEvent);
+
+	return ret;
 }
 
 
