@@ -65,7 +65,7 @@ IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowPositionX,fgx,Int,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowPositionY,fgy,Int,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoomSource,fgz,Int,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoom4Line,fgz4,Bool,0);
-IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoomHeight,fgzh,Float,0);
+IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoomFactor,fgzf,Float,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoomX,fgzx,Float,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ForegroundWindowZoomY,fgzy,Float,0);
 IOBJECT_DEFINE_KEY(iImageComposer,ImageHeight,h,Int,1);
@@ -279,8 +279,11 @@ void iImageComposer::UpdateSize()
 	}
 	if(mTileWidth==0 || mTileHeight==0) 
 	{
-		mTileWidth = this->GetControlModule()->GetViewModule()->GetThisImageWidth(); 
-		mTileHeight = this->GetControlModule()->GetViewModule()->GetThisImageHeight();
+		for(i=0; i<this->GetControlModule()->GetNumberOfViewModules(); i++)
+		{
+			if(mTileWidth < this->GetControlModule()->GetViewModule(i)->GetThisImageWidth()) mTileWidth = this->GetControlModule()->GetViewModule(i)->GetThisImageWidth(); 
+			if(mTileHeight < this->GetControlModule()->GetViewModule(i)->GetThisImageHeight()) mTileHeight = this->GetControlModule()->GetViewModule(i)->GetThisImageHeight();
+		}
 	}
 
 	mFullWidth = mNumTilesX*mTileWidth + 2*mBorderWidth;
@@ -420,8 +423,8 @@ void iImageComposer::PackStateBody(iString &s) const
 	for(i=0; i<mForegroundWindows.Size(); i++) ftmp[i] = mForegroundWindows[i]->GetZoomY();
 	this->PackValue(s,KeyForegroundWindowZoomY(),ftmp,n);
 
-	for(i=0; i<mForegroundWindows.Size(); i++) ftmp[i] = mForegroundWindows[i]->GetZoomHeight();
-	this->PackValue(s,KeyForegroundWindowZoomHeight(),ftmp,n);
+	for(i=0; i<mForegroundWindows.Size(); i++) ftmp[i] = mForegroundWindows[i]->GetZoomFactor();
+	this->PackValue(s,KeyForegroundWindowZoomFactor(),ftmp,n);
 
 	delete [] btmp;
 	delete [] ftmp;
@@ -483,18 +486,6 @@ void iImageComposer::UnPackStateBody(const iString &s)
 		this->UnPackingHelper(mForegroundWindows.Size(),1,(iImageComposerWindow**)mForegroundWindows.Data(),itmp,KeyForegroundWindowViewModule2(),s);
 		this->UnPackingHelper(mForegroundWindows.Size(),2,(iImageComposerWindow**)mForegroundWindows.Data(),itmp,KeyForegroundWindowViewModule3(),s);
 
-		for(i=0; i<mForegroundWindows.Size(); i++) itmp[i] = mForegroundWindows[i]->GetPositionX();
-		if(this->UnPackValue(s,KeyForegroundWindowPositionX(),itmp,mForegroundWindows.Size()))
-		{
-			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetPositionX(itmp[i]);
-		}
-		
-		for(i=0; i<mForegroundWindows.Size(); i++) itmp[i] = mForegroundWindows[i]->GetPositionY();
-		if(this->UnPackValue(s,KeyForegroundWindowPositionY(),itmp,mForegroundWindows.Size()))
-		{
-			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetPositionY(itmp[i]);
-		}
-
 		for(i=0; i<mForegroundWindows.Size(); i++) itmp[i] = mForegroundWindows[i]->GetBorderWidth();
 		if(this->UnPackValue(s,KeyForegroundWindowBorderWidth(),itmp,mForegroundWindows.Size()))
 		{
@@ -515,6 +506,18 @@ void iImageComposer::UnPackStateBody(const iString &s)
 			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetScale(ftmp[i]);
 		}
 
+		for(i=0; i<mForegroundWindows.Size(); i++) itmp[i] = mForegroundWindows[i]->GetPositionX();
+		if(this->UnPackValue(s,KeyForegroundWindowPositionX(),itmp,mForegroundWindows.Size()))
+		{
+			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetPositionX(itmp[i]);
+		}
+		
+		for(i=0; i<mForegroundWindows.Size(); i++) itmp[i] = mForegroundWindows[i]->GetPositionY();
+		if(this->UnPackValue(s,KeyForegroundWindowPositionY(),itmp,mForegroundWindows.Size()))
+		{
+			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetPositionY(itmp[i]);
+		}
+
 		//
 		//  As an optimization, load positions first, then the source, and then the height - loading the height
 		//  will adjust the position, but only once.
@@ -567,10 +570,10 @@ void iImageComposer::UnPackStateBody(const iString &s)
 			}
 		}
 
-		for(i=0; i<mForegroundWindows.Size(); i++) ftmp[i] = mForegroundWindows[i]->GetZoomHeight();
-		if(this->UnPackValue(s,KeyForegroundWindowZoomHeight(),ftmp,mForegroundWindows.Size()))
+		for(i=0; i<mForegroundWindows.Size(); i++) ftmp[i] = mForegroundWindows[i]->GetZoomFactor();
+		if(this->UnPackValue(s,KeyForegroundWindowZoomFactor(),ftmp,mForegroundWindows.Size()))
 		{
-			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetZoomHeight(ftmp[i]);
+			for(i=0; i<mForegroundWindows.Size(); i++) mForegroundWindows[i]->SetZoomFactor(ftmp[i]);
 		}
 
 		delete [] ftmp;
