@@ -41,6 +41,11 @@ iInteractorEventRecorder::iInteractorEventRecorder()
 }
 
 
+iInteractorEventRecorder::~iInteractorEventRecorder()
+{
+}
+
+
 void iInteractorEventRecorder::SetFileName(const char *s)
 {
 	if(this->InputStream != 0)
@@ -148,12 +153,12 @@ void iInteractorEventRecorder::Play()
 		while(!mStopped && !this->OutputStream->eof())
 		{
 			this->OutputStream->width(256);
-			*((fstream *)this->OutputStream) >> event;
+			*static_cast<fstream *>(this->OutputStream) >> event;
 			
 			// Quick skip comment
 			if (*event == '#')
 			{
-				((fstream *)this->OutputStream)->getline(buffer, 512);
+				static_cast<fstream *>(this->OutputStream)->getline(buffer, 512);
 				
 				// Parse the StreamVersion (not using >> since comment could be empty)
 				// Expecting: # StreamVersion x.y
@@ -172,7 +177,7 @@ void iInteractorEventRecorder::Play()
 				unsigned long ievent = vtkCommand::GetEventIdFromString(event);
 				if (ievent == vtkCommand::NoEvent)
 				{
-					((fstream *)this->OutputStream)->ignore(512, '\n');
+					static_cast<fstream *>(this->OutputStream)->ignore(512, '\n');
 				}
 				else
 				{
@@ -180,13 +185,13 @@ void iInteractorEventRecorder::Play()
 					{
 						// We could grab the time info here
 					}
-					*((fstream *)this->OutputStream) >> pos[0];
-					*((fstream *)this->OutputStream) >> pos[1];
-					*((fstream *)this->OutputStream) >> ctrlKey;
-					*((fstream *)this->OutputStream) >> shiftKey;
-					*((fstream *)this->OutputStream) >> keyCode;
-					*((fstream *)this->OutputStream) >> repeatCount;
-					*((fstream *)this->OutputStream) >> keySym;
+					*static_cast<fstream *>(this->OutputStream) >> pos[0];
+					*static_cast<fstream *>(this->OutputStream) >> pos[1];
+					*static_cast<fstream *>(this->OutputStream) >> ctrlKey;
+					*static_cast<fstream *>(this->OutputStream) >> shiftKey;
+					*static_cast<fstream *>(this->OutputStream) >> keyCode;
+					*static_cast<fstream *>(this->OutputStream) >> repeatCount;
+					*static_cast<fstream *>(this->OutputStream) >> keySym;
 					
 					this->Interactor->SetEventPosition(pos);
 					this->Interactor->SetControlKey(ctrlKey);
@@ -234,8 +239,8 @@ void iInteractorEventRecorder::Rewind()
 	if(this->OutputStream != 0) //need to already have an open file
 	{
 		this->OutputStream->clear();
-		((fstream *)this->OutputStream)->seekp(0);
-		((fstream *)this->OutputStream)->seekg(0);
+		static_cast<fstream *>(this->OutputStream)->seekp(0);
+		static_cast<fstream *>(this->OutputStream)->seekg(0);
 	}
 }
 
