@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "ioverlayhelper.h"
 
 #include <vtkCamera.h>
 #include <vtkMath.h>
@@ -39,13 +40,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkTextProperty.h>
 
 
-iLegend* iLegend::New(const iRenderTool *rv)
+iLegend* iLegend::New(iRenderTool *rv)
 {
+	IERROR_ASSERT(rv);
 	return new iLegend(rv);
 }
 
 
-iLegend::iLegend(const iRenderTool *rv) : iOverlayBase(rv)
+iLegend::iLegend(iRenderTool *rv) : mOverlayHelper(rv)
 {
 	this->BorderOn(); 
 	this->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
@@ -56,10 +58,6 @@ iLegend::iLegend(const iRenderTool *rv) : iOverlayBase(rv)
 	this->LockBorderOn();
 	this->GetProperty()->SetColor(0.0,0.0,0.0);
 	this->GetProperty()->SetLineWidth(2.0);
-	this->GetEntryTextProperty()->SetFontFamilyToArial();
-	this->GetEntryTextProperty()->BoldOn();
-	this->GetEntryTextProperty()->ItalicOff();
-	this->GetEntryTextProperty()->ShadowOn();
 	this->GetEntryTextProperty()->SetJustificationToLeft(); 
 	this->GetEntryTextProperty()->SetVerticalJustificationToCentered();
 	this->GetEntryTextProperty()->SetColor(0.0,0.0,0.0);
@@ -95,10 +93,12 @@ int iLegend::RenderOpaqueGeometry(vtkViewport* viewport)
 	//
 	double *x1 = this->GetPosition();
 	double *x2 = this->GetPosition2();
-	int mag = this->GetRenderingMagnification();
+	int mag = mOverlayHelper->GetRenderingMagnification();
 	int *size = viewport->GetSize();
 
-	float s = (this->GetFontSize(viewport)*NumberOfEntries+(NumberOfEntries+1)*Padding)/fabs(size[1]*x2[1]);
+	float s = (mOverlayHelper->GetFontSize(viewport)*NumberOfEntries+(NumberOfEntries+1)*Padding)/fabs(size[1]*x2[1]);
+
+	mOverlayHelper->UpdateTextProperty(this->GetEntryTextProperty());
 
 	if(mag == 1)
 	{
@@ -120,7 +120,7 @@ int iLegend::RenderOpaqueGeometry(vtkViewport* viewport)
 	else
 	{
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(winij);
+		mOverlayHelper->ComputePositionShiftsUnderMagnification(winij);
 		
 		this->SetPosition(mag*mUnmagx1[0]-winij[0],mag*mUnmagx1[1]-winij[1]);
 		this->Padding *= mag;
@@ -146,6 +146,7 @@ int iLegend::RenderOpaqueGeometry(vtkViewport* viewport)
         }
 	}
 
+	this->GetProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 	ret = this->vtkLegendBoxActor::RenderOpaqueGeometry(viewport);
 	
 	//
@@ -153,7 +154,7 @@ int iLegend::RenderOpaqueGeometry(vtkViewport* viewport)
 	//
     for(i=0; i<this->NumberOfEntries; i++)
 	{
-		this->TextMapper[i]->GetTextProperty()->SetColor(EntryTextProperty->GetColor());
+		this->TextMapper[i]->GetTextProperty()->SetColor(this->GetOverlayHelper()->GetColor(viewport).ToVTK());
 	    this->TextActor[i]->RenderOpaqueGeometry(viewport);
     }
 	
