@@ -31,29 +31,38 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkLegendBoxActor.h>
-#include "ioverlaybase.h"
 
 
-class iLegend: public vtkLegendBoxActor, public iOverlayBase
+#include "ipointermacro.h"
+
+class iOverlayHelper;
+class iRenderTool;
+
+
+class iLegend: public vtkLegendBoxActor
 {
 	
+	IPOINTER_AS_USER(OverlayHelper);
+
 public:
 	
-	static iLegend* New(const iRenderTool *rv);
+	vtkTypeMacro(iLegend,vtkLegendBoxActor);
+	static iLegend* New(iRenderTool *rv = 0);
 	
-	virtual int RenderOverlay(vtkViewport*);
-	virtual int RenderOpaqueGeometry(vtkViewport*);
-	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
+	virtual int RenderOverlay(vtkViewport *vp);
+	virtual int RenderOpaqueGeometry(vtkViewport *vp);
+	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
 	
 	virtual void ReleaseGraphicsResources(vtkWindow *win);
 
 protected:
-	
-	iLegend(const iRenderTool *rv);
-	virtual ~iLegend();
-	
-private:
 
+	virtual ~iLegend();
+
+private:
+	
+	iLegend(iRenderTool *rv);
+	
 	float mUnmagx1[2], mUnmagx2[2];
 };
 
