@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iLineToBandFilter : public iGenericPolyDataToPolyDataFilter<vtkRuledSurfaceFilter>
 {
 	
-	IGENERICFILTER_DECLARE(iLineToBandFilter);
+	IGENERICFILTER_DECLARE(iLineToBandFilter,vtkRuledSurfaceFilter);
 	
 protected:
 
