@@ -52,6 +52,11 @@ iLookupTable::iLookupTable()
 }
 
 
+iLookupTable::~iLookupTable()
+{
+}
+
+
 void iLookupTable::SetPalette(const iPalette *p)
 {
 	if(p != mPalette)
@@ -89,10 +94,12 @@ void iLookupTable::SetColor(const iColor &c)
 
 void iLookupTable::OnStretchChanged()
 {
-	switch(mStretch)
+	switch(this->GetStretch())
 	{
 	case iParameter::_StretchLog:
 		{
+			if(this->TableRange[0] < 1*iMath::_DoubleRes) this->TableRange[0] = 1*iMath::_DoubleRes;
+			if(this->TableRange[1] < 2*iMath::_DoubleRes) this->TableRange[1] = 2*iMath::_DoubleRes;
 			this->SetScaleToLog10();
 			break;
 		}
@@ -104,7 +111,7 @@ void iLookupTable::OnStretchChanged()
 	default:
 		{
 			this->SetScaleToLinear();
-			IERROR_REPORT("This stretch is not implemented.");
+			IERROR_LOW("This stretch is not implemented.");
 		}
 	}
 	this->Modified();
@@ -125,3 +132,19 @@ void iLookupTable::ForceBuild()
 	}
 }
 
+
+void iLookupTable::MapScalarsThroughTable2(void *input, unsigned char *output, int inputDataType, int numberOfValues, int inputIncrement, int outputFormat)
+{
+	//
+    // This is how this function is used.
+	//
+	//this->MapScalarsThroughTable2(scalars->GetVoidPointer(comp), 
+    //                              newColors->GetPointer(0),
+    //                              scalars->GetDataType(),
+    //                              scalars->GetNumberOfTuples(),
+    //                              scalars->GetNumberOfComponents(), 
+    //                              VTK_RGBA);
+
+	this->vtkLookupTable::MapScalarsThroughTable2(input,output,inputDataType,numberOfValues,inputIncrement,outputFormat);
+}
+
