@@ -51,8 +51,14 @@ public:
 	
 	virtual void ForceBuild();
 
+	virtual void MapScalarsThroughTable2(void *input, unsigned char *output, int inputDataType, int numberOfValues, int inputIncrement, int outputFormat);
+
 protected:
 
+	virtual ~iLookupTable();
+
+private:
+
 	iLookupTable();
 
 	virtual void OnStretchChanged();
