@@ -51,11 +51,12 @@ using namespace iParameter;
 
 iMeasuringBox* iMeasuringBox::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iMeasuringBox(vm);
 }
 
 
-iMeasuringBox::iMeasuringBox(iViewModule *vm) : iActor(false), iViewModuleComponent(vm)
+iMeasuringBox::iMeasuringBox(iViewModule *vm) : iActor(false), mViewModule(vm)
 {
 	mStarted = false;
 	mSize = 0.25;
@@ -103,7 +104,6 @@ iMeasuringBox::~iMeasuringBox()
 
 void iMeasuringBox::SetColor(iColor &c)
 {
-	mText->SetColor(c); 
 	this->GetProperty()->SetColor(mFactor1r+mFactor2*c.ToVTK()[0],mFactor1g+mFactor2*c.ToVTK()[1],mFactor1b+mFactor2*c.ToVTK()[2]);
 	mFrame->GetProperty()->SetColor(c.ToVTK());
 }
