@@ -34,7 +34,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "itransform.h"
 
 #include <vtkCamera.h>
-#include <vtkCommand.h>
 #include <vtkMath.h>
 #include <vtkMatrix4x4.h>
 #include <vtkRenderer.h>
@@ -47,6 +46,17 @@ iMeasuringBoxInteractorStyle* iMeasuringBoxInteractorStyle::New()
 }
 
 
+iMeasuringBoxInteractorStyle::iMeasuringBoxInteractorStyle()
+{
+	mBox = 0;
+}
+
+
+iMeasuringBoxInteractorStyle::~iMeasuringBoxInteractorStyle()
+{
+}
+
+
 void iMeasuringBoxInteractorStyle::FindPickedActor(int x, int y)
 { 
 	this->InteractionProp = mBox; x = y = 0; 
