@@ -33,14 +33,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IOBJECT_H
 
 
+#include <vtkObjectBase.h>
+
+
 #include "icolor.h"
+#include "ipointermacro.h"
 #include "iposition.h"
 #include "istring.h"
 
+#include <vtkSetGet.h>
 
 template<class T> class iArray;
 
-
+class iErrorStatus;
 class iObjectKeyHelp;
 class iObjectKeyPointer;
 class iObjectTypeHelp;
@@ -59,9 +64,10 @@ public:
 
 	enum ClassId
 	{
-		_Helper,
-		_Visual,
+		_Data,
+		_View,
 		_Module,
+		_Helper,
 		_Any
 	};
 
@@ -81,7 +87,7 @@ public:
 
 private:
 
-	iObjectType(){}
+	iObjectType();
 	iObjectType(ClassId c, const char *fullname, const char *shortname);
 	~iObjectType();
 
@@ -149,7 +155,9 @@ public:
 
 	bool IsArgumentCompatible(Arg a) const;
 	bool IndexHelper(Arg a, int n, int index, int &imin, int &imax) const;
- 
+ 	
+	int FindInString(const iString &str, int &index) const;
+
 	inline bool IsIndexed() const { return (mDim > 1); }
 
 	inline const iObjectKeyHelp* GetHelp() const { return mHelp; }
@@ -167,6 +175,7 @@ public:
     bool operator<(const iObjectKey &s) const;
 
 	bool IsHidden() const;
+	inline bool IsInherited() const { return (mParent != 0); }
 
 private:
 
@@ -181,6 +190,8 @@ private:
 	//
 	void Define(const iObjectType *type, const char *fk, const char *sk, Arg a, int d, const iObjectType* parent = 0);
 
+	int FindFullMatch(const iString &str, const iString &pat) const;
+
 	Arg mArg;
 	int mDim;
 	const iObjectType *mType, *mParent;
@@ -208,7 +219,7 @@ public:
 
 	static const iObjectKey* FindKey(const iString &str, bool hidden = false);
 
-	static void InitTraversal(const iObjectType *type = 0);
+	static void InitTraversal(const iObjectType *type = 0, bool inherited = true);
 	static const iObjectKey* GetNextKey(bool hidden = false);
 
 private:
@@ -221,28 +232,24 @@ private:
 	static iArray<iObjectKey*>& TempKeys();
 
 	static int mTraversalLocation;
+	static bool mTraversalWithInherited;
 	static const iObjectType *mTraversalType;
 };
 
-#define IOBJECT_DECLARE_SELF(_self_,_parent_) \
-	static _self_* SafeDownCast(iObject *self) { if(self!=0 && self->IsOfType(#_self_)) return (_self_*)self; else; return 0; } \
-	static _self_* RequiredCast(iObject *self) { if(self==0 || !self->IsOfType(#_self_)) iObject::ReportBadCast(#_self_,__FILE__,__LINE__); return (_self_*)self; } \
-	virtual bool IsOfType(const iString &name) const { static const iString thisName(#_self_); if(name == thisName) return true; else return this->_parent_::IsOfType(name); } \
-	virtual const iString& GetThisClassName() const { static const iString thisName(#_self_); return thisName; }
-
 #define IOBJECT_DECLARE_PACKUNPACK(_type1_,_type2_) \
 	void PackValue(iString &s, const iObjectKey &key, const _type1_* val, int num, int index = -1, bool prefixed = false) const; \
 	inline void PackValue(iString &s, const iObjectKey &key, _type2_ val, int index = -1, bool prefixed = false) const { if(index >= 0) PackValue(s,key,&val-index,1,index,prefixed); else PackValue(s,key,&val,1,index,prefixed); } \
 	bool UnPackValue(const iString &s, const iObjectKey &key, _type1_* val, int num); \
 	inline bool UnPackValue(const iString &s, const iObjectKey &key, _type1_ &val){ return !key.IsIndexed() && UnPackValue(s,key,&val,1); }  
 
-class iObject
+class iObject : public vtkObjectBase
 {
 	
+	IPOINTER_AS_USER(ErrorStatus);
+
 public:
 
-	virtual const iString& GetThisClassName() const = 0;
-	virtual bool IsOfType(const iString &name) const;
+	vtkTypeMacro(iObject,vtkObjectBase);
 
 	virtual void PackCompleteState(iString &s) const;
 	virtual void UnPackCompleteState(const iString &s);
@@ -276,8 +283,6 @@ public:
 	void PackValueDistance(iString &s, const iObjectKey &key, const iDistance &val, int index = -1, bool prefixed = false) const;
 	bool UnPackValueDistance(const iString &s, const iObjectKey &key, iDistance &val); 
 
-	int FindUnPackKey(const iString &str, const iObjectKey &key, int &index) const;
-
 	inline bool UnPackedSomething() const { return mUnPackedSomething; }
 	inline void ClearUnPackedSomethingFlag() { mUnPackedSomething = false; }
 
@@ -287,24 +292,21 @@ public:
 
 protected:
 	
-	iObject();
+	iObject(const iString &name);
 	virtual ~iObject(); 
 
 	virtual void PackStateBody(iString &s) const = 0;
 	virtual void UnPackStateBody(const iString &s) = 0;
 
-	int FindFullMatch(const iString &str, const iString &pat) const;
-
-	static const iString mSlash;
 	bool mUnPackedSomething;
 	mutable bool mCacheInvalid;
 	mutable iString mCache;
 
-	static void ReportBadCast(const char *self, const char *file, int line);
-	static void ReportAMissingKey(const iObjectKey &key);
-
 private:
 
+	static void ReportAMissingKey(const iObjectKey &key);
+
+	static const iString mSlash;
 	static int mMissingKeysStack;
 };
 
@@ -330,8 +332,8 @@ private:
 		return *__p##_object_##_fkey_##_arg_; \
 	}
 
-#define IOBJECT_DEFINE_EXTRINSIC_KEY(_owner_,_object_,_fkey_,_skey_,_arg_,_dim_) \
-	static const iObjectKey *__p##_object_##_fkey_##_arg_ = iObjectKeyRegistry::CreateKey(_owner_::Type(),#_fkey_,#_skey_,iObjectKey::_##_arg_,_dim_); \
+#define IOBJECT_DEFINE_EXTRINSIC_KEY(_owner_,_object_,_prefix_,_fkey_,_skey_,_arg_,_dim_) \
+	static const iObjectKey *__p##_object_##_fkey_##_arg_ = iObjectKeyRegistry::CreateKey(_owner_::Type(),#_prefix_"-"#_fkey_,#_skey_,iObjectKey::_##_arg_,_dim_); \
 	const iObjectKey& _object_::Key##_fkey_() \
 	{ \
 		return *__p##_object_##_fkey_##_arg_; \
@@ -413,6 +415,14 @@ private:
 		if(opengl) return *ogl; else return *__p##_object_##_fkey_##Double; \
 	}
 
+#define IOBJECT_DEFINE_INHERITED_POSITION_KEY(_parent_,_object_,_fkey_,_skey_) \
+	static const iObjectKey *__p##_object_##_fkey_##Double = iObjectKeyRegistry::CreateKey(_object_::Type(),#_fkey_,#_skey_,iObjectKey::_Double,3,&_parent_::Type()); \
+	const iObjectKey& _object_::Key##_fkey_(bool opengl) \
+	{ \
+		static const iObjectKey *ogl = iObjectKeyRegistry::CreateKey(_object_::Type(),#_fkey_"GL","-"#_skey_,iObjectKey::_Double,3,0,__p##_object_##_fkey_##Double); \
+		if(opengl) return *ogl; else return *__p##_object_##_fkey_##Double; \
+	}
+
 #define IOBJECT_DECLARE_GETSET_POSITION(_fun_,_var_) \
 	virtual void Set##_fun_(const iPosition&); \
     inline const iPosition& Get##_fun_() const { return _var_; } \
@@ -423,5 +433,7 @@ private:
     inline const iDistance& Get##_fun_() const { return _var_; } \
 	static const iObjectKey& Key##_fun_(bool opengl = false)
 
+#define IOBJECT_BACKWARD_COMPATIBLE
+
 #endif // IOBJECT_H
 
