@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iOrthoSlicer : public iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>
 {
 
-	IGENERICFILTER_DECLARE(iOrthoSlicer);
+	IGENERICFILTER_DECLARE(iOrthoSlicer,vtkStructuredPointsToStructuredPointsFilter);
 
 public: 
 
@@ -64,6 +64,8 @@ protected:
 
 	virtual void ProduceOutput();
 
+private:
+
 	int mCurVar;
 	double mPos[3];
     int mDir, mSampleRate;
