@@ -77,33 +77,32 @@ namespace iParameter
 	const int _ObjectTypeVectorField		= 4;
 	const int _ObjectTypeVolume				= 5;
 	
-	const int _ObjectModeMask		= 0x00F;
-	const int _ObjectModeInvalid	= 0x0;
-	const int _ObjectModeCurrent	= 0x1;
-	const int _ObjectModeAll		= 0x2;
+	const int _ObjectOptionMask		= 0x00F;
+	const int _ObjectOptionOne		= 0x1;
+	const int _ObjectOptionAll		= 0x2;
 	
-	const int _ModuleModeMask		= 0x0F0;
-	const int _ModuleModeInvalid	= 0x00;
-	const int _ModuleModeCurrent	= 0x10;
-	const int _ModuleModeAll		= 0x20;
-	const int _ModuleModeClones		= 0x30;
+	const int _ModuleOptionMask		= 0x0F0;
+	const int _ModuleOptionOne		= 0x10;
+	const int _ModuleOptionAll		= 0x20;
+	const int _ModuleOptionClones	= 0x30;
 	
-	const int _RenderModeMask		= 0xF00;
-	const int _RenderModeInvalid	= 0x000;
-	const int _RenderModeCurrent	= 0x100;
-	const int _RenderModeAll		= 0x200;
-	const int _RenderModeClones		= 0x300;
-	const int _RenderModeAuto		= 0xF00;
+	const int _RenderOptionMask		= 0xF00;
+	const int _RenderOptionOne		= 0x100;
+	const int _RenderOptionAll		= 0x200;
+	const int _RenderOptionClones	= 0x300;
+	const int _RenderOptionAuto		= 0xF00;
 
-	const int _EnvironmentBase				= 0;
-	const int _EnvironmentData				= 1;
-	const int _EnvironmentImage				= 2;
-	const int _EnvironmentScript			= 3;
-	const int _EnvironmentPalette			= 4;
-	const int _EnvironmentScalarFieldData	= 5;
-	const int _EnvironmentParticleSetData	= 6;
-	const int _EnvironmentVectorFieldData	= 7;
-	const int _EnvironmentTensorFieldData	= 8;
+	const int _DefaultOption = _ObjectOptionOne | _ModuleOptionOne | _RenderOptionAuto;
+
+	const int _EnvironmentBase					= 0;
+	const int _EnvironmentData					= 1;
+	const int _EnvironmentImage					= 2;
+	const int _EnvironmentScript				= 3;
+	const int _EnvironmentPalette				= 4;
+	const int _EnvironmentUniformScalarsData	= 5;
+	const int _EnvironmentBasicParticlesData	= 6;
+	const int _EnvironmentUniformVectorsData	= 7;
+	const int _EnvironmentUniformTensorsData	= 8;
 
 	//
 	// DataConsumer parameters
@@ -115,12 +114,16 @@ namespace iParameter
 	const int __NumDataConsumerOptimizationModes = 3;
 
 	//
-    // DataLimit parameters
+    // Data parameters
 	//
 	const int _BoundaryConditionsPeriodic = 0;
 	const int _BoundaryConditionsWall = 1;
 	const int __NumBoundaryConditions = 2;
 
+	const int _VoxelLocationVertex = 0;
+	const int _VoxelLocationCenter = 1;
+	const int __NumVoxelLocations = 2;
+
 	const int _StretchLin = 0;
 	const int _StretchLog = 1;
 
@@ -176,9 +179,12 @@ namespace iParameter
 	const int _TextJustRight = 2;
 	const int __NumTextJusts = 3;
 	
-	const int _TextTypeBitmap = 0;
-	const int _TextTypeVector = 1;
-	const int __NumTextTypes = 2;
+	const int _TextTypeVector = -1;
+	const int _TextTypeBitmapArial = 0;
+	const int _TextTypeBitmapCourier = 1;
+	const int _TextTypeBitmapTimes = 2;
+	const int __OffTextTypes = 1;
+	const int __NumTextTypes = 4;
 
 	//
 	// VectorFieldViewSubject parameters
@@ -235,20 +241,19 @@ namespace iParameter
 	//
 	//  ViewSubject parameters
 	//
-	const unsigned int _ViewSubjectAlwaysShaded =	1U;
-	const unsigned int _ViewSubjectNoReplicating =	2U;
-	const unsigned int _ViewSubjectNoColor =			4U;
-	const unsigned int _ViewSubjectNoOpacity =		8U;
-	const unsigned int _ViewSubjectNoPalette =		16U;
+	const unsigned int _ViewSubjectAlwaysShaded =	  1U;
+	const unsigned int _ViewSubjectNoReplicating =	  2U;
+	const unsigned int _ViewSubjectHasPosition =	  4U;
+	const unsigned int _ViewSubjectNoColor =		  8U;
+	const unsigned int _ViewSubjectNoOpacity =		 16U;
+	const unsigned int _ViewSubjectNoPalette =		 32U;
+	const unsigned int _ViewSubjectSameColor =		 64U;
+	const unsigned int _ViewSubjectSameOpacity =	128U;
+	const unsigned int _ViewSubjectSamePalette =	256U;
 
-	//
-	// VolumeViewSubject parameter;
-	//
-	const int _VolumeMethodRayCast = 0;
-	const int _VolumeMethod2DTexture = 1;
-	const int _VolumeMethod3DTexture = 2;
-	const int _VolumeMethodVolumePro = 3;
-	const int __NumVolumeMethods = 4;
+	const int _LocationPickedPoint =	0;
+	const int _LocationFocalPoint =		1;
+	const int _LocationBoxCenter =		2;
 };
 
 #endif // IPARAMETER_H
