@@ -29,6 +29,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iparticlesviewsubject.h"
 
 
+#include "iactor.h"
 #include "ibuffer.h"
 #include "ierror.h"
 #include "ifunctionmapping.h"
@@ -105,6 +106,7 @@ IOBJECT_DEFINE_KEY(iParticlesViewSubject,AttributeSizeExtraFactor,ae,Float,0);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,AttributeToSize,as,OffsetInt,0);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,AttributeToConnect,atc,OffsetInt,0);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,AttributeToSeparate,ats,OffsetInt,0);
+IOBJECT_DEFINE_KEY(iParticlesViewSubject,AutoScaled,au,Bool,0);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,Color,c,Color,0);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,CurrentGroup,cg,OffsetInt,1);
 IOBJECT_DEFINE_KEY(iParticlesViewSubject,StretchToColor,stc,Int,0);
@@ -140,23 +142,20 @@ IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,SpecularPower,mp
 IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,Visible,vis,Bool,1);
 IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,DataPresent,dp,Bool,1);
 IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,Ready,r,Bool,1);
-IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,Shading,mh,Bool,0);
+IOBJECT_DEFINE_INHERITED_KEY(iViewSubject,iParticlesViewSubject,Shading,mw,Bool,0);
 
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iParticlesViewSubject);
 
 
-iParticlesViewSubject::iParticlesViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iViewSubject(vm,type,name,0U)
+iParticlesViewSubject::iParticlesViewSubject(iViewModule *vm, const iDataType &type, const iString &name, const iColor &color, bool shaded) : iViewSubject(vm,type,name,0U)
 {
 	mObjectType = _ObjectTypeParticles;
 
-	vtkPolyData *input = dynamic_cast<vtkPolyData*>(this->GetData()); // accepts any PolyData
-	if(input == 0)
-	{
-		IERROR_FINISH("iParticlesViewSubject is configured incorrectly.");
-	}
-
 	mGroups = new iParticleGroupFamily(this); IERROR_ASSERT(mGroups);
 	mSplitter = iParticleSplitter::New(this); IERROR_ASSERT(mSplitter);
+
+	if(color.IsValid()) mGroups->GetMember(0)->SetColor(0,color);
+	mGroups->GetMember(0)->SetShading(shaded);
 }
 
 
@@ -202,7 +201,6 @@ void iParticlesViewSubject::ShowBody(bool s)
 void iParticlesViewSubject::Reset()
 {
 	mGroups->Reset();
-	mSplitter->SetInput(iRequiredCast<vtkPolyData>(this->GetData()));
 	this->SyncWithData(this->RequestAll());
 	this->ClearCache();
 }
@@ -237,7 +235,7 @@ void iParticlesViewSubject::PackStateBody(iString &s) const
 	this->PackValue(s,KeyClipPlane(),mClipPlaneOn);
 	this->PackValue(s,KeyNumReplicas(),mNumReplicas,6);
 	this->PackValue(s,KeyVisible(),this->IsVisible());
-	this->PackValue(s,KeyDataPresent(),this->IsDataPresent());
+	this->PackValue(s,KeyDataPresent(),this->IsThereData());
 	this->PackValue(s,KeyReady(),this->IsReady());
 
 	this->PackValue(s,KeyAttributeToSplit(),mSplitter->GetAttributeToSplit());
@@ -426,6 +424,9 @@ void iParticlesViewSubject::PackGroupStateBody(iString &s, int first, int last)
 	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetLineWidth();
 	this->PackValue(s,KeyLineWidth(),iv+first,n);
 
+	for(i=first; i<=last; i++) bv[i] = mGroups->GetMember(i)->GetAutoScaled();
+	this->PackValue(s,KeyAutoScaled(),bv+first,n);
+
 	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetAttributeToConnect();
 	this->PackValue(s,KeyAttributeToConnect(),iv+first,n);
 
@@ -578,6 +579,13 @@ void iParticlesViewSubject::UnPackGroupStateBody(const iString &s, int first, in
 		this->ClearCache();
 	}
 
+	for(i=first; i<=last; i++) bv[i] = mGroups->GetMember(i)->GetAutoScaled();
+	if(this->UnPackValue(s,KeyAutoScaled(),bv+first,n))
+	{
+		for(i=first; i<=last; i++) mGroups->GetMember(i)->SetAutoScaled(bv[i]);
+		this->ClearCache();
+	}
+
 	for(i=first; i<=last; i++) iv[i] = mGroups->GetMember(i)->GetAttributeToConnect();
 	if(this->UnPackValue(s,KeyAttributeToConnect(),iv+first,n))
 	{
@@ -758,7 +766,7 @@ int iParticlesViewSubject::GetAttributeToSplit() const
 void iParticlesViewSubject::ViewSubjectPackStateBody(iString &) const
 {
 #ifdef I_CHECK1
-	IERROR_REPORT("This function should never be called.");
+	IERROR_LOW("This function should never be called.");
 #endif
 }
 
@@ -766,14 +774,14 @@ void iParticlesViewSubject::ViewSubjectPackStateBody(iString &) const
 void iParticlesViewSubject::ViewSubjectUnPackStateBody(const iString &)
 {
 #ifdef I_CHECK1
-	IERROR_REPORT("This function should never be called.");
+	IERROR_LOW("This function should never be called.");
 #endif
 }
 
 
 bool iParticlesViewSubject::CanBeShown() const
 {
-	return true;
+	return (vtkPolyData::SafeDownCast(this->GetData()) != 0);
 }
 
 
@@ -781,6 +789,8 @@ void iParticlesViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &r)
 {
 	int i;
 
+	mSplitter->SetInput(vtkPolyData::SafeDownCast(this->GetData()));
+
 	for(i=0; i<=mGroups->GetMaxMemberIndex(); i++) 
 	{
 		mGroups->GetMember(i)->ViewSubjectSyncWithData(r);
