@@ -65,7 +65,7 @@ public:
 #ifdef IVTK_4
 		this->Modified();
 #else
-		this->Update(); // Very inefficient, but needed to work arund a VTK 5.0.0 bug
+		this->Update(); // Very inefficient, but needed to work around a VTK 5.0.0 bug
 #endif
 		mParent->Modified();
 	}
@@ -81,11 +81,11 @@ private:
 //
 iPiecewiseFunction* iPiecewiseFunction::New(float ymin, float ymax)
 {
-	return new iPiecewiseFunction(ymin,ymax);
+	return new iPiecewiseFunction(ymin,ymax,10);
 }
 
 
-iPiecewiseFunction::iPiecewiseFunction(float ymin, float ymax) : mArr(Point(iMath::_LargeFloat,0.0f))
+iPiecewiseFunction::iPiecewiseFunction(float ymin, float ymax, int inc) : mArr(inc)
 {
 	mYmin = ymin;
 	mYmax = ymax;
@@ -139,39 +139,20 @@ void iPiecewiseFunction::SetMinMax(float ymin, float ymax)
 
 void iPiecewiseFunction::AddPoint(int n) 
 {
-	int i;
-	
 	n++;
 	if(n < 1) n = 1;
 	if(n > mArr.MaxIndex()) n = mArr.MaxIndex();
 
-	mArr.Add(Point(0.0,0.0));
-
-	for(i=mArr.MaxIndex(); i>n; i--) mArr[i] = mArr[i-1];
-
-	mArr[n].X = 0.5*(mArr[n-1].X+mArr[n+1].X);
-	mArr[n].Y = 0.5*(mArr[n-1].Y+mArr[n+1].Y);
-
+	mArr.Add(Point(0.5*(mArr[n-1].X+mArr[n].X),0.5*(mArr[n-1].Y+mArr[n].Y)));
 	mHelper->ParentChanged();
 }
 
 
 void iPiecewiseFunction::AddPoint(float x, float y) 
 {
-	int i, n;
-
 	if(x>mArr[0].X && x<mArr.Last().X) 
 	{
-		n = 0;
-		while(mArr[n].X < x) n++;
-		
-		mArr.Add(Point(0.0,0.0));
-
-		for(i=mArr.MaxIndex(); i>n; i--) mArr[i] = mArr[i-1];
-
-		mArr[n].X = x; 
-		mArr[n].Y = y; 
-
+		mArr.Add(Point(x,y));
 		mHelper->ParentChanged();
 	}
 }
@@ -181,7 +162,7 @@ void iPiecewiseFunction::RemovePoint(int n)
 {
 	if(n>0 && n<mArr.MaxIndex() && mArr.Size()>2) 
 	{
-		mArr.Remove(n);
+		mArr.iArray<Point>::Remove(n);
 		mHelper->ParentChanged();
 	}
 }
