@@ -30,10 +30,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
+#include "idatahelper.h"
 #include "idatalimits.h"
 #include "ierror.h"
-#include "itune.h"
-#include "iuniformgriddatasubject.h"
 #include "iviewmodule.h"
 
 #include <vtkFloatArray.h>
@@ -113,7 +112,7 @@ void iProbeFilter::ProduceOutputForImageData(vtkPointSet *input, vtkPointSet *ou
 		inpts->GetPoint(l,x);
 
 		// Find the cell that contains xyz and get it
-		iUniformGridDataSubject::GetCICInterpolation(per,dims,org,spa,x,ijk1,ijk2,d1,d2);
+		iDataHelper::CIC(per,dims,org,spa,x,ijk1,ijk2,d1,d2);
 		loff111	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk1[1]+(vtkIdType)dims[1]*ijk1[2]));
 		loff112	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk1[1]+(vtkIdType)dims[1]*ijk2[2]));
 		loff121	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk2[1]+(vtkIdType)dims[1]*ijk1[2]));
