@@ -46,12 +46,14 @@ class vtkPointSet;
 class iProbeFilter : public iGenericFilter<vtkProbeFilter,vtkDataSet,vtkDataSet>
 {
 
-	IGENERICFILTER_DECLARE(iProbeFilter);
+	IGENERICFILTER_DECLARE(iProbeFilter,vtkProbeFilter);
 
 protected:
 	
 	virtual void ProduceOutput();
 
+private:
+
 	void ProduceOutputForImageData(vtkPointSet *input, vtkPointSet *output, vtkImageData *source);
 };
 
