@@ -40,7 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // iRangeCollection class
 //
-iRangeCollection::iRangeCollection(float min, float max) : mArr(Range(-iMath::_LargeFloat,iMath::_LargeFloat))
+iRangeCollection::iRangeCollection(float min, float max)
 {
 	mTiled = false;
 	mGlobalMin = min;
@@ -198,7 +198,7 @@ void iRangeCollection::Copy(const iRangeCollection *f)
 
 	mTiled = f->mTiled;
 
-	mStretch = f->mStretch;
+	this->SetStretch(f->GetStretch());
 }
 
 
