@@ -191,6 +191,12 @@ iRenderTool* iRenderTool::New(iViewModule *vm)
 
 iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : mViewModule(vm)
 {
+	//
+	//  Keeping the rendering order (a workaround for a VTK bug)
+	//
+	mActorObjects = vtkPropCollection::New(); IERROR_ASSERT(mActorObjects);
+	mVolumeObjects = vtkPropCollection::New(); IERROR_ASSERT(mVolumeObjects);
+
 	//
 	//  Main Window stuff
 	//
@@ -355,6 +361,9 @@ iRenderTool::~iRenderTool()
 {
 	this->ShowDualWindow(false);
 
+	mActorObjects->Delete();
+	mVolumeObjects->Delete();
+
 	mWindowCollection->RemoveAllItems();
 	mWindowCollection->Delete();
 	mDualWindowObserver->Delete();
@@ -508,8 +517,11 @@ void iRenderTool::SetBackground(const iImage &image)
 
 void iRenderTool::AddObject(vtkProp* p)
 {
-	if(p != 0)
+	if(p == 0) return;
+	
+	if(p->IsA("vtkVolume") != 0)
 	{
+		mVolumeObjects->AddItem(p);
 #ifdef IVTK_4
 		mMainRen->AddProp(p);
 		mDualRen->AddProp(p);
@@ -518,21 +530,68 @@ void iRenderTool::AddObject(vtkProp* p)
 		mDualRen->AddViewProp(p);
 #endif
 	}
+	else
+	{
+		//
+		//  Make sure all actors are ahead of volumes (is it a VTK bug?)
+		//
+		mActorObjects->AddItem(p);
+
+#ifdef IVTK_4
+		mMainRen->RemoveAllProps();
+		mDualRen->RemoveAllProps();
+#else
+		mMainRen->RemoveAllViewProps();
+		mDualRen->RemoveAllViewProps();
+#endif
+
+		vtkProp *p;
+		mActorObjects->InitTraversal();
+		while((p = mActorObjects->GetNextProp()) != 0)
+		{
+#ifdef IVTK_4
+			mMainRen->AddProp(p);
+			mDualRen->AddProp(p);
+#else
+			mMainRen->AddViewProp(p);
+			mDualRen->AddViewProp(p);
+#endif
+		}
+		mVolumeObjects->InitTraversal();
+		while((p = mVolumeObjects->GetNextProp()) != 0)
+		{
+#ifdef IVTK_4
+			mMainRen->AddProp(p);
+			mDualRen->AddProp(p);
+#else
+			mMainRen->AddViewProp(p);
+			mDualRen->AddViewProp(p);
+#endif
+		}
+	}
 }
 
 
 void iRenderTool::RemoveObject(vtkProp* p)
 {
-	if(p != 0)
+	if(p == 0) return;
+
+	if(p->IsA("vtkVolume") != 0)
 	{
-#ifdef IVTK_4
-		mMainRen->RemoveProp(p);
-		mDualRen->RemoveProp(p);
-#else
-		mMainRen->RemoveViewProp(p);
-		mDualRen->RemoveViewProp(p);
-#endif
+		mVolumeObjects->RemoveItem(p);
 	}
+	else
+	{
+		mActorObjects->RemoveItem(p);
+	}
+
+#ifdef IVTK_4
+	mMainRen->RemoveProp(p);
+	mDualRen->RemoveProp(p);
+#else
+	mMainRen->RemoveViewProp(p);
+	mDualRen->RemoveViewProp(p);
+#endif
 }
 
 
