@@ -60,6 +60,7 @@ class iViewModule;
 
 class vtkProp;
 class vtkPropAssembly;
+class vtkPropCollection;
 class vtkRenderer;
 class vtkRenderWindow;
 class vtkRenderWindowCollection;
@@ -182,6 +183,11 @@ private:
 	int mStereoType;
 	double mClippingRange[2];
 	bool mAntialiasing, mStereoAlignmentMarkersOn, mAutoClippingRange, mWindowCollectionUpToDate;
+
+	//
+	//  For ordered rendering
+	//
+	vtkPropCollection *mActorObjects, *mVolumeObjects;
 };
 
 #endif // IRENDERVIEW_H
