@@ -57,41 +57,54 @@ iReplicated::~iReplicated()
 }
 
 
-void iReplicated::SetNumReplicas(const int n[6])
+void iReplicated::UpdateReplicas(bool force)
 {
 	int i;
-	bool work = false;
+	bool work = force;
 
-	for(i=0; i<6; i++)
+	for(i=0; !work && i<6; i++)
 	{
-		if(n[i]>=0 && n[i]!=mNumReplicas[i])
-		{
-			work = true;
-			mOldNumReplicas[i] = mNumReplicas[i];
-			mNumReplicas[i] = n[i];
-		}
+		if(mOldNumReplicas[i] != mNumReplicas[i]) work = true;
 	}
 
 	if(work)
 	{
-		this->UpdateReplicas();
+		this->UpdateReplicasBody();
 		for(i=0; i<6; i++) mOldNumReplicas[i] = mNumReplicas[i];
 	}
 }
 
 
+void iReplicated::SetNumReplicas(const int n[6])
+{
+	int i;
+
+	for(i=0; i<6; i++)
+	{
+		mNumReplicas[i] = n[i];
+	}
+
+	this->UpdateReplicas();
+}
+
+
 void iReplicated::SetNumReplicas(int d, int n)
 {
 	if(n>=0 && d>=0 && d<6 && n!=mNumReplicas[d])
 	{
-		mOldNumReplicas[d] = mNumReplicas[d];
 		mNumReplicas[d] = n;
 		this->UpdateReplicas();
-		mOldNumReplicas[d] = mNumReplicas[d];
 	}
 }
 
 
+void iReplicated::GetNumReplicas(int n[6])
+{
+	int i;
+	for(i=0; i<6; i++) n[i] = mNumReplicas[i];
+}
+
+
 void iReplicated::UnReplicate()
 {
 	static int r[6] = { 0, 0, 0, 0, 0, 0 };
