@@ -44,6 +44,7 @@ public:
 	void SetNumReplicas(const int n[6]);
 	void SetNumReplicas(int d, int n);
 	inline int GetNumReplicas(int d) const { if(d>=0 && d<6) return mNumReplicas[d]; else return 0; }
+	void GetNumReplicas(int n[6]);
 
 	inline bool IsReplicated() const { return mNumReplicas[0]>0 || mNumReplicas[1]>0 || mNumReplicas[2]>0 || mNumReplicas[3]>0 || mNumReplicas[4]>0 || mNumReplicas[5]>0; }
 
@@ -55,7 +56,8 @@ protected:
 	iReplicated(iViewSubjectReplicator *replicator, bool data);
 	virtual ~iReplicated();
 	
-	virtual void UpdateReplicas() = 0;
+	void UpdateReplicas(bool force = false);
+	virtual void UpdateReplicasBody() = 0;
 
 	int mNumReplicas[6], mOldNumReplicas[6];
 	bool mIsDataReplicated;
