@@ -112,7 +112,7 @@ private:
 		}
 	}
 
-	iReplicatedActorDevice(iReplicatedActor *parent) : mReplicas(Replica())
+	iReplicatedActorDevice(iReplicatedActor *parent)
 	{
 		mParent = parent; IERROR_ASSERT(mParent);
 	
@@ -138,6 +138,7 @@ private:
 //
 iReplicatedActor* iReplicatedActor::New(iViewSubjectReplicator *replicator, bool scaled)
 {
+	IERROR_ASSERT(replicator);
 	return new iReplicatedActor(replicator,scaled);
 }
 
@@ -191,7 +192,7 @@ void iReplicatedActor::Render(vtkRenderer *ren, vtkMapper *m)
 }
 
 
-void iReplicatedActor::UpdateReplicas()
+void iReplicatedActor::UpdateReplicasBody()
 {
 	int i, j, k;
 
