@@ -47,7 +47,6 @@ class iReplicatedActor : public iActor, public iReplicated
 public:
 	
 	vtkTypeMacro(iReplicatedActor,iActor);
-
 	static iReplicatedActor* New(iViewSubjectReplicator *replicator = 0, bool scaled = false);
 
 	virtual double* GetBounds();
@@ -58,7 +57,9 @@ protected:
 	iReplicatedActor(iViewSubjectReplicator *replicator, bool scaled);
 	virtual ~iReplicatedActor();
 	
-	virtual void UpdateReplicas();
+	virtual void UpdateReplicasBody();
+
+private:
 
 	iReplicatedActorDevice *mRealDevice;
 	vtkTimeStamp mReplicatedBoundsMTime;
