@@ -40,13 +40,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkStructuredPoints.h>
 #include <vtkUnsignedCharArray.h>
 
+//
+//  Templates
+//
+#include "igenericfiltertemplate.h"
+
 
 iReplicatedGridData::iReplicatedGridData(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>(vo,1,true,true), iParallelWorker(vo->GetViewModule()->GetParallelManager()), iReplicated(vo->GetReplicator(),true)
 {
 }
 
 
-void iReplicatedGridData::UpdateReplicas()
+void iReplicatedGridData::UpdateReplicasBody()
 {
 	this->Modified();
 }
