@@ -52,11 +52,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 iReplicatedVolume* iReplicatedVolume::New(iViewSubjectReplicator *replicator)
 {
+	IERROR_ASSERT(replicator);
 	return new iReplicatedVolume(replicator);
 }
 
 
-iReplicatedVolume::iReplicatedVolume(iViewSubjectReplicator *replicator) : iReplicated(replicator,false), iViewModuleComponent(replicator->GetViewModule()), mReplicas(Replica())
+iReplicatedVolume::iReplicatedVolume(iViewSubjectReplicator *replicator) : iReplicated(replicator,false), mViewModule(replicator->GetViewModule())
 {
 	//
 	//  Must create property first - it is not created by default
@@ -94,12 +95,6 @@ void iReplicatedVolume::CreateReplica(int i, int j, int k)
 }
 
 
-int iReplicatedVolume::IsA(const char *type)
-{
-	if(strcmp(type,"iReplicatedVolume") == 0) return 1; else return vtkVolume::IsA(type);
-}
-
-
 double* iReplicatedVolume::GetBounds()
 {
 	int i;
@@ -137,7 +132,7 @@ int iReplicatedVolume::RenderTranslucentGeometry(vtkViewport *vp)
 	//
 	//  Reorder volumes
 	//
-	mCuller->Cull(iRequiredCast<vtkRenderer>(vp),buf,n,initialized);
+	mCuller->Cull(iRequiredCast<vtkRenderer>(INFO,vp),buf,n,initialized);
 
 	//
 	//  n can change inside Cull()
@@ -149,7 +144,7 @@ int iReplicatedVolume::RenderTranslucentGeometry(vtkViewport *vp)
 }
 
 
-void iReplicatedVolume::UpdateReplicas()
+void iReplicatedVolume::UpdateReplicasBody()
 {
 	int i, j, k;
 	Replica tmp;
