@@ -34,23 +34,27 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IREPLICATEDVOLUME_H
 
 
-#include "vtkVolume.h"
+#include <vtkVolume.h>
 #include "ireplicated.h"
-#include "iviewmodulecomponent.h"
 
 
 #include "iarray.h"
 
+#include "ipointermacro.h"
+
+class iViewModule;
 class vtkFrustumCoverageCuller;
 
 
-class iReplicatedVolume : public vtkVolume, public iReplicated, public iViewModuleComponent
+class iReplicatedVolume : public vtkVolume, public iReplicated
 {
 	
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 	
-	static iReplicatedVolume* New(iViewSubjectReplicator *replicator);
-	virtual int IsA(const char *type);
+	vtkTypeMacro(iReplicatedVolume,vtkVolume);
+	static iReplicatedVolume* New(iViewSubjectReplicator *replicator = 0);
 
 	virtual double* GetBounds();
 	virtual int RenderTranslucentGeometry(vtkViewport *vp);
@@ -62,8 +66,11 @@ protected:
 	iReplicatedVolume(iViewSubjectReplicator *replicator);
 	virtual ~iReplicatedVolume();
 	
+	virtual void UpdateReplicasBody();
+
+private:
+
 	void CreateReplica(int i, int j, int k);
-	virtual void UpdateReplicas();
 
 	struct Replica
 	{
