@@ -31,45 +31,56 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include <vtkAxisActor2D.h>
-#include "ioverlaybase.h"
-#include "iviewmodulecomponent.h"
 
 
-class iColor;
+#include "ipointermacro.h"
+#include "istring.h"
+
+class iOverlayHelper;
+class iRenderTool;
+class iViewModule;
 
 
-class iRuler: public vtkAxisActor2D, public iOverlayBase, protected iViewModuleComponent
+class iRuler: public vtkAxisActor2D
 {
 	
+	IPOINTER_AS_PART(ViewModule);
+	IPOINTER_AS_USER(OverlayHelper);
+
 public:
 	
-	static iRuler* New(iViewModule *vm);
+	vtkTypeMacro(iRuler,vtkAxisActor2D);
+	static iRuler* New(iViewModule *vm = 0);
 	
-	virtual int RenderOverlay(vtkViewport*);
-	virtual int RenderOpaqueGeometry(vtkViewport*);
-	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
+	virtual int RenderOverlay(vtkViewport *vp);
+	virtual int RenderOpaqueGeometry(vtkViewport *vp);
+	virtual int RenderTranslucentGeometry(vtkViewport * ){ return 0; }
 	
 	virtual void ReleaseGraphicsResources(vtkWindow *win);
 
-	void SetColor(iColor &c);
 	void SetBaseScale(float s);
 
 	void SetScale(float s);
 	inline float GetScale() const { return mScale; }
 
+	void SetTitle(const iString &title);
+	inline const iString& GetTitle() const { return mTitle; }
+
 protected:
+
+	virtual ~iRuler();
+
+private:
 	
 	iRuler(iViewModule *vm);
-	virtual ~iRuler();
 	
-private:
-
 	float mLineWidth;
 	int mTickLength;
 	float mDx;
 
 	bool mStarted;
 	float mScale, mBaseScale;
+	iString mTitle;
 };
 
 #endif // IRULER_H
