@@ -26,25 +26,29 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
-#ifndef ISHELL_H
-#define ISHELL_H
-
 //
 //  A base class for all GUI shells around the VTK-based core
 //
 
+#ifndef ISHELL_H
+#define ISHELL_H
+
+
+#include <vtkObjectBase.h>
+
+
 #include "iarray.h"
 #include "istring.h"
 
+#include <vtkSetGet.h>
+
 class iControlModule;
 class iFile;
-class iObjectKey;
-class iOutputWindow;
 
 class vtkTimerLog;
 
 
-class iShell
+class iShell : public vtkObjectBase
 {
 
 public:
@@ -58,6 +62,8 @@ public:
 		Option() { NeedsValue = false; }
 	};
 
+	vtkTypeMacro(iShell,vtkObjectBase);
+
 	//
 	//  A helper function that creates, runs, and deletes a shell in one call
 	//
@@ -66,10 +72,10 @@ public:
 	//
 	//  Create a shell with this function
 	//
-	static iShell* New(const iString &type, int argc, char **argv);
+	static iShell* New(const iString &type = "", int argc = 0, char **argv = 0);
 
 	//
-	//  This function does the shell's work after all the windows are created. 
+	//  This function does the shell's work after all the components are created. 
 	//
 	void Run();
 
@@ -88,30 +94,20 @@ public:
 	//
 	inline const iString& Type() const { return mType; }
 	inline iControlModule* GetControlModule() const { return mControlModule; }
-	inline iOutputWindow* GetOutputWindow() const { return mOutputWindow; }
 	inline bool IsRunning() const { return mRunning; }
 
 	const iString& GetEnvironment(int key) const;
 	inline const iString& GetStateFileName() const { return mStateFileName; }
 
-	virtual bool LoadShellStateFromFile(iFile &F) = 0;
-	virtual bool SaveShellStateToFile(iFile &F) const  = 0;
+	bool LoadShellStateFromFile(iFile &F);
+	bool SaveShellStateToFile(iFile &F) const;
 
 	void OnInitAtom();
-
-	//
-	//  Directory naming convention for portability
-	//
-	const iString& GetDirSeparator() const;
-	const iString& GetCurrentDir() const;
-
-#ifdef I_DEBUG
-	virtual void OutputDebugMessage(const iString &message) const = 0;
-#endif
-
+	void OnLoadStateFileAtom(int prog);
+	
 protected:
 
-	iShell(int argc, char **argv);
+	iShell(const iString &type, int argc, char **argv);
 	virtual ~iShell();  
 
 	//
@@ -135,29 +131,38 @@ protected:
 	virtual void Start() = 0;
 	virtual void RunBody() = 0; // body of Run()
 	virtual void PrepareForConstruction() = 0;
+
+	virtual void PrepareToLoadStateFile() = 0;
+	virtual bool LoadShellStateFromFileBody(iFile &F) = 0;
+	virtual bool SaveShellStateToFileBody(iFile &F) const  = 0;
+
 	virtual void DefineSpecificCommandLineOptions() = 0;
-	virtual void LoadStateFile(const iString &fname) = 0;
-	virtual void OutputStartupMessage(const iString &message) = 0;
 	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o) = 0;
 
 	//
-	//  This function can be used to animate the initialization progress.
-	//  Does nothing by default
+	//  These functions can be used to animate the initialization/load state file progress.
+	//  Do nothing by default.
 	//
 	virtual void OnInitAtomBody(bool timed);
+	virtual void OnLoadStateFileAtomBody(int prog);
+	
+	//
+	//  Useful helpers
+	//
+	bool HasStateFile() const;
+
+	iControlModule* ControlModule() const { return mControlModule; }
+
+private:
 
 	iControlModule *mControlModule;
-	iOutputWindow *mOutputWindow;
 
 	bool mRunning;
-	iString mType;
+	const iString mType;
 	static const iString mOptionPrefix;
 	iArray<Option> mOptions;
-	iString mStateFileName;
 	int mNumProcs, mFirstOption;
 
-	vtkTimerLog *mInitTimer;
-	
 	//
 	//  Initialization
 	//
@@ -169,6 +174,7 @@ protected:
 
 	int mCurInitStep;
 	InitStep mInitSteps[4];
+	vtkTimerLog *mInitTimer;
 
 	//
 	//  Environment
@@ -179,9 +185,9 @@ protected:
 	iString mEnvScriptDir;
 	iString mEnvPaletteDir;
 
-private:
+	iString mStateFileName, mScriptFileName;
 
-#ifdef I_DEVEL
+#ifdef I_DEBUG
 	void InitHelper();
 #endif
 };
