@@ -47,7 +47,7 @@ class vtkPointSet;
 class iStreamLineFilter : public iGenericFilter<vtkStreamTracer,vtkDataSet,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iStreamLineFilter);
+	IGENERICFILTER_DECLARE(iStreamLineFilter,vtkStreamTracer);
 
 public:
 
@@ -74,7 +74,6 @@ public:
 protected:
 	
 	virtual void ProduceOutput();
-	void ProduceOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source);
 
 	virtual vtkIdType GetVector(double x[3], float v[3], float *vort = 0, float *div = 0);
 	virtual int FollowLine(double x[3], double &d, float &h, float eps, vtkIdType l);
@@ -83,12 +82,6 @@ protected:
 	virtual void AssignScalars(float *p, vtkIdType l);
 	virtual void GetDmin(vtkIdType l, float &ddmin, float &dx);
 
-	float mVmin, mDmin, mEps;
-	float mLength;
-	bool mComputeVort, mComputeDiv;
-	int mDir, mQuality, mItMax, mAxisDir;
-	bool mSplitLines;
-
 	//
 	//  Work variables
 	//
@@ -96,6 +89,19 @@ protected:
 	int wDims[3], wNsca;
 	float *wPtrVec, *wPtrSca;
 	double wOrg[3], wSpa[3];
+
+	float mDmin;
+
+private:
+
+	void ProduceOutputForImageData(vtkImageData *input, vtkPolyData *output, vtkPointSet *source);
+
+	float mVmin, mEps;
+	float mLength;
+	bool mComputeVort, mComputeDiv;
+	int mDir, mQuality, mItMax, mAxisDir;
+	bool mSplitLines;
+
 };
 
 #endif  // ISTREAMLINEFILTER_H
