@@ -44,7 +44,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewsubjectparallelpipeline.h"
 
 #include <vtkImageData.h>
+#include <vtkMassProperties.h>
 #include <vtkPolyData.h>
+#include <vtkPolyDataConnectivityFilter.h>
+#include <vtkTriangleFilter.h>
 
 //
 //  Templates
@@ -62,6 +65,7 @@ IOBJECT_DEFINE_KEY(iSurfaceViewSubject,IsoSurfaceLevel,l,Float,1);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,Method,m,Int,1);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,NormalsFlipped,nf,Bool,1);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,IsoSurfaceOptimization,op,Bool,1);
+IOBJECT_DEFINE_KEY(iSurfaceViewSubject,OutputProperties,out,Bool,1);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,PlaneDirection,pd,Float,3);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,PaintVar,pv,OffsetInt,2);
 IOBJECT_DEFINE_KEY(iSurfaceViewSubject,IsoSurfaceReduction,rd,Int,1);
@@ -76,7 +80,7 @@ IOBJECT_DEFINE_DISTANCE_KEY(iSurfaceViewSubject,Size,s);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COMMON(iSurfaceViewSubject);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iSurfaceViewSubject);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_POSITION(iSurfaceViewSubject);
-IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COLOR(iSurfaceViewSubject,2);
+IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COLOR(iSurfaceViewSubject,1);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_OPACITY(iSurfaceViewSubject,1);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_PALETTE(iSurfaceViewSubject,2);
 
@@ -89,7 +93,7 @@ IOBJECT_DEFINE_KEY(iSurfaceViewSubject,ProbePositionToPickedPoint,-p2p,Bool,1);
 //
 // iSurfaceViewSubject class
 //
-iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,2,_ViewSubjectHasPosition|_ViewSubjectSameOpacity), mSize(vm,true)
+iSurfaceViewSubject::iSurfaceViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iSolidViewSubject(vm,type,name,2,_ViewSubjectHasPosition|_ViewSubjectSameOpacity|_ViewSubjectSameColor), mSize(vm,true)
 {
 	mObjectType = _ObjectTypeSurface;
 
@@ -405,12 +409,16 @@ void iSurfaceViewSubject::SolidViewSubjectUnPackStateBody(const iString &s)
 
 	if(this->UnPackValueDistance(s,KeySize(),mSize)) this->SetSize(mSize);
 
-#ifdef IOBJECT_BACKWARD_COMPATIBLE
+	//
+	//  Action key
+	//
 	iObject::ReportMissingKeys(false);
+	if(this->UnPackValue(s,KeyOutputProperties(),b) && b) this->OutputProperties();
+#ifdef IOBJECT_BACKWARD_COMPATIBLE
 	if(this->UnPackValue(s,KeyAttachProbeToMarker(),i)) this->AttachToMarker(i);
 	if(this->UnPackValue(s,KeyProbePositionToPickedPoint(),b) && b) this->SetPosition(_LocationPickedPoint); 
-	iObject::ReportMissingKeys(true);
 #endif
+	iObject::ReportMissingKeys(true);
 }
 
 
@@ -428,7 +436,7 @@ void iSurfaceViewSubject::SetMethod(int m)
 
 void iSurfaceViewSubject::SetSize(const iDistance &s)
 {
-	if(s < 1.0)
+	if(s < 1.1)
 	{
 		mSize = s;
 		this->Pipeline()->UpdateContents(iSurfacePipeline::_FixedSurfaceSize);
@@ -453,6 +461,47 @@ void iSurfaceViewSubject::SetPlaneDirection(const float n[3])
 }
 
 
+void iSurfaceViewSubject::OutputProperties() const
+{
+	if(!this->IsVisible()) return;
+
+	iString s;
+	float l = 1.0;
+	if(!this->GetViewModule()->GetOpenGLCoordinates())
+	{
+		l = 0.5*this->GetViewModule()->GetBoxSize();
+	}
+
+	vtkTriangleFilter *tf = vtkTriangleFilter::New(); IERROR_ASSERT(tf);
+	tf->SetInput(this->Pipeline()->GetOutput(0));
+	tf->PassLinesOff();
+	tf->PassVertsOff();
+
+	//
+	//  Surface area & volume
+	//
+	vtkMassProperties *f1 = vtkMassProperties::New(); IERROR_ASSERT(f1);
+	f1->SetInput(tf->GetOutput());
+	f1->Update();
+	s = "Area:   " + iString::FromNumber(f1->GetSurfaceArea()*l*l); iConsole::Display(iConsole::_Info,s.ToCharPointer());
+	s = "Volume: " + iString::FromNumber(f1->GetVolume()*l*l*l); iConsole::Display(iConsole::_Info,s.ToCharPointer());
+	f1->Delete();
+
+	//
+	//  Connectivity info
+	//
+	vtkPolyDataConnectivityFilter *f2 = vtkPolyDataConnectivityFilter::New(); IERROR_ASSERT(f2);
+	f2->SetInput(tf->GetOutput());
+	f2->ScalarConnectivityOff();
+	f2->SetExtractionModeToAllRegions();
+	f2->Update();
+	s = "Regions: " + iString::FromNumber(f2->GetNumberOfExtractedRegions()); iConsole::Display(iConsole::_Info,s.ToCharPointer());
+	f2->Delete();
+
+	tf->Delete();
+}
+
+
 bool iSurfaceViewSubject::CanBeShown() const
 {
 	iDataHelper *h = this->CreateDataHelper(this->GetData());
