@@ -95,7 +95,6 @@ public:
 	//virtual void SetSize(const iDistance &s);
 	//inline const iDistance& GetSize() const { return mSize; }
 	
-//	inline iActor* GetActor(int i = 0) const { if(i == 0) return mActor[0]; else return mActor[1]; }
 		
 	//
 	//  Inherited members
@@ -109,6 +108,8 @@ public:
 	static const iObjectKey& KeyProbePositionToPickedPoint();
 #endif
 
+	static const iObjectKey& KeyOutputProperties();
+
 protected:
 	
 	iSurfaceViewSubject(iViewModule *vm, const iDataType &type, const iString &name);
@@ -118,6 +119,8 @@ protected:
 
 	virtual void UpdatePosition(const iPosition &oldPos);
 
+	void OutputProperties() const;
+
 	int mMethod, mIsoSurfaceMethod;
 	float mLev;
 	int mVar, mPaintVarExt, mPaintVarInt;
