@@ -28,7 +28,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "itext.h"
 
+
 #include "imath.h"
+#include "ioverlayhelper.h"
 
 #include <vtkCamera.h>
 #include <vtkRenderer.h>
@@ -37,14 +39,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-iText::iText(const iRenderTool *rv) : iOverlayBase(rv)
+iText::iText(iRenderTool *rv) : mOverlayHelper(rv)
 {
 	mBold = false;
 	mHorJust = mVerJust = _TextJustCenter;
 	mPos[0] = mPos[1] = 0.0;
 	mAngle = 0.0;
+	mFontScale = 0;
 
-	mColor = iColor();
 	mSize[0] = mSize[1] = 0.0;
 
 	this->PickableOff();
