@@ -29,19 +29,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "itextactor.h"
 
 #include "ierror.h"
-
-#include <vtkProp.h>
+#include "ioverlayhelper.h"
 
 
 using namespace iParameter;
 
 
-iTextActor::iTextActor(const iRenderTool *rv)
+iTextActor::iTextActor(iRenderTool *rv)
 {
-	mFontType = _TextTypeBitmap;
+	mFontIndex = 1;
 
-	mText[0] = iTextBitmap::New(rv); IERROR_ASSERT(mText[0]);
-	mText[1] = iTextVector::New(rv); IERROR_ASSERT(mText[1]);
+	mText[0] = iTextVector::New(rv); IERROR_ASSERT(mText[0]);
+	mText[1] = iTextBitmap::New(rv); IERROR_ASSERT(mText[1]);
+	mText[2] = iTextBitmap::New(rv); IERROR_ASSERT(mText[2]);
+	mText[3] = iTextBitmap::New(rv); IERROR_ASSERT(mText[3]);
 
 	this->PickableOff();
 }
@@ -62,12 +63,12 @@ void iTextActor::ReleaseGraphicsResources(vtkWindow *w)
 
 int iTextActor::RenderOverlay(vtkViewport *v)
 {
-	return mText[mFontType]->RenderOverlay(v);
+	return mText[mFontIndex]->RenderOverlay(v);
 }
 
 
 int iTextActor::RenderOpaqueGeometry(vtkViewport *v)
 {
-	return mText[mFontType]->RenderOpaqueGeometry(v);
+	return mText[mFontIndex]->RenderOpaqueGeometry(v);
 }
 
