@@ -42,40 +42,45 @@ class iTextActor: public vtkProp
 	
 public:
 
-	static iTextActor* New(const iRenderTool *rv){ return new iTextActor(rv); }
+	static iTextActor* New(iRenderTool *rv){ return new iTextActor(rv); }
 	
 	virtual int RenderOverlay(vtkViewport *v);
 	virtual int RenderOpaqueGeometry(vtkViewport *v);
 	
 	virtual void ReleaseGraphicsResources(vtkWindow *w);
 
-	inline void GetSize(vtkViewport *v, float s[2]) const { mText[mFontType]->GetSize(v,s); }
-	inline void GetSize(float s[2]) const { s[0] = mText[mFontType]->GetSize()[0]; s[1] = mText[mFontType]->GetSize()[1]; }
+	inline void GetSize(vtkViewport *v, float s[2]) const { mText[mFontIndex]->GetSize(v,s); }
+	inline void GetSize(float s[2]) const { s[0] = mText[mFontIndex]->GetSize()[0]; s[1] = mText[mFontIndex]->GetSize()[1]; }
 
-	inline void SetFontType(int s){ if(s>=0 && s<iParameter::__NumTextTypes) mFontType = s; }
-	inline int GetFontType() const { return mFontType; }
-
-	virtual void SetColor(iColor &c){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetColor(c); }
-	virtual void SetFontScale(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetFontScale(s); }
-	virtual void SetBold(bool s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetBold(s); }
-	virtual void SetHJustification(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetHJustification(s); }
-	virtual void SetVJustification(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetVJustification(s); }
-	virtual void SetPosition(float p[2]){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetPosition(p); }
-	virtual void SetPosition(float p0, float p1){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetPosition(p0,p1); }
-	virtual void Rotate(float a){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->Rotate(a); }
+	void SetFontType(int s){ s += iParameter::__OffTextTypes; if(s>=0 && s<iParameter::__NumTextTypes) mFontIndex = s; }
+	inline int GetFontType() const { return mFontIndex - iParameter::__OffTextTypes; }
 
+	void SetFontScale(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetFontScale(s); }
 	inline int GetFontScale() const { return mText[0]->GetFontScale(); }
+
+	void SetBold(bool s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetBold(s); }
 	inline bool GetBold() const { return mText[0]->GetBold(); }
+
+	void SetHJustification(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetHJustification(s); }
+	void SetVJustification(int s){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetVJustification(s); }
+
+	void SetPosition(float p[2]){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetPosition(p); }
+	void SetPosition(float p0, float p1){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetPosition(p0,p1); }
 	inline const float* GetPosition() const { return mText[0]->GetPosition(); }
 
+	void Rotate(float a){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->Rotate(a); }
+
 	virtual void SetText(const iString &t){ for(int i=0; i<iParameter::__NumTextTypes; i++) mText[i]->SetText(t);} 
 
 protected:
 	
-	iTextActor(const iRenderTool *rv);
 	virtual ~iTextActor();
-	
-	int mFontType;
+
+private:
+
+	iTextActor(iRenderTool *rv);
+
+	int mFontIndex;
 	iText *mText[iParameter::__NumTextTypes];
 };
 
