@@ -48,7 +48,7 @@ class iTextBitmap: public iText
 	
 public:
 	
-	static iTextBitmap* New(const iRenderTool *rv){ return new iTextBitmap(rv); }
+	static iTextBitmap* New(iRenderTool *rv);
 	
 	virtual int RenderOverlay(vtkViewport *v);
 	virtual int RenderOpaqueGeometry(vtkViewport *v);
@@ -58,9 +58,12 @@ public:
 	virtual void GetSize(vtkViewport *v, float s[2]);
 
 protected:
-	
-	iTextBitmap(const iRenderTool *rv);
+
 	virtual ~iTextBitmap();
+
+private:
+	
+	iTextBitmap(iRenderTool *rv);
 	
 	vtkTextMapper *mMapper;
 	vtkActor2D *mActor;
