@@ -29,11 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iuniformgridfileloader.h"
 
 
+#include "icalculator.h"
 #include "icommoneventobservers.h"
 #include "idatalimits.h"
 #include "idatasubject.h"
 #include "ierrorstatus.h"
-#include "iexpressionparser.h"
 #include "ifile.h"
 #include "iparallel.h"
 #include "iparallelmanager.h"
@@ -56,6 +56,7 @@ using namespace iParameter;
 //
 #include "iarraytemplate.h"
 #include "ibuffertemplate.h"
+#include "icalculatortemplate.h"
 
 
 //
@@ -99,7 +100,7 @@ public:
 
 	iUniformScalarsHelper(iUniformScalarsFileLoader *loader);
 
-	void OperateOnData1(int nvar, int dims[3], iExpressionParser *calc, bool doVector, float ps, float dp);
+	void OperateOnData1(int nvar, int dims[3], const iString &calculatorExpression, bool doVector, float ps, float dp);
 	void OperateOnData2(int nvar, int dims[3], float *fMin, float *fMax, bool &overflow, float ps, float dp);
 
 protected:
@@ -111,7 +112,8 @@ protected:
 
 	iUniformScalarsFileLoader *mLoader;
 	iProgressEventObserver *mObserver;
-	iExpressionParser *mCalculator;
+
+	iString mCalculatorExpression;
 
 	int mNumVars, mNumProcs, *mDims;
 
@@ -891,9 +893,8 @@ iUniformScalarsFileLoader::iUniformScalarsFileLoader(iDataReader *r, iUniformVec
 	mVectorFieldLoader = vs;
 
 	mCalculatorOutput = 0;
-//	mCalculatorFunction = "";
+//	mCalculatorExpression = "";
 
-	mCalculator = iExpressionParser::New(); IERROR_ASSERT(mCalculator);
 	mHelper2 = new iUniformScalarsHelper(this); IERROR_ASSERT(mHelper2);
 }
 
@@ -901,7 +902,6 @@ iUniformScalarsFileLoader::iUniformScalarsFileLoader(iDataReader *r, iUniformVec
 iUniformScalarsFileLoader::~iUniformScalarsFileLoader()
 {
 	delete mHelper2;
-	mCalculator->Delete();
 }
 
 
@@ -969,9 +969,9 @@ void iUniformScalarsFileLoader::SetCalculatorOutput(int n)
 }
 
 
-void iUniformScalarsFileLoader::SetCalculatorFunction(const iString &s)
+void iUniformScalarsFileLoader::SetCalculatorExpression(const iString &s)
 {
-	mCalculatorFunction = s;
+	mCalculatorExpression = s;
 }
 
 
@@ -988,17 +988,15 @@ void iUniformScalarsFileLoader::OperateOnData()
 	//
 	//  Do the array function first
 	//
-	if(mCalculatorOutput>=0 && mCalculatorOutput<nvar && !mCalculatorFunction.IsEmpty())
+	if(mCalculatorOutput>=0 && mCalculatorOutput<nvar && !mCalculatorExpression.IsEmpty())
 	{
 		this->GetObserver()->Started(iProgressEventObserver::_Operating);
 		this->GetObserver()->SetProgress(0.0);
 
-		mCalculator->SetFunction(mCalculatorFunction);
-
 		bool doVector = false;
 		if(this->IsCompatible(mVectorFieldLoader)) doVector = true;
 
-		mHelper2->OperateOnData1(nvar,mFileDims,mCalculator,doVector,0.0,1.0);
+		mHelper2->OperateOnData1(nvar,mFileDims,mCalculatorExpression,doVector,0.0,1.0);
 	}
 
 	this->GetObserver()->Started(iProgressEventObserver::_Formatting);
@@ -1426,17 +1424,29 @@ iUniformScalarsHelper::iUniformScalarsHelper(iUniformScalarsFileLoader *subject)
 }
 
 
-void iUniformScalarsHelper::OperateOnData1(int nvar, int dims[3], iExpressionParser *calc, bool doVector, float ps, float dp)
+void iUniformScalarsHelper::OperateOnData1(int nvar, int dims[3], const iString &calculatorExpression, bool doVector, float ps, float dp)
 {
 	mNumVars = nvar;
 	mDims = dims;
-	mCalculator = calc;
+	mCalculatorExpression = calculatorExpression;
 	mDoVector = doVector;
 
 	mProgStart = ps;
 	mProgStep = dp;
 
-	this->ParallelExecute(1);
+	iCalculator<float> calc;
+	iCalculator<float>::real_var var("Var",mNumVars,&calc);
+	iCalculator<float>::real_var vec("Vec",3);
+	if(mDoVector) calc.AddVariable(&vec);
+
+	if(!calc.Compile(mCalculatorExpression) || !calc.Link())
+	{
+		IERROR_LOW(calc.GetErrorMessage());
+	}
+	else
+	{
+		this->ParallelExecute(1);
+	}
 }
 
 
@@ -1502,26 +1512,34 @@ int iUniformScalarsHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 //
 void iUniformScalarsHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &p)
 {
-	char arName[5];
-	double res;
-	
-	arName[0] = 'V';
-	arName[1] = 'a';
-	arName[2] = 'r';
-	arName[4] = 0;
-
 	float *arr1 = mLoader->GetDataPointer();
 	float *arr2 = mLoader->mVectorFieldLoader->GetDataPointer();
 
 	if(arr1==0 || (mDoVector && arr2==0)) return;
 
 	long size = (long)mDims[0]*mDims[1]*mDims[2];
-	int n, nout = mLoader->GetCalculatorOutput();
+	int nout = mLoader->GetCalculatorOutput();
 	long l, kbeg, kend, kstp;
 	iParallel::SplitRange(p,size,kbeg,kend,kstp);
 
 	float progScale = mProgStep/kstp;
 
+	//
+	// Create our calculator
+	//
+	iCalculator<float> calc;
+
+	iCalculator<float>::real_ptr var(arr1+kbeg*mNumVars,"Var",mNumVars,&calc);
+	iCalculator<float>::real_ptr vec(arr2==0?arr1:arr2+kbeg*3,"Vec",3);
+	if(mDoVector)
+	{
+		calc.AddVariable(&vec);
+	} 
+
+	if(!calc.Compile(mCalculatorExpression) || !calc.Link()) return;
+
+	const float *output = calc.GetResultData();
+
 	for(l=kbeg; l<kend; l++) 
 	{
 		if(l%1000==0 && mObserver!=0)
@@ -1529,21 +1547,10 @@ void iUniformScalarsHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &p)
 			if(this->IsMaster(p)) mObserver->SetProgress(mProgStart+progScale*(l-kbeg));
 			if(mObserver->IsAborted()) return;
 		}
-		for(n=0; n<mNumVars; n++)
-		{
-			arName[3] = (char)((int)'1'+n);
-			mCalculator->SetScalarVariableValue(arName,arr1[n+mNumVars*l]);
-		}
-		if(mDoVector)
-		{
-			mCalculator->SetVectorVariableValue("Vector",arr2[0+3*l],arr2[1+3*l],arr2[2+3*l]);
-		} 
-		else 
-		{
-			mCalculator->SetVectorVariableValue("Vector",0.0,0.0,0.0);
-		}
-		
-		if(mCalculator->GetScalarResult(res)) arr1[nout+mNumVars*l] = res;
+		if(!calc.Execute()) break;		
+		arr1[nout+mNumVars*l] = *output;
+		++var;
+		++vec;
 	}
 }
 
