@@ -29,12 +29,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ivectorfieldviewsubject.h"
 
 
-#include "ibasicdatadistributor.h"
 #include "iboundedplanesource.h"
 #include "iboundeddisksource.h"
 #include "iboundedspheresource.h"
 #include "icolorbars.h"
+#include "icommondatadistributors.h"
 #include "idata.h"
+#include "idatahelper.h"
+#include "idatalimits.h"
 #include "ierror.h"
 #include "imarker.h"
 #include "imarkerfamily.h"
@@ -62,14 +64,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-IVIEWSUBJECT_DEFINE_TYPE(iVectorFieldViewSubject,Vector,v);
+IVIEWSUBJECT_DEFINE_TYPE(iVectorFieldViewSubject,VectorField,v);
 
-IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,AttachSourceToMarker,am,OffsetInt,1);  //  for sphere and plane
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,LineDir,ld,Int,1);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,LineLength,ll,Float,1);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,LineQuality,lq,Int,1);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,Method,m,Int,1);
-IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,SourcePositionToPickedPoint,s2p,Bool,1); // action key
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,SourceDirection,sd,Float,3);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,SourceOpacity,so,Float,1);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,NumberOfStreamLines,nl,Int,1);
@@ -80,28 +80,33 @@ IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,TubeSize,ts,Int,1);
 IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,TubeVariationFactor,tv,Float,1);
 
 IOBJECT_DEFINE_DISTANCE_KEY(iVectorFieldViewSubject,SourceSize,ss);
-IOBJECT_DEFINE_POSITION_KEY(iVectorFieldViewSubject,SourcePosition,sx);
 
 //
 //  Inherited keys
 //
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COMMON(iVectorFieldViewSubject);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iVectorFieldViewSubject);
+IVIEWSUBJECT_DEFINE_INHERITED_KEYS_POSITION(iVectorFieldViewSubject);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_COLOR(iVectorFieldViewSubject,2);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_OPACITY(iVectorFieldViewSubject,2);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_PALETTE(iVectorFieldViewSubject,2);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_FIELD(iVectorFieldViewSubject);
 
 
+#ifdef IOBJECT_BACKWARD_COMPATIBLE
+IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,AttachSourceToMarker,-am,OffsetInt,1);
+IOBJECT_DEFINE_KEY(iVectorFieldViewSubject,SourcePositionToPickedPoint,-p2p,Bool,1);
+IOBJECT_DEFINE_POSITION_KEY(iVectorFieldViewSubject,SourcePosition,-sx);
+#endif
+
+
 //
 // iVectorFieldViewSubject class
 //
-iVectorFieldViewSubject::iVectorFieldViewSubject(iViewModule *vm, const iDataType &type, const iString &name) : iFieldViewSubject(vm,type,name,2,1U,_ViewSubjectAlwaysShaded), mSourceSize(vm,true), mSourcePos(vm)
+iVectorFieldViewSubject::iVectorFieldViewSubject(iViewModule *vm, const iDataType &type, const iDataType &scalarType, const iString &name) : iFieldViewSubject(vm,type,scalarType,name,2,_ViewSubjectAlwaysShaded|_ViewSubjectHasPosition), mSourceSize(vm,true)
 {
 	mObjectType = _ObjectTypeVectorField;
 
-	this->AddSecondaryDataType(iData::UniformScalars());
-
 	mMethod = _VectorMethodGlyph;
 	mLineQuality = 0;
 	mLineLength = 1.0;
@@ -261,11 +266,9 @@ void iVectorFieldViewSubject::UpdateAfterMarkerMove()
 
 		this->Pipeline(1)->GetInput()->Modified();
 	}
-	else if(mAttachedMarker != 0)
+	else
 	{
-		mSourcePos = mAttachedMarker->GetPosition();
-		this->UpdateStreamLineSource();
-		this->ClearCache();
+		this->iFieldViewSubject::UpdateAfterMarkerMove();
 	}
 }
 
@@ -291,12 +294,12 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 			n = mNumLines;
 			if(n < 1) return;
 
-			mSourceDisk->SetCenter(mSourcePos);
+			mSourceDisk->SetCenter(mPosition);
 			mSourceDisk->SetNormal(mSourceDir);
 			mSourceDisk->SetRadius(mSourceSize);
-			mSourcePlane->SetCenter(mSourcePos);
+			mSourcePlane->SetCenter(mPosition);
 			mSourcePlane->SetNormal(mSourceDir);
-			mSourceSphere->SetCenter(mSourcePos);
+			mSourceSphere->SetCenter(mPosition);
 			mSourceSphere->SetRadius(mSourceSize);
 
 			if(mStreamLineSourcePoints->GetNumberOfPoints() != n)
@@ -333,7 +336,7 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 			rf = 1.0;
 			double sz = mSourceSize;
 			double pos[3];
-			for(i=0; i<3; i++) pos[i] = mSourcePos[i];
+			for(i=0; i<3; i++) pos[i] = mPosition[i];
 
 			while(l < n)
 			{
@@ -410,7 +413,7 @@ void iVectorFieldViewSubject::UpdateStreamLineSource()
 #ifdef I_CHECK1
 					IERROR_REPORT_BUG;
 #endif
-					for(i=0; i<3; i++) x[i] = mSourcePos[i];
+					for(i=0; i<3; i++) x[i] = mPosition[i];
 				}
 
 				k = 0;
@@ -654,10 +657,8 @@ void iVectorFieldViewSubject::FieldViewSubjectPackStateBody(iString &s) const
 	this->PackValue(s,KeySourceType(),mSourceType);
 	this->PackValue(s,KeyNumberOfStreamLines(),mNumLines);
 	this->PackValue(s,KeySourceDirection(),mSourceDir,3);
-	this->PackValue(s,KeyAttachSourceToMarker(),mAttachedMarkerIndex);  //  for sphere and plane
 
 	this->PackValueDistance(s,KeySourceSize(),mSourceSize);
-	this->PackValuePosition(s,KeySourcePosition(),mSourcePos);
 }
 
 
@@ -680,14 +681,19 @@ void iVectorFieldViewSubject::FieldViewSubjectUnPackStateBody(const iString &s)
 	for(i=0; i<3; i++) fv[i] = mSourceDir[i];
 	if(this->UnPackValue(s,KeySourceDirection(),fv,3)) this->SetSourceDirection(fv);
 
-	if(this->UnPackValue(s,KeyAttachSourceToMarker(),i)) this->SetAttachSourceToMarker(i);  //  for sphere and plane
-
 	if(this->UnPackValueDistance(s,KeySourceSize(),mSourceSize)) this->SetSourceSize(mSourceSize);
-	if(this->UnPackValuePosition(s,KeySourcePosition(),mSourcePos)) this->SetSourcePosition(mSourcePos);
+
+#ifdef IOBJECT_BACKWARD_COMPATIBLE
+	iObject::ReportMissingKeys(false);
+ 	if(this->UnPackValue(s,KeyAttachSourceToMarker(),i)) this->AttachToMarker(i);
+	if(this->UnPackValuePosition(s,KeySourcePosition(),mPosition)) this->SetPosition(mPosition);
+	if(this->UnPackValue(s,KeySourcePositionToPickedPoint(),b) && b) this->SetPosition(_LocationPickedPoint); 
+	iObject::ReportMissingKeys(true);
+#endif
 }
 
 
-void iVectorFieldViewSubject::UpdateAfterMarkerAdd(iMarker *)
+void iVectorFieldViewSubject::UpdateAfterMarkerAdd(iMarker * )
 {
 	this->UpdateAfterMarkerMove();
 }
@@ -706,6 +712,15 @@ int iVectorFieldViewSubject::GetDataOffset() const
 }
 
 
+bool iVectorFieldViewSubject::CanBeShown() const
+{
+	iDataHelper *h = this->CreateDataHelper(this->GetData());
+	bool ret = (h->IsThereVectorData() && this->GetDataOffset()>=0 && this->GetDataOffset()<this->GetLimits()->GetNumVars());
+	delete h;
+	return ret;
+}
+
+
 void iVectorFieldViewSubject::SetSourceSize(const iDistance &s)
 {
 	if(s < 1.0)
@@ -717,25 +732,10 @@ void iVectorFieldViewSubject::SetSourceSize(const iDistance &s)
 }
 	
 
-void iVectorFieldViewSubject::DetachFromMarker()
+void iVectorFieldViewSubject::UpdatePosition(const iPosition &)
 {
-	if(mAttachedMarker != 0)
-	{
-		mAttachedMarker->DetachViewSubject(this);
-		mAttachedMarker = 0;
-		mAttachedMarkerIndex = -1;
-	}
-}
-
-
-void iVectorFieldViewSubject::SetSourcePosition(const iPosition &pos)
-{
-	this->DetachFromMarker();
-
-	mSourcePos = pos;
-	mSourcePos.CutToBounds();
+	mPosition.CutToBounds();
 	this->UpdateStreamLineSource();
-	this->ClearCache();
 }
 
 
@@ -748,38 +748,6 @@ void iVectorFieldViewSubject::SetSourceDirection(const float n[3])
 }
 
 
-void iVectorFieldViewSubject::SetAttachSourceToMarker(int m)
-{
-	int i;
-
-	this->DetachFromMarker();
-
-	if(m>=0 && m<=this->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex())
-	{
-		mAttachedMarkerIndex = m;
-		mAttachedMarker = this->GetViewModule()->GetMarkerFamily()->GetMember(mAttachedMarkerIndex);
-		mAttachedMarker->AttachViewSubject(this);
-
-		for(i=0; i<3; i++) mSourcePos[i] = mAttachedMarker->GetPosition()[i];
-		this->UpdateStreamLineSource();
-		this->ClearCache();
-	}
-}
-
-
-void iVectorFieldViewSubject::SetSourcePositionToPickedPoint()
-{
-	int i;
-	double *x = this->GetViewModule()->GetPicker()->GetPickPosition();
-
-	this->DetachFromMarker();
-
-	for(i=0; i<3; i++) mSourcePos[i] = x[i];
-	this->UpdateStreamLineSource();
-	this->ClearCache();
-}
-
-
 void iVectorFieldViewSubject::FieldViewSubjectSyncWithData(const iDataSyncRequest &)
 {
 	this->UpdatePipelines();
@@ -799,7 +767,7 @@ iViewSubjectPipeline* iVectorFieldViewSubject::CreatePipeline(int id)
 
 void iVectorFieldViewSubject::ConfigureMainPipeline(iViewSubjectPipeline *p, int id)
 {
-	iViewSubjectParallelPipeline *pp = iPointerCast<iViewSubjectParallelPipeline,iViewSubjectPipeline>(p);
+	iViewSubjectParallelPipeline *pp = iRequiredCast<iViewSubjectParallelPipeline>(INFO,p);
 
 	switch(id)
 	{
