@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iVectorGlyphFilter : public iGenericFilter<vtkHedgeHog,vtkDataSet,vtkPolyData>
 {
 
-	IGENERICFILTER_DECLARE(iVectorGlyphFilter);
+	IGENERICFILTER_DECLARE(iVectorGlyphFilter,vtkHedgeHog);
 
 protected:
 	
