@@ -337,6 +337,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 
 	mCameraOrthoActor = iCameraOrthoActor::New(mRenderTool);
 	mCameraOrthoActor->PickableOff();
+	mCameraOrthoActor->SetVisibility(0);
 
 	mRenderTool->AddObject(mCameraOrthoActor);
 
@@ -657,6 +658,8 @@ bool iViewModule::BecomeClone(iViewModule *v)
 	int i;
 	bool ret = true;
 
+	if(v == this) return true;
+
 	if(v == 0)
 	{
 		//
@@ -740,6 +743,42 @@ bool iViewModule::BecomeClone(iViewModule *v)
 }
 
 
+void iViewModule::CopySettings(iViewModule *v)
+{
+	if(v==0 || v==this) return;
+
+	//
+	//  Copy Reader state
+	//
+	mDataReader->CopyState(v->mDataReader);
+
+	//
+	//  Copy iViewSubject families
+	//
+	mMarkerFamily->Copy(v->mMarkerFamily);
+
+	int i;
+	for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->Copy(v->mViewObjectFamilies[i]);
+
+	//
+	//  Copy Animator state
+	//
+	mAnimator->CopyState(v->mAnimator);
+
+	//
+	//  Copy camera state
+	//
+	mRenderTool->GetCamera()->CopyState(v->mRenderTool->GetCamera());
+
+	//
+	//  Copy self
+	//
+	this->CopyState(v);
+
+	this->ClearCache();
+}
+
+
 void iViewModule::SetDebugMode(bool s)
 {
 	int i;
