@@ -32,7 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idata.h"
 #include "idatareader.h"
 #include "ierror.h"
-#include "iextensionfactory.h"
+#include "iobjectfactory.h"
 #include "iviewmodule.h"
 #include "iviewsubject.h"
 
@@ -44,11 +44,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iViewObject* iViewObject::New(iViewObjectParent *parent)
 {
-	return iExtensionFactory::CreateViewObject(parent);
+	IERROR_ASSERT(parent);
+	return iObjectFactory::CreateViewObject(parent);
 }
 
 
-iViewObject::iViewObject(iViewObjectParent *parent, bool synced, bool single) : iMultiTypeDataConsumer(parent->GetViewModule(),iData::UniformScalars()), mSubjects(0)
+iViewObject::iViewObject(iViewObjectParent *parent, bool synced, bool single) : iObject(parent?parent->GetObjectType().FullName():""), iMultiTypeDataConsumer(parent->GetViewModule(),iDataType::Null())
 {
 	mParent = parent; IERROR_ASSERT(parent);
 	mIsSynced = synced;
@@ -72,7 +73,7 @@ void iViewObject::AddSubject(iViewSubject *subject)
 		*mPrimaryDataInfo += subject->GetDataType();
 		if(!mParent->GetDataType().IsNull() && mParent->GetDataType()!=mPrimaryDataInfo->Type(0))
 		{
-			IERROR_FINISH("Incorrectly configured iViewObject.");
+			IERROR_FATAL("Incorrectly configured iViewObject.");
 		}
 	}
 	else
@@ -86,7 +87,7 @@ void iViewObject::Verify()
 {
 	if(mSubjects.Size() == 0)
 	{
-		IERROR_FINISH("Incorrectly configured iViewObject.");
+		IERROR_FATAL("Incorrectly configured iViewObject.");
 	}
 }
 
@@ -100,13 +101,13 @@ iViewObject::~iViewObject()
 iViewSubject* iViewObject::GetViewSubject(int obs) const
 {
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 
 	if(obs == -1) obs = mActiveDataTypeIndex;
 	if(obs>=0 && obs<mSubjects.Size()) return mSubjects[obs]; else
 	{
-		IERROR_FINISH("Requesting non-existing ViewSubject.");
+		IERROR_FATAL("Requesting non-existing ViewSubject.");
 		return 0;
 	}
 }
@@ -125,7 +126,7 @@ void iViewObject::Show(bool s)
 	int i;
 
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 
 	if(mIsSingle) for(i=0; i<mSubjects.Size(); i++) mSubjects[i]->Show(false);
@@ -161,7 +162,7 @@ float iViewObject::GetMemorySize() const
 void iViewObject::PackStateBody(iString &s) const
 {
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 	this->PackValue(s,iViewSubject::KeyDataType(),mActiveDataTypeIndex);
 
@@ -174,7 +175,7 @@ void iViewObject::UnPackStateBody(const iString &s)
 	int i;
 
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 	if(this->UnPackValue(s,iViewSubject::KeyDataType(),i)) this->SetActiveDataTypeIndex(i);
 
@@ -200,7 +201,7 @@ void iViewObject::PackCompleteState(iString &s) const
 	iString s1;
 
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 	s.Init(10000);
 	this->PackValue(s,iViewSubject::KeyDataType(),mActiveDataTypeIndex);
@@ -224,7 +225,7 @@ void iViewObject::UnPackCompleteState(const iString &s)
 	iString s1, name;
 
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 	if(this->UnPackValue(s,iViewSubject::KeyDataType(),i)) this->SetActiveDataTypeIndex(i);
 
@@ -247,7 +248,7 @@ void iViewObject::UnPackCompleteState(const iString &s)
 void iViewObject::UpdateDataType(int prev)
 {
 #ifdef I_CHECK1
-	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FINISH("iViewObject is misconfigured.");
+	if(mActiveDataTypeIndex<0 || mActiveDataTypeIndex>mSubjects.MaxIndex()) IERROR_FATAL("iViewObject is misconfigured.");
 #endif
 
 	if(this->mIsSingle)
@@ -258,7 +259,7 @@ void iViewObject::UpdateDataType(int prev)
 			vis = mSubjects[prev]->IsVisible();
 			mSubjects[prev]->Show(false);
 		}
-		else IERROR_REPORT("Invalid previous data type index. Hiding the object.");
+		else IERROR_LOW("Invalid previous data type index. Hiding the object.");
 		mSubjects[mActiveDataTypeIndex]->Show(vis);
 	}
 	this->ClearCache();
@@ -271,7 +272,7 @@ void iViewObject::SyncWithDataBody(const iDataSyncRequest &r)
 	//
 	//  If we are not visible, automatically switch to the first data type that has data
 	//
-	if(!this->GetViewSubject()->IsVisible() && !this->GetViewSubject()->IsDataPresent())
+	if(!this->GetViewSubject()->IsVisible() && !this->GetViewSubject()->IsThereData())
 	{
 		int i;
 		for(i=0; i<mPrimaryDataInfo->Count(); i++)
