@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "icamera.h"
+#include "idata.h"
 #include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
@@ -290,6 +291,7 @@ void iViewSubject::PackStateBody(iString &s) const
 	}
 	this->PackValue(s,KeyVisible(),this->IsVisible());
 	this->PackValue(s,KeyDataPresent(),this->IsThereData());
+	//this->PackValue(s,KeyDataType(),this->GetDataType().GetId());
 	this->PackValue(s,KeyReady(),this->IsReady());
 
 	this->ViewSubjectPackStateBody(s);
