@@ -42,7 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iVolumeDataConverter : public iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>, protected iParallelWorker
 {
 
-	IGENERICFILTER_DECLARE(iVolumeDataConverter);
+	IGENERICFILTER_DECLARE(iVolumeDataConverter,vtkStructuredPointsToStructuredPointsFilter);
 
 public:
 
@@ -55,7 +55,9 @@ protected:
 	
 	virtual void ProduceOutput();
 	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
-	
+
+private:
+
 	int mCurVar;
 
 	//
