@@ -497,7 +497,7 @@ iVolumeViewSubject::iVolumeViewSubject(iViewModule *vm, const iDataType &type, c
 	//
 	mVolume->AddObserver(vtkCommand::UserEvent,mObjectObserver);
 
-	mVolume->SetVisibility(false);
+	mVolume->SetVisibility(0);
 	this->GetViewModule()->AddObject(mVolume);
 }
 
@@ -560,8 +560,7 @@ void iVolumeViewSubject::Reset()
 	if(mIsInitialized)
 	{
 		this->ShowColorBars(false);
-		mVolume->SetVisibility(false);
-		this->GetViewModule()->RemoveObject(mVolume);
+		mVolume->SetVisibility(0);
 		mIsInitialized = false;
 	}
 }
@@ -651,13 +650,13 @@ void iVolumeViewSubject::ShowBody(bool show)
 {
 	if(show)
 	{
-		mVolume->SetVisibility(true);
+		mVolume->SetVisibility(1);
 		this->ShowColorBars(true);
 	} 
 	else 
 	{
 		this->ShowColorBars(false);
-		mVolume->SetVisibility(false);
+		mVolume->SetVisibility(0);
 	}
 }
 
@@ -871,7 +870,7 @@ void iVolumeViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &)
 		vtkImageData *id = vtkImageData::SafeDownCast(this->GetData());
 	 	if(id != 0)
 		{
-			mDataConverter->SetInput(vtkImageData::SafeDownCast(this->GetData()));
+			mDataConverter->SetInput(id);
 
 			double s = id->GetSpacing()[2];
 			for(i=0; i<mHelpers.Size(); i++)
@@ -881,7 +880,7 @@ void iVolumeViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &)
 		}
 
 		//
-		//  Reset inout
+		//  Reset input
 		//
 		for(i=0; i<mHelpers.Size(); i++) if(mHelpers[i]->IsAttachedDirectly())
 		{
