@@ -29,10 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iwriter.h"
 
 
+#include "icommoneventobservers.h"
 #include "icontrolmodule.h"
 #include "ierror.h"
-#include "ieventobserver.h"
 #include "ipostscriptwriter.h"
+#include "ishell.h"
 #include "iviewmodule.h"
 #include "ivtk.h"
 
@@ -43,14 +44,24 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkPNMWriter.h>
 #include <vtkTIFFWriter.h>
 
-class vtkGenericMovieWriter;
 #ifndef IVTK_4
+
+#include "vtkGenericMovieWriter.h"
+
 #ifdef IVTK_SUPPORTS_AVI
 #include <vtkAVIWriter.h>
 #endif
+
+#ifdef IVTK_SUPPORTS_MPEG
 #include <vtkMPEG2Writer.h>
 #endif
 
+#else
+
+class vtkGenericMovieWriter;
+
+#endif
+
 //
 //  Templates
 //
@@ -72,11 +83,15 @@ iString iWriter::mCurrentAnimationImageFilePrefix = "ifrit-an";
 //
 //  Helper class
 //
-class iGenericMultiImageMovieWriter : public iViewModuleComponent, public iDeletable
+class iGenericMultiImageMovieWriter : public vtkObjectBase
 {
 
+	IPOINTER_AS_PART(ViewModule);
+
 public:
 
+	vtkTypeMacro(iGenericMultiImageMovieWriter,vtkObjectBase);
+
 	void Start()
 	{
 		mStarted = true;
@@ -94,7 +109,7 @@ public:
 			mImageWriters[i]->End();
 			if(mImageWriters[i]->GetError() != 0)
 			{
-				IERROR_REPORT("Unable to write a movie file: different frames have varied number of images");
+				IERROR_LOW("Unable to write a movie file: different frames have varied number of images");
 				return;
 			}
 		}
@@ -104,8 +119,9 @@ public:
 
 protected:
 
-	iGenericMultiImageMovieWriter(iViewModule *vm) : iViewModuleComponent(vm), mImageWriters(0)
+	iGenericMultiImageMovieWriter(iViewModule *vm) : mViewModule(vm)
 	{
+		IERROR_ASSERT(vm);
 		mStarted = false;
 	}
 
@@ -116,10 +132,8 @@ protected:
 #endif
 	}
 
-#ifndef IVTK_4
 	virtual vtkGenericMovieWriter* CreateWriter() const = 0;  // factory method
 	virtual const iString& GetFileSuffix() const = 0;
-#endif
 
 	bool mStarted;
 	iArray<vtkGenericMovieWriter*> mImageWriters;
@@ -128,7 +142,6 @@ protected:
 
 namespace iWriter_Private
 {
-#ifndef IVTK_4
 	template <class T>
 	class MultiImageMovieWriter : public iGenericMultiImageMovieWriter
 	{
@@ -159,7 +172,6 @@ namespace iWriter_Private
 
 		iString mSuffix;
 	};
-#endif
 
 
 	iString FrameFileName(int i, const iString &tag, const iString &root)
@@ -200,10 +212,6 @@ using namespace iWriter_Private;
 
 void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images, const iString &path, const iString &root)
 {
-#ifndef IVTK_4
-	int i;
-#endif
-
 	if(mStarted)
 	{
 #ifndef IVTK_4
@@ -217,6 +225,7 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 			mImageWriters.Add(tmp);
 		}
 
+		int i;
 		iString name;
 		for(i=0; i<mImageWriters.Size(); i+=2)
 		{
@@ -245,26 +254,29 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 #ifndef IVTK_4
 	if(!mStarted && 2*images.Size()!=mImageWriters.Size())
 	{
-		IERROR_REPORT("Unable to write a movie file: different frames have varied number of images.");
+		IERROR_LOW("Unable to write a movie file: different frames have varied number of images.");
 		return;
 	}
 
+	int i;
 	for(i=0; i<mImageWriters.Size(); i+=2)
 	{
 		mImageWriters[i]->SetInput(images[i/2].LeftEye().DataObject());
 		mImageWriters[i]->Write();
+		mImageWriters[i]->SetInput(0);
 		if(mImageWriters[i]->GetError() != 0)
 		{
-			IERROR_REPORT("Unable to write a movie file: VTK reported an unidentified error.");
+			IERROR_LOW("Unable to write a movie file: VTK reported an unidentified error.");
 			return;
 		}
 		if(images[i/2].IsStereo())
 		{
 			mImageWriters[i+1]->SetInput(images[i/2].RightEye().DataObject());
 			mImageWriters[i+1]->Write();
+			mImageWriters[i+1]->SetInput(0);
 			if(mImageWriters[i+1]->GetError() != 0)
 			{
-				IERROR_REPORT("Unable to write a movie file: VTK reported an unidentified error.");
+				IERROR_LOW("Unable to write a movie file: VTK reported an unidentified error.");
 				return;
 			}
 		}
@@ -278,11 +290,12 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 //
 iWriter* iWriter::New(iViewModule *vm)
 {
+	IERROR_ASSERT(vm);
 	return new iWriter(vm);
 }
 
 
-iWriter::iWriter(iViewModule *vm) : iViewModuleComponent(vm)
+iWriter::iWriter(iViewModule *vm) : mViewModule(vm)
 {
 	mPostScriptPaperFormat = 9;
 	mPostScriptOrientation = 0;
@@ -370,11 +383,13 @@ void iWriter::SetAnimationOutput(int i)
 		}
 		switch(mAnimationOutput)
 		{
+#ifdef IVTK_SUPPORTS_MPEG
 		case _AnimationOutputMPEG2:
 			{
 				mMovieWriter = MultiImageMovieWriter<vtkMPEG2Writer>::New(this->GetViewModule(),"mpg"); IERROR_ASSERT(mMovieWriter);
 				break;
 			}
+#endif
 #ifdef IVTK_SUPPORTS_AVI
 		case _AnimationOutputAVI:
 			{
@@ -402,7 +417,7 @@ void iWriter::SetPostScriptPaperFormat(int i)
 	{
 		mPostScriptPaperFormat = i;
 		this->GetViewModule()->ClearCache();
-		if(mImageFormat == _ImageFormatEPS) iPointerCast<iPostScriptWriter,vtkImageWriter>(mImageWriter)->SetPaperFormat(i);
+		if(mImageFormat == _ImageFormatEPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetPaperFormat(i);
 	}
 }
 
@@ -413,7 +428,7 @@ void iWriter::SetPostScriptOrientation(int i)
 	{
 		mPostScriptOrientation = i;	
 		this->GetViewModule()->ClearCache();
-		if(mImageFormat == _ImageFormatEPS) iPointerCast<iPostScriptWriter,vtkImageWriter>(mImageWriter)->SetOrientation(i);
+		if(mImageFormat == _ImageFormatEPS) iRequiredCast<iPostScriptWriter>(INFO,mImageWriter)->SetOrientation(i);
 	}
 }
 
@@ -458,12 +473,12 @@ void iWriter::WriteFrame(const iStereoImageArray& images, int mode)
 		}
 	default:
 		{
-			IERROR_REPORT("Invalid argument to iWriter::WriteFrame.");
+			IERROR_LOW("Invalid argument to iWriter::WriteFrame.");
 			return;
 		}
 	}
 
-	path = this->GetViewModule()->GetControlModule()->GetFileName(_EnvironmentImage,"");
+	path = this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(_EnvironmentImage);
 	root += iString::FromNumber(*cur,"-%05d");
 
 	if(mode==_ImageTypeSnapshot || mMovieWriter==0)
@@ -524,7 +539,7 @@ void iWriter::WriteMovieFrame(const iStereoImageArray& images, const iString &pa
 	}
 	else
 	{
-		IERROR_REPORT("Cannot write a movie file: a MovieWriter has not been created.");
+		IERROR_LOW("Cannot write a movie file: a MovieWriter has not been created.");
 	}
 }
 
