@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgdialogsubject.h"
 
 
@@ -54,3 +58,5 @@ void ibgDialogSubject::OnClose()
 {
 	mOwner->Close();
 }
+
+#endif
