@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgframesubject.h"
 
 
@@ -77,3 +81,4 @@ ibgFrameScrollSubject::ibgFrameScrollSubject(iggFrameScroll *owner, bool) : ibgW
 {
 }
 
+#endif
