@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgmainwindowsubject.h"
 
 
@@ -46,3 +50,5 @@ ibgMainWindowSubject::ibgMainWindowSubject(iggMainWindow *owner)
 ibgMainWindowSubject::~ibgMainWindowSubject()
 {
 }
+
+#endif
