@@ -43,6 +43,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggshell.h"
 
 
+bool ibgRenderWindowSubject::RenderOnFocus = false;
+
+
 ibgRenderWindowSubject::ibgRenderWindowSubject(iggRenderWindow *owner) : ibgWindowSubject(owner?owner->GetViewModule()->GetControlModule()->GetShell():0)
 {
 	mOwner = owner; IERROR_ASSERT(owner);
@@ -55,6 +58,13 @@ ibgRenderWindowSubject::~ibgRenderWindowSubject()
 }
 
 
+void ibgRenderWindowSubject::Render()
+{
+	if(RenderOnFocus || !mOwner->IsInitialized()) return;
+	mOwner->Render();
+}
+
+
 void ibgRenderWindowSubject::OnMouseMoveBody(int x, int y, int b) 
 {
 	if(!this->IsBlocked() && this->IsInteractorPresent())	mInteractor->OnMouseMove(x,y,b);
@@ -87,9 +97,17 @@ void ibgRenderWindowSubject::OnTimerBody()
 
 void ibgRenderWindowSubject::OnWindowFocusInBody()
 {
-	if(!this->IsBlocked() && mOwner->GetMainWindow()!=0)
+	if(!this->IsBlocked())
 	{
-		mOwner->GetMainWindow()->OnRenderWindowFocusIn(mOwner->GetViewModule()->GetWindowNumber());
+		if(RenderOnFocus)
+		{
+			mOwner->Render();
+		}
+
+		if(mOwner->GetMainWindow()!=0)
+		{
+			mOwner->GetMainWindow()->OnRenderWindowFocusIn(mOwner->GetViewModule()->GetWindowNumber());
+		}
 	}
 }
 
