@@ -43,6 +43,10 @@ class ibgRenderWindowSubject : public ibgWindowSubject
 	friend class iggRenderWindow;
 	friend class iggRenderWindowInteractor;
 
+public:
+
+	static bool RenderOnFocus;
+
 protected:
 
 	ibgRenderWindowSubject(iggRenderWindow *owner);
@@ -52,7 +56,6 @@ protected:
 	//  RenderWindow methods
 	//
 	virtual void Initialize(bool show) = 0;
-	virtual void Render() = 0;
 	virtual void SwapBuffers() = 0;
 
 	virtual void SetBorder(bool) = 0;
@@ -65,6 +68,11 @@ protected:
 	virtual void RenderIntoMemory(iImage &) = 0;
 	virtual bool IsReadyForDumpingImage() = 0;
 
+	//
+	//  Render the scene
+	//
+	void Render();
+
 	//
 	//  RenderWindowInteractor methods
 	//
