@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgwidgetareasubject.h"
 
 
@@ -170,3 +174,4 @@ void ibgWidgetDrawAreaSubject::Paint()
 	mInPaint = false;
 }
 
+#endif
