@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "ibgwidgetselectionboxsubject.h"
 
 
@@ -96,3 +100,4 @@ ibgWidgetRadioBoxSubject::~ibgWidgetRadioBoxSubject()
 {
 }
 
+#endif
