@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_CL)
+
+
 #include "iclcommandinterpreter.h"
 
 
@@ -126,3 +130,4 @@ void iclCommandInterpreter::CheckBreak()
 	//
 }
 
+#endif
