@@ -26,21 +26,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_CL)
+
+
 #include "iclcontrolscript.h"
 
 
 #include "ihelpfactory.h"
 #include "istring.h"
 
-#include <vtkIOStream.h>
-
-#include <stdio.h>
-
-//
-//  macros
-//
-#include "ibasescriptmacro.h"
-
 
 #ifndef I_NO_CONSOLEIO
 #ifdef _WIN32
@@ -67,7 +62,7 @@ iclControlScript::~iclControlScript()
 //
 //  Own console functions
 //
-void iclControlScript::OutputText(const iString &s0)
+void iclControlScript::OutputText(const iString &s0) const
 {
 	//
 	//  Help is kept in HTML format. Strip formatting first.
@@ -100,7 +95,7 @@ void iclControlScript::OutputText(const iString &s0)
 	}
 }
 
-void iclControlScript::OutputError(const iString &s0)
+void iclControlScript::OutputError(const iString &s0) const
 {
 	//
 	//  Help is kept in HTML format. Strip formatting first.
@@ -127,3 +122,5 @@ const iString& iclControlScript::GetHelpString(_HelpId id) const
 
 	if(id == _Root) return s0; else return iControlScript::GetHelpString(id);
 }
+
+#endif
