@@ -55,8 +55,8 @@ protected:
 	//
 	//  Own console functions for re-directing the output into special windows
 	//
-	virtual void OutputText(const iString &s);
-	virtual void OutputError(const iString &s);
+	virtual void OutputText(const iString &s) const;
+	virtual void OutputError(const iString &s) const;
 };
 
 #endif // ICLCONTROLCRIPT_H
