@@ -29,10 +29,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iconfigure.h"
 
 
+#include "icontrolmodule.h"
 #include "ierror.h"
 #include "ishell.h"
 #include "istring.h"
-
+#include "iviewmodule.h"
 
 #if defined(ISHELL)
 
@@ -143,14 +144,14 @@ ibgDialogSubject* iggSubjectFactory::CreateDialogSubject(iggDialog *owner, const
 }
 
 
-ibgExtensionWindowSubject* iggSubjectFactory::CreateExtensionWindowSubject(iggExtensionWindow *owner, bool single)
+ibgExtensionWindowSubject* iggSubjectFactory::CreateExtensionWindowSubject(iggExtensionWindow *owner)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		return new iqtExtensionWindowSubject(owner,single);
+		return new iqtExtensionWindowSubject(owner);
 #else
 		return 0;
 #endif
@@ -159,7 +160,7 @@ ibgExtensionWindowSubject* iggSubjectFactory::CreateExtensionWindowSubject(iggEx
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		return new ifxExtensionWindowSubject(owner,single);
+		return new ifxExtensionWindowSubject(owner);
 #else
 		return 0;
 #endif
@@ -195,14 +196,14 @@ ibgFrameSubject* iggSubjectFactory::CreateFrameSubject(iggFrame *owner, int cols
 }
 
 
-ibgFrameBookSubject* iggSubjectFactory::CreateFrameBookSubject(iggFrameBook *owner, bool withFeedback)
+ibgFrameBookSubject* iggSubjectFactory::CreateFrameBookSubject(iggFrameBook *owner, bool withFeedback, bool tabsOnTop)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT1(qt,FrameBook,withFeedback);
+		RETURN_SUBJECT2(qt,FrameBook,withFeedback,tabsOnTop);
 #else
 		return 0;
 #endif
@@ -211,7 +212,7 @@ ibgFrameBookSubject* iggSubjectFactory::CreateFrameBookSubject(iggFrameBook *own
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,FrameBook,withFeedback);
+		RETURN_SUBJECT2(fx,FrameBook,withFeedback,tabsOnTop);
 #else
 		return 0;
 #endif
@@ -247,14 +248,14 @@ ibgFrameFlipSubject* iggSubjectFactory::CreateFrameFlipSubject(iggFrameFlip *own
 }
 
 
-ibgFrameScrollSubject* iggSubjectFactory::CreateFrameScrollSubject(iggFrameScroll *owner, bool withHor)
+ibgFrameScrollSubject* iggSubjectFactory::CreateFrameScrollSubject(iggFrameScroll *owner, bool withHor, bool withVer)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT1(qt,FrameScroll,withHor);
+		RETURN_SUBJECT2(qt,FrameScroll,withHor,withVer);
 #else
 		return 0;
 #endif
@@ -263,7 +264,7 @@ ibgFrameScrollSubject* iggSubjectFactory::CreateFrameScrollSubject(iggFrameScrol
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,FrameScroll,withHor);
+		RETURN_SUBJECT2(fx,FrameScroll,withHor,withVer);
 #else
 		return 0;
 #endif
@@ -331,9 +332,9 @@ ibgMenuWindowSubject* iggSubjectFactory::CreateMenuWindowSubject(iggMenuWindow *
 
 ibgRenderWindowSubject* iggSubjectFactory::CreateRenderWindowSubject(iggRenderWindow *owner)
 {
-	if(owner->GetShell() == 0) return 0;
+	if(owner->GetViewModule()->GetControlModule()->GetShell() == 0) return 0;
 
-	if(owner->GetShell()->Type() == qt)
+	if(owner->GetViewModule()->GetControlModule()->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
 		return new iqtRenderWindowSubject(owner);
@@ -342,7 +343,7 @@ ibgRenderWindowSubject* iggSubjectFactory::CreateRenderWindowSubject(iggRenderWi
 #endif
 	}
 	
-	if(owner->GetShell()->Type() == fx)
+	if(owner->GetViewModule()->GetControlModule()->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
 		return new ifxRenderWindowSubject(owner);
