@@ -48,6 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggextensionwindow.h"
 #include "iggmainwindow.h"
 #include "iggpageobjectextension.h"
+#include "iggshell.h"
 #include "iggwidgetarea.h"
 
 #include "ibgmenuwindowsubject.h"
@@ -92,7 +93,7 @@ void iggExtensionFrameBook::Block(bool s)
 
 void iggExtensionFrameBook::OnInt1Body(int i)
 {
-	if(!mBlocked && i>=0 && i<mPages.Size() && mPages[i].Index>=0)
+	if(!iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iggParameter::_ConditionSlowRemoteConnection) && !mBlocked && i>=0 && i<mPages.Size() && mPages[i].Index>=0)
 	{
 		mBlocked = true; // avoid loops
 		this->GetMainWindow()->OpenBookPage(mPages[i].Index);
