@@ -89,7 +89,7 @@ void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iI
 
 	mMode = mode;
 
-	if(closetext!=0 && (closetext[0]!=0 || !iDynamicCast<iggShell,iShell>(INFO,this->GetShell())->IsWindowManagerModern()))
+	if(closetext!=0 && (closetext[0]!=0 || iDynamicCast<iggShell,iShell>(INFO,this->GetShell())->CheckCondition(iggParameter::_ConditionOldWindowManager)))
 	{
 		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_ASSERT(tmp);
 		mSubject->SetFrame(tmp->GetSubject());
