@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogdataexplorer.h"
 
 
@@ -1333,3 +1337,4 @@ void iggDialogDataExplorer::ShowFractionInfo(bool s)
 	mFlashFrame->ShowLayer(s?1:0);
 }
 
+#endif
