@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogimagecomposer.h"
 
 
@@ -278,6 +282,7 @@ namespace iggDialogImageComposer_Private
 			//
 			//  Draw
 			//
+			bool needUpdate = false;
 			n = ic->GetNumberOfForegroundWindows();
 			int cfw = mDialog->GetCurrentForegroundWindow();
 			for(i=0; i<n; i++)
@@ -322,10 +327,13 @@ namespace iggDialogImageComposer_Private
 				//
 				if(fw->GetZoomSource() != 0)
 				{
-					int zx = mStartX + round(mScaleFactor*(fw->GetZoomSource()->GetContentsX()+(fw->GetZoomX()-0.5*fw->GetZoomWidth())*fw->GetZoomSource()->GetContentsWidth()));
-					int zy = mStartY + round(mScaleFactor*(fw->GetZoomSource()->GetContentsY()+(fw->GetZoomY()-0.5*fw->GetZoomHeight())*fw->GetZoomSource()->GetContentsHeight()));
-					int zw = round(mScaleFactor*fw->GetZoomWidth()*fw->GetZoomSource()->GetContentsWidth());
-					int zh = round(mScaleFactor*fw->GetZoomHeight()*fw->GetZoomSource()->GetContentsHeight());
+					fw->UpdateWindow();
+					needUpdate = true;
+
+					int zx = mStartX + round(mScaleFactor*(fw->GetZoomSource()->GetContentsX()+(fw->GetZoomX()*fw->GetZoomSource()->GetContentsWidth()-0.5*fw->GetZoomWidth())));
+					int zy = mStartY + round(mScaleFactor*(fw->GetZoomSource()->GetContentsY()+(fw->GetZoomY()*fw->GetZoomSource()->GetContentsHeight()-0.5*fw->GetZoomHeight())));
+					int zw = round(mScaleFactor*fw->GetZoomWidth());
+					int zh = round(mScaleFactor*fw->GetZoomHeight());
 
 					this->DrawWindowBase(zx,zy,zw,zh,iColor::Invalid(),bw,bc);
 
@@ -342,6 +350,8 @@ namespace iggDialogImageComposer_Private
 				this->DrawWindow(x,y,w,h,fw->GetViewModule()->GetBackgroundColor(),bw,bc,v,0,i==mDialog->GetCurrentForegroundWindow());
 			}
 
+			if(needUpdate) mDialog->UpdateZooms();
+
 			if(!ic->IsActive())
 			{
 				w = round(0.9*mSubject->Width());
@@ -631,7 +641,7 @@ namespace iggDialogImageComposer_Private
 
 		ScaleSpinBox(const iObjectKey &key, iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetKeyHandler<float>(_WidgetTypeOther,key,_RenderModeNoRender,parent,0,0)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,10,100,"",10);
+			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,5,100,"",5);
 			mDialog = dialog;
 			this->SetBaloonHelp("Scale foreground window","Use this box to scale the image of the foreground window in the composed final image. The window size on the screen will not be changed, only the image of it will.");
 		}
@@ -808,6 +818,59 @@ namespace iggDialogImageComposer_Private
 		ibgWidgetComboBoxSubject *mSubject;
 		iggDialogImageComposer *mDialog;
 	};
+
+	//
+	//  update zooms button
+	//
+	class UpdateZoomsButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		UpdateZoomsButton(iggDialogImageComposer *dialog, iggFrame *parent) : iggWidgetSimpleButton("Update",parent)
+		{
+			mDialog = dialog;
+			this->SetBaloonHelp("Update zoom arrangements");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			mDialog->UpdateZooms();
+		}
+
+		iggDialogImageComposer *mDialog;
+	};
+
+	//
+	//  zoom widgets frame
+	//
+	class ZoomWidgetsFrame : public iggFrame
+	{
+
+	public:
+
+		ZoomWidgetsFrame(iggDialogImageComposer *dialog, iggFrame *parent) : iggFrame(parent,2)
+		{
+			mDialog = dialog;
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			iImageComposerForegroundWindow *win = mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow());
+
+			if(win!=0 && win->GetZoomSource()!=0)
+			{
+				win->UpdateWindow();
+				this->Enable(!mDialog->GetImageComposer()->GetForegroundWindow(mDialog->GetCurrentForegroundWindow())->IsAutoZoom());
+			}
+		}
+
+		iggDialogImageComposer *mDialog;
+	};
 };
 
 
@@ -930,19 +993,27 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	wid = new ZoomSourceListComboBox("",this,tmp2);
 	wid->AddDependent(mArea);
 	tmp2->AddLine(new iggWidgetTextArea("Source",tmp2),wid);
-	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),_RenderModeNoRender,tmp2,0);
+
+	iggFrame *tmp3 = new ZoomWidgetsFrame(this,tmp2);
+	mIndexHolders[3] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomX(),_RenderModeNoRender,tmp3,0);
 	mIndexHolders[3]->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Center X",tmp2),mIndexHolders[3]);
-	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),_RenderModeNoRender,tmp2,0);
+	tmp3->AddLine(new iggWidgetTextArea("Center X",tmp3),mIndexHolders[3]);
+	mIndexHolders[4] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomY(),_RenderModeNoRender,tmp3,0);
 	mIndexHolders[4]->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Center Y",tmp2),mIndexHolders[4]);
-	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomHeight(),_RenderModeNoRender,tmp2,0);
+	tmp3->AddLine(new iggWidgetTextArea("Center Y",tmp3),mIndexHolders[4]);
+	mIndexHolders[5] = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,3,"",iImageComposer::KeyForegroundWindowZoomFactor(),_RenderModeNoRender,tmp3,0);
 	mIndexHolders[5]->AddDependent(mArea);
-	tmp2->AddLine(new iggWidgetTextArea("Height",tmp2),mIndexHolders[5]);
+	tmp3->AddLine(new iggWidgetTextArea("Factor",tmp3),mIndexHolders[5]);
+	tmp3->SetColStretch(1,10);
+
+	tmp2->AddLine(tmp3,2);
+
 	mIndexHolders[6] = new iggWidgetKeyCheckBox("Use 4-line zoom",iImageComposer::KeyForegroundWindowZoom4Line(),tmp2,0);
 	mIndexHolders[6]->AddDependent(mArea);
 	tmp2->AddLine(mIndexHolders[6],2);
 
+	tmp2->SetColStretch(1,10);
+
 	b->AddSpace(2);
 	b->AddLine(tmp2,2);
 
@@ -995,8 +1066,22 @@ void iggDialogImageComposer::UpdateView()
 }
 
 
+void iggDialogImageComposer::UpdateZooms()
+{
+	this->GetImageComposer()->ClearCache();
+	this->GetImageComposer()->UpdateWindowList();
+//	this->UpdateDialog();
+	int i;
+	for(i=3; i<mNumIndexHolders; i++)
+	{
+		mIndexHolders[i]->UpdateWidget();
+	}
+}
+
+
 iImageComposer* iggDialogImageComposer::GetImageComposer() const
 {
 	return this->GetShell()->GetControlModule()->GetImageComposer();
 }
 
+#endif
