@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogrenderingprogress.h"
 
 
@@ -183,3 +187,5 @@ bool iggDialogRenderingProgress::CanBeClosed()
 {
 	return false;  // make it non-closeable
 }
+
+#endif
