@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggdialogscriptdebugger.h"
 
 
@@ -37,6 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierrorstatus.h"
 #include "ifile.h"
 #include "iimagefactory.h"
+#include "iscriptkit.h"
 #include "ishell.h"
 #include "iviewmodule.h"
 
@@ -96,7 +101,7 @@ public:
 		int i, n = s->GetNumberOfReservedWords();
 		for(i=0; i<n; i++)
 		{
-			if(s->IsParameterWord(s->GetReservedWord(i)))
+			if(s->IsConstantName(s->GetReservedWord(i)))
 			{
 				mSubject->AddKeyword(s->GetReservedWord(i),1);
 			}
@@ -139,12 +144,19 @@ public:
 
 	void ShowError(iAnimatorScript *s)
 	{
-		mSubject->Select(s->GetCurrentLine(),s->GetErrorLocation(),s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
+		mSubject->Select(s->GetThisLine(),s->GetErrorPosition(),s->GetThisLine(),mSubject->GetLine(s->GetThisLine()).Length());
 	}
 
-	void ShowLine(bool before, iAnimatorScript *s)
+	void MarkLine(iAnimatorScript *s)
 	{
-		if(before == mMarkBefore) mSubject->Select(s->GetCurrentLine(),0,s->GetCurrentLine(),mSubject->GetLine(s->GetCurrentLine()).Length());
+		if(mMarkBefore)
+		{
+			mSubject->Select(s->GetNextLine(),0,s->GetNextLine(),mSubject->GetLine(s->GetNextLine()).Length());
+		}
+		else
+		{
+            mSubject->Select(s->GetThisLine(),0,s->GetThisLine(),mSubject->GetLine(s->GetThisLine()).Length());
+		}
 	}
 
 	void ClearSelection()
@@ -535,6 +547,8 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	mNumIter = 0;
 	mDebugFlag = 1;
 
+	mFirstShow = true;
+
 	//
 	//  Top frame
 	//
@@ -615,6 +629,21 @@ iggDialogScriptDebugger::~iggDialogScriptDebugger()
 }
 
 
+void iggDialogScriptDebugger::Show(bool s)
+{
+	if(s && mFirstShow)
+	{
+		mFirstShow = false;
+		int wg1[4], wg2[4];
+		this->GetMainWindow()->GetSubject()->GetWindowGeometry(wg1);
+		this->GetSubject()->GetWindowGeometry(wg2);
+		wg2[0] = wg1[0] + 50;
+		wg2[1] = wg1[1] + 100;
+		this->GetSubject()->SetWindowGeometry(wg2);
+	}
+	this->iggMenuWindow::Show(s);
+}
+
 inline iAnimator* iggDialogScriptDebugger::GetAnimator()
 {
 	if(mCurrentAnimator != this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator())
@@ -649,17 +678,18 @@ void iggDialogScriptDebugger::Debug(bool s)
 
 	if(mDebugging)
 	{
-		mAllowFrameStep = false;
+		mInsideALine = mAllowFrameStep = false;
 		this->GetAnimator()->SetDebugFlag(mDebugFlag); // make sure we are current
 		this->SetScript(this->GetAnimator()->GetScript());
 		mRunState = _RunStatePaused;
 		this->GetAnimator()->SetUseScript(true);
 		this->GetAnimator()->Start();
-		mEditor->ShowLine(true,this->GetAnimator()->GetScript());
+		this->UpdateVariables();
+		mEditor->MarkLine(this->GetAnimator()->GetScript());
 	}
 	else
 	{
-		this->GetAnimator()->Finish();
+		this->GetAnimator()->Stop();
 		this->GetAnimator()->SetDebugFlag(0); // to avoid a loop
 		this->SetScript(0);
 	}
@@ -675,7 +705,7 @@ void iggDialogScriptDebugger::OnScriptStartBody()
 
 void iggDialogScriptDebugger::OnScriptStopBody(const iString &error)
 {
-	if(!error.IsEmpty())
+	if(!error.IsEmpty() && error!="Animation finished.")
 	{
 		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Run time error:\n")+error,_PopupWindowWarning);
 	}
@@ -686,13 +716,12 @@ void iggDialogScriptDebugger::OnScriptStopBody(const iString &error)
 void iggDialogScriptDebugger::OnScriptBeginLineBody(int , const iString &)
 {
 	mInsideALine = true;
-	mEditor->ShowLine(false,this->GetAnimator()->GetScript());
 }
 
 
 void iggDialogScriptDebugger::OnScriptEndLineBody(int , const iString &)
 {
-	mEditor->ShowLine(true,this->GetAnimator()->GetScript());
+	mEditor->MarkLine(this->GetAnimator()->GetScript());
 	mInsideALine = false;
 }
 
@@ -732,7 +761,7 @@ void iggDialogScriptDebugger::SetRunState(int n)
 			{
 				while(mDebugging && mRunState==_RunStateExecute && this->GetAnimator()->Continue())
 				{
-					if(mEditor->IsBreakPoint(this->GetAnimator()->GetScript()->GetCurrentLine()))
+					if(mEditor->IsBreakPoint(this->GetAnimator()->GetScript()->GetThisLine()))
 					{
 						mRunState = _RunStatePaused;
 						this->UpdateButtons();
@@ -747,6 +776,7 @@ void iggDialogScriptDebugger::SetRunState(int n)
 						}
 						while(mTimer->GetElapsedTime() < mDelayTime);
 					}
+					this->GetMainWindow()->ProcessEvents();
 				}
 				if(mRunState==_RunStateExecute || this->GetAnimator()->GetErrorStatus()->IsError()) this->Debug(false);
 				break;
@@ -778,10 +808,9 @@ void iggDialogScriptDebugger::SetDebugFlag(int f)
 bool iggDialogScriptDebugger::CheckSyntax(bool silent)
 {
 	iAnimatorScript *s = this->GetAnimator()->GetScript();
-	s->Run(true);
-	if(s->GetErrorStatus()->IsError())
+	if(!s->Compile())
 	{
-		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetCurrentLine()+1)+"\n"+s->GetErrorStatus()->Message(),_PopupWindowError);
+		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetThisLine()+1)+"\n"+s->GetErrorStatus()->Message(),_PopupWindowError);
 		mEditor->ShowError(s);
 		return false;
 	}
@@ -797,29 +826,29 @@ void iggDialogScriptDebugger::UpdateVariables()
 {
 	iAnimatorScript *s = this->GetAnimator()->GetScript();
 
-	iValue *v;
-	int i, n = s->GetNumberOfVariables();
+	int i;
 	iString s1, w;
 	int maxNameLen = 0, maxTypeLen = 0, maxDataLen = 0;
 
-	for(i=0; i<n; i++)
+	iArray<const iScriptKit::Value*> list;
+	s->QueryVariables(list);
+
+	for(i=0; i<list.Size(); i++)
 	{
-		v = s->GetVariable(i);
-		if(maxNameLen < v->GetName().Length()) maxNameLen = v->GetName().Length();
-		if(maxTypeLen < v->GetTypeAsText().Length()) maxTypeLen = v->GetTypeAsText().Length();
-		if(maxDataLen < v->GetValueAsText().Length()) maxDataLen = v->GetValueAsText().Length();
+		if(maxNameLen < list[i]->Name().Length()) maxNameLen = list[i]->Name().Length();
+		if(maxTypeLen < list[i]->GetTypeAsText().Length()) maxTypeLen = list[i]->GetTypeAsText().Length();
+		if(maxDataLen < list[i]->GetValueAsText().Length()) maxDataLen = list[i]->GetValueAsText().Length();
 	}
 	while(w.Length() < maxNameLen) w += "..........";
 	while(w.Length() < maxTypeLen) w += "..........";
 	while(w.Length() < maxDataLen) w += "..........";
 
 	mVarView->Clear();
-	for(i=0; i<n; i++)
+	for(i=0; i<list.Size(); i++)
 	{
-		v = s->GetVariable(i);
-		s1 = "<b>" + v->GetName() + "</b>" + w.Part(0,maxNameLen-v->GetName().Length()) + ":  ";
-		s1 += "<font color=blue>" + v->GetTypeAsText() + "</font>" + w.Part(0,maxTypeLen-v->GetTypeAsText().Length()) + "  ";
-		s1 += v->GetValueAsText();
+		s1 = "<b>" + list[i]->Name() + "</b>" + w.Part(0,maxNameLen-list[i]->Name().Length()) + "..:  ";
+		s1 += "<font color=blue>" + list[i]->GetTypeAsText() + "</font>" + w.Part(0,maxTypeLen-list[i]->GetTypeAsText().Length()) + "  ";
+		s1 += list[i]->GetValueAsText();
 		mVarView->InsertItem(s1);
 	}
 	if(mNumIter > 0)
@@ -960,14 +989,20 @@ void iggDialogScriptDebugger::SaveToFile(const iString &filename)
 		return;
 	}
 
+	iString line;
 	int i, n = mEditor->GetNumberOfLines();
 	for(i=0; i<n; i++)
 	{
-		if(!f.WriteLine(mEditor->GetLine(i)))
+		line = mEditor->GetLine(i);
+		if(!line.IsEmpty() && line.IsWhiteSpace(line.Length()-1)) line = line.Part(0,line.Length()-1); // weird Qt bug
+		if(i<n-1 || !line.IsEmpty()) //  Qt bug
 		{
-			mMainWindow->PopupWindow(mGlobalFrame,"Error in writing a script file.",_PopupWindowError);
-			f.Close();
-			return;
+			if(!f.WriteLine(line))
+			{
+				mMainWindow->PopupWindow(mGlobalFrame,"Error in writing a script file.",_PopupWindowError);
+				f.Close();
+				return;
+			}
 		}
 	}
 	f.Close();
@@ -1182,3 +1217,4 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 	IERROR_LOW("Invalid menu item id.");
 }
 
+#endif
