@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframe.h"
 
 
@@ -606,3 +610,4 @@ void iggFrameScroll::FlipThroughAllChildren()
 	mContents->FlipThroughAllChildren();
 }
 
+#endif
