@@ -165,7 +165,7 @@ class iggFrameBook : public iggFrameBase
 
 public:
 
-	iggFrameBook(iggFrameBase *parent, bool withFeedback = false);
+	iggFrameBook(iggFrameBase *parent, bool withFeedback = false, bool tabsOnTop = true);
 	
 	void OpenPage(int i);
 	void AddPage(const iString &title, const iImage *image, iggFrame *frame, int index = -1);
@@ -209,6 +209,7 @@ public:
 
 	int Count() const;
 
+	inline int GetCurrentLayer() const { return mCurrentLayer; }
 	void ShowLayer(int i);
 	void AddLayer(iggFrame *layer);
 
@@ -218,6 +219,7 @@ public:
 
 protected:
 
+	int mCurrentLayer;
 	iArray<iggFrame*> mLayers;
 	ibgFrameFlipSubject *mSubject;
 };
@@ -231,7 +233,7 @@ class iggFrameScroll : public iggFrameBase
 
 public:
 
-	iggFrameScroll(iggFrameBase *parent, bool withHor = true);
+	iggFrameScroll(iggFrameBase *parent, bool withHor = true, int numcol = 1, bool withVer = true);
 
 	inline iggFrame* GetContents() const { return mContents; }
 
