@@ -52,6 +52,9 @@ public:
 	iggFrameDataTypeSelector(iggDataTypeProvider *provider, bool withapply, const iString &title, iggFrameBase *parent, int mode = iggParameter::_ListDataTypesAll);
 	virtual ~iggFrameDataTypeSelector();
 
+	inline int GetMode() const { return mMode; }
+	void SetMode(int m);
+
 	const iDataInfo* GetDataInfo();
 
 	bool IsModified() const;
