@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframedatavariablelist.h"
 
 
@@ -220,3 +224,4 @@ void iggFrameDataVariableList::InsertItem(const iString &text)
 	}
 }
 
+#endif
