@@ -216,19 +216,23 @@ void iggFrameCreateDeleteButton::SetActive(bool s)
 
 void iggFrameCreateDeleteButton::OnButton1()
 {
+	this->GetMainWindow()->Block(true);
 	if(this->GetShell()->GetControlModule()->CreateObject(mType,true))
 	{
 		if(mDependent != 0) mDependent->UpdateWidget();
 	}
+	this->GetMainWindow()->Block(false);
 }
 
 
 void iggFrameCreateDeleteButton::OnButton2()
 {
+	this->GetMainWindow()->Block(true);
 	if(this->GetShell()->GetControlModule()->DeleteObject(mType,true))
 	{
 		if(mDependent != 0) mDependent->UpdateWidget();
 	}
+	this->GetMainWindow()->Block(false);
 }
 
 
