@@ -45,7 +45,7 @@ class iggFrameHistogramAreaExtra : public iggFrame
 
 public:
 
-	iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent);
+	iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent, bool withFull = true);
 
 protected:
 
