@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframeobjectcontrols.h"
 
 
@@ -91,3 +95,4 @@ void iggFrameObjectControls::EnableSize(bool s)
 	mOS->Enable(s);
 }
 
+#endif
