@@ -51,7 +51,7 @@ public:
 
 	void SetIndex(int i);
 
-	virtual iPalette* GetCurrentPalette() const;
+	virtual int GetCurrentPaletteIndex() const;
 
 protected:
 
