@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggframepiecewisefunctioncontrols.h"
 
 
@@ -359,3 +363,4 @@ iggFramePiecewiseFunctionControls::iggFramePiecewiseFunctionControls(bool withre
 	this->SetColStretch(2,10);
 }
 
+#endif
