@@ -296,34 +296,34 @@ namespace iggMainWindow_Private
 			static Entry data0[] = 
 			{ 
 				Entry("U key","dump the current view into an image."),
-					Entry("F key","toggle the Full Screen mode on and off."),
-					Entry("","(use Style->Show interactor help menu to turn this help off)")
+				Entry("F key","toggle the Full Screen mode on and off."),
+				Entry("","(use Style->Show interactor help menu to turn this help off)")
 			};
 
 			static Entry dataD[] = 
 			{ 
 				Entry(   "Trackball/Joystick mode",""),
-					Entry("","-------------------------"),
-					Entry("Left button","rotate the camera around its focal point."),
-					Entry("[Ctrl]+Left button","spin the camera around the Z-axis (axis perpendicular to the screen)."),
-					Entry("Middle button","pan (move sideways) the camera."),
-					Entry("Right button","zoom in/out."),
-					Entry("3 key","toggle into and out of stereo mode."),
-					Entry("P key","perform a pick operation."),
-					Entry("R key","reset the camera view along the current view direction."),
-					Entry("S key","show all solid objects as surfaces."),
-					Entry("W key","show all solid objects as wireframe (faster).")
+				Entry("","-------------------------"),
+				Entry("Left button","rotate the camera around its focal point."),
+				Entry("[Ctrl]+Left button","spin the camera around the Z-axis (axis perpendicular to the screen)."),
+				Entry("Middle button","pan (move sideways) the camera."),
+				Entry("Right button","zoom in/out."),
+				Entry("3 key","toggle into and out of stereo mode."),
+				Entry("P key","perform a pick operation."),
+				Entry("R key","reset the camera view along the current view direction."),
+				Entry("S key","show all solid objects as surfaces."),
+				Entry("W key","show all solid objects as wireframe (faster).")
 			};
 
 			static Entry dataF[] = 
 			{ 
 				Entry(   "Fly-by mode",""),
-					Entry("","-------------"),
-					Entry("Left button","forward motion."),
-					Entry("Right button","reverse motion."),
-					Entry("[Shift] key","accelerator in mouse and key modes."),
-					Entry("[Ctrl]+[Shift] keys","causes sidestep instead of steering."),
-					Entry("+/- keys","increase/deacrease normal speed.")
+				Entry("","-------------"),
+				Entry("Left button","forward motion."),
+				Entry("Right button","reverse motion."),
+				Entry("[Shift] key","accelerator in mouse and key modes."),
+				Entry("[Ctrl]+[Shift] keys","causes sidestep instead of steering."),
+				Entry("+/- keys","increase/deacrease normal speed.")
 			};
 
 			static Entry dataK[] = 
@@ -566,7 +566,10 @@ namespace iggMainWindow_Private
 
 		virtual void OnInt1Body(int i)
 		{
-			if(this->GetMainWindow()->GetExtensionWindow() != 0) this->GetMainWindow()->GetExtensionWindow()->OpenBookPageByIndex(i);
+			if(!iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iggParameter::_ConditionSlowRemoteConnection) && this->GetMainWindow()->GetExtensionWindow()!=0)
+			{
+				this->GetMainWindow()->GetExtensionWindow()->OpenBookPageByIndex(i);
+			}
 		}
 	};
 
@@ -902,13 +905,18 @@ void iggMainWindow::StartInitialization()
 	iggFrame *tmpf = new iggFrame(mBaseFrame);
 	mLog = new iggWidgetTextBrowser(false,false,mGlobalFrame);
 	mLog->SetBaloonHelp("Log window","In this window IFrIT logs information about the data files, non-critical execution error, performance information, etc.");
-	if(iRequiredCast<iggShell>(INFO,this->GetShell())->IsDesktopSmall(true))
+
+	//
+	//  Adjust our behaviour depending on the running conditions
+	//
+	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetShell());
+	
+	if(s->IsDesktopSmall(true)) mLog->Show(false);
+	if(s->IsDesktopSmall(false)) mAttachWindows = false;
+	if(s->CheckCondition(iggParameter::_ConditionSlowRemoteConnection))
 	{
-		mLog->Show(false);
-	}
-	if(iRequiredCast<iggShell>(INFO,this->GetShell())->IsDesktopSmall(false))
-	{
-		mAttachWindows = false;
+		ibgRenderWindowSubject::RenderOnFocus = true;
+		mAutoRender = false;
 	}
 
 	//
@@ -984,7 +992,7 @@ void iggMainWindow::StartInitialization()
 	iggFrame *tmp2 = new iggFrame(mGlobalFrame);
 	tmp1->AddSpace(10);
 	mRenderButton = new RenderButton(tmp1);
-	mRenderButton->Show(false);
+	mRenderButton->Show(!mAutoRender);
 	tmp1->SetPadding(true);
 	tmp1->AddLine(new ImageButton(tmp1),mRenderButton);
 	tmp1->AddSpace(10);
@@ -2463,17 +2471,17 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			}
 		case _MenuStyleTabText:
 			{
-				if(on) mBook->SetTabMode(_BookTitleOnly);
+				if(on) this->SetTabMode(_BookTitleOnly);
 				break;
 			}
 		case _MenuStyleTabIcon:
 			{
-				if(on) mBook->SetTabMode(_BookImageOnly);
+				if(on) this->SetTabMode(_BookImageOnly);
 				break;
 			}
 		case _MenuStyleTabBoth:
 			{
-				if(on) mBook->SetTabMode(_BookTitleAndImage);
+				if(on) this->SetTabMode(_BookTitleAndImage);
 				break;
 			}
 		case _MenuStyleRenderImmediate:
