@@ -45,11 +45,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iColor;
 class iDataInfo;
 class iDataType;
+class iFileLoader;
 class iImage;
 
 class iggDialog;
 class iggDialogAbout;
 class iggDialogAnimatingProgress;
+class iggDialogAuto;
 class iggDialogBase;
 class iggDialogDataExplorer;
 class iggDialogEventRecorder;
@@ -68,8 +70,10 @@ class iggFrameBook;
 class iggFrameFlip;
 class iggFrameTopParent;
 class iggPageData;
+class iggPageObject;
 class iggPageParticles;
 class iggPageView;
+class iggRenderWindow;
 class iggWidget;
 class iggWidgetProgressBar;
 class iggWidgetTextBrowser;
@@ -85,9 +89,7 @@ class iggMainWindow : public iObject, public iggMenuWindow
 
 public:
 
-	IOBJECT_DECLARE_SELF(iggMainWindow,iObject);
-
-	virtual ~iggMainWindow();
+	vtkTypeMacro(iggMainWindow,iObject);
 	static const iObjectType& Type();
 
 	//
@@ -96,6 +98,10 @@ public:
 	void Register(ibgWindowSubject *ws);
 	void UnRegister(ibgWindowSubject *ws);
 
+	void RegisterAutoDialog(iggDialogAuto *d);
+	void UnRegisterAutoDialog(iggDialogAuto *d);
+	void PlaceAutoDialogs();
+
 	//
 	//  Access components
 	//
@@ -119,16 +125,20 @@ public:
 	inline iggDialogRenderingProgress* GetDialogRenderingProgress() const { return mDialogRenderingProgress; };
 	inline iggDialogScriptDebugger* GetDialogScriptDebugger() const { return mDialogScriptDebugger; };
 
-	inline iggPageParticles* GetParticlesPage() const { return mParticlesPage; }
+	inline iggPageObject* GetPage(int n) const { if(n>0 && n<7) return mPages[n-1]; else return 0; }
 
 	//
 	//  User notification
 	//
 	int PopupWindow(const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
 	int PopupWindow(const iggFrame *parent, const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
+	int PopupWindow(const iggRenderWindow *parent, const iString &text, int type = iggParameter::_PopupWindowMessage, const char *b0 = "Ok", const char *b1 = 0, const char *b2 = 0);
 
 	void WriteToLog(const iString &prefix, const iString &message, const iColor &c = iColor(0,0,0));
+	void WriteToLog(const iString &message);
 	void ClearLog();
+	void ShowLog(bool s);
+	bool IsLogVisible() const;
 
 	inline bool IsIdiosyncratic() const { return mIdiosyncratic; }
 	bool AskForConfirmation(const iString &message, const char *action);
@@ -154,6 +164,8 @@ public:
 	void AddEraseDataType(const iDataType &type);
 	void RemoveEraseDataType(const iDataType &type);
 
+	void LogDataInfo(const iFileLoader *loader, bool details);
+
 	//
 	//  Multiple window settings
 	//
@@ -165,7 +177,7 @@ public:
 	//
 	void UpdateOnPick();
 	void UpdateMarkerWidgets();
-	void UpdateParticleSetWidgets(const iImage *icon = 0);
+	void UpdateParticleWidgets(const iImage *icon = 0);
 
 	void ShowAll(bool s);
 	void Block(bool s);
@@ -195,10 +207,12 @@ public:
 	void MoveWindows(bool all);
 
 	inline bool IsDocked() const { return mDocked; }
+	inline bool IsAutoRender() const { return mAutoRender; }
 		
-protected:
+private:
 
 	iggMainWindow(iShell *shell);
+	virtual ~iggMainWindow();
 
 	void StartInitialization();
 	void PreShowInitialization();
@@ -258,7 +272,9 @@ protected:
 	iggDialogRenderingProgress *mDialogRenderingProgress;
 	iggDialogScriptDebugger *mDialogScriptDebugger;
 
-#if defined(I_DEBUG) && defined(I_EDITION)
+	iSearchableArray<iggDialogAuto*> mAutoDialogList;
+
+#if defined(I_DEBUG)
 	iggDialog *mDialogDebugHelper;
 #endif
 	//
@@ -266,28 +282,28 @@ protected:
 	//
 	iggFrameTopParent *mBusyIndicatorFrame, *mVisitedFileListFrame;
 	iggFrameFlip *mBaseFrame, *mDataTypeFrame;
-	iggWidget *mBusyIndicator, *mVisitedFileList;
+	iggWidget *mBusyIndicator, *mVisitedFileList, *mRenderButton;
 	iggFrameBook *mBook;
 	iggPageView *mViewPage;
 	iggPageParticles *mParticlesPage;
 	iggPageData *mDataPage;
 	iggWidgetTextBrowser *mLog;
 
+	iggPageObject *mPages[6];
+
 	//
 	//  Helper variables
 	//
 	iArray<iString> mThemeList;
-	int mCurrentTheme;
+	int mCurrentTheme, mBlockLevel;
 	iPointerArray<ibgWindowSubject> mWindowList;
 	iggWidgetProgressBar *mProgressBar;
-	bool mDocked, mInteractorHelp, mToolTips, mOptionsAreGlobal, mWindowUnderFocusCurrent, mDetailLoadedDataInfo;
-	bool mIdiosyncratic, mAttachWindows, mDoNotOfferToReload, mInitialized, mInMove, mTwoSubjectsAreTheSame;
+	bool mDocked, mInteractorHelp, mToolTips, mOptionsAreGlobal, mWindowUnderFocusCurrent, mDetailLoadedDataInfo, mAutoRender;
+	bool mIdiosyncratic, mAttachWindows, mDoNotOfferToReload, mInitialized, mInMove, mTwoSubjectsAreTheSame, mAllowPrePopulateToolBar;
 	iDataInfo *mReloadDataInfo, *mEraseDataInfo;
 	iString mStateFileName;
 	int mInitialGeometry[4], mPrevPos[2], mProgressBarMode;
 
-private:
-
 	iggMainWindow(const iggMainWindow&); // Not implemented.
 	void operator=(const iggMainWindow&);  // Not implemented.
 
@@ -302,6 +318,8 @@ private:
 	static const iObjectKey& KeyAttachWindows();
 	static const iObjectKey& KeyTabMode();
 	static const iObjectKey& KeyTheme();
+	static const iObjectKey& KeySlidersAreEditable();
+	static const iObjectKey& KeyAllowPrePopulateToolBar();
 };
 
 //
@@ -309,7 +327,7 @@ private:
 //
 #define FOR_EVERY_RENDER_WINDOW(window) \
 vtkRenderWindowCollection *c_; iggRenderWindow *window; int k_, n_ = this->GetShell()->GetControlModule()->GetNumberOfViewModules(); \
-for(k_=0;  k_<n_ && (c_=this->GetShell()->GetControlModule()->GetViewModule(k_)->GetRenderWindowCollection(true))!=0; k_++) while((window=iPointerCast<iggRenderWindow,vtkRenderWindow>(c_->GetNextItem())) != 0)
+for(k_=0;  k_<n_ && (c_=this->GetShell()->GetControlModule()->GetViewModule(k_)->GetRenderWindowCollection(true))!=0; k_++) while((window=iRequiredCast<iggRenderWindow>(INFO,c_->GetNextItem())) != 0)
 
 #endif  // IGGMAINWINDOW_H
 
