@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagecrosssection.h"
 
 
@@ -439,3 +443,4 @@ iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(p
 	page3->SetColStretch(1,10);
 }
 
+#endif
