@@ -182,7 +182,7 @@ namespace iggPageData_Private
 						this->GetShell()->GetControlModule()->PackCommand(ws,keyMax,mIndex,fmax);
 					}
 
-					this->GetShell()->GetControlModule()->Execute(ws,!mOut && this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
+					this->GetShell()->GetControlModule()->Execute(ws,this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 					mParent->UpdateWidget();
 				}
 			}
@@ -727,7 +727,7 @@ namespace iggPageData_Private
 				new CalculatorButton(".",".",mCalculatorLineEdit,f4),
 				new CalculatorButton("E","e",mCalculatorLineEdit,f4));
 			f4->AddLine(
-				new CalculatorButton("(",")",mCalculatorLineEdit,f4),
+				new CalculatorButton("(","(",mCalculatorLineEdit,f4),
 				new CalculatorButton(")",")",mCalculatorLineEdit,f4),
 				new CalculatorButton("<-","",mCalculatorLineEdit,f4));
 			mFrame->AddLine(f3,f4);
@@ -961,6 +961,7 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 				fbpage2->AddLine(vl);
 
 				iggWidgetTextArea *tmp = new iggWidgetTextArea("  Dimension to fit",fbpage2);
+				tmp->AlignLeft(true);
 				fbpage2->AddLine(tmp);
 				iggWidgetKeyRadioBox *fb = new iggWidgetKeyRadioBox(1,"into bounding box",2,iDataReader::KeyScaledDimension(),fbpage2);
 				fb->InsertItem("Longest");
