@@ -39,6 +39,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishell.h"
 #include "isurfaceviewsubject.h"
 #include "iviewmodule.h"
+#include "iviewobject.h"
+#include "iviewobjectfamily.h"
 
 #include "iggdatatypeprovider.h"
 #include "iggframecurrentinstance.h"
@@ -48,6 +50,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframeobjectcontrols.h"
 #include "iggframepaletteselection.h"
 #include "iggframereplicate.h"
+#include "iggmainwindow.h"
 #include "iggwidgetkeybutton.h"
 #include "iggwidgetkeycolorselection.h"
 #include "iggwidgetkeyselectionbox.h"
@@ -232,7 +235,7 @@ namespace iggPageSurface_Private
 		
 	public:
 
-		BatchCreateFrame(iggFrame *parent) : iggFrame("Create multiple isosurfaces",parent,2)
+		BatchCreateFrame(iggFrame *parent) : iggFrame("Interpolate between instances",parent,2)
 		{
 			//
 			//  Subjects are inserted into a parent frame layout, so we need to create a child frame
@@ -268,16 +271,13 @@ namespace iggPageSurface_Private
 		virtual void UpdateWidgetBody()
 		{
 			int n;
-			bool dataPresent;
 
-			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataPresent(),dataPresent) || !this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeySurfaceMax(),n))
+			if(!this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeySurfaceMax(),n))
 			{
 				this->Enable(false);
 				return this->UpdateFailed();
 			}
 
-			this->Enable(dataPresent);
-
 			n++;
 			if(mSpinBox1->Count() != n) mSpinBox1->SetRange(1,n);
 			if(mSpinBox2->Count() != n) mSpinBox2->SetRange(1,n);
@@ -297,23 +297,24 @@ namespace iggPageSurface_Private
 				}
 			}
 
-			mWidgetHelper->Enable(this->AreTwoInstancesConsistent());
+			this->Enable(this->AreTwoInstancesConsistent());
 		}
 		
 		bool AreTwoInstancesConsistent() const
 		{
 			int m1, m2, v1, v2, dc1, dc2;
 
-			if(mSpinBox1->GetValue()==mSpinBox2->GetValue() ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc2,-1,mSpinBox2->GetValue()-1))
-			{
-				return false; 
-			}
+			//
+			//  Split one if for debugging
+			//
+			if(mSpinBox1->GetValue() == mSpinBox2->GetValue()) return false;
+			dc1 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
+			dc2 = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox2->GetValue()-1)->GetActiveDataTypeIndex();
+				
+			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m1,-1,mSpinBox1->GetValue()-1)) return false;
+			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m2,-1,mSpinBox2->GetValue()-1)) return false;
+			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v1,-1,mSpinBox1->GetValue()-1)) return false;
+			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v2,-1,mSpinBox2->GetValue()-1)) return false;
 
 			return (m1==m2) && (m1!=_SurfaceMethodIsoSurface || v1==v2) && (dc1==dc2);
 		}
@@ -340,10 +341,11 @@ namespace iggPageSurface_Private
 				return;
 			}
 
+			dc = this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetMember(mSpinBox1->GetValue()-1)->GetActiveDataTypeIndex();
+
 			if(
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m,-1,mSpinBox1->GetValue()-1) ||
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc,-1,mSpinBox1->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceLevel(),lmin,-1,mSpinBox1->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceLevel(),lmax,-1,mSpinBox2->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPosition(true),pmin,3,-1,mSpinBox1->GetValue()-1) || 
@@ -352,10 +354,10 @@ namespace iggPageSurface_Private
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeySize(true),smax,-1,mSpinBox2->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPlaneDirection(),dmin,3,-1,mSpinBox1->GetValue()-1) || 
 				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPlaneDirection(),dmax,3,-1,mSpinBox2->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),0,omin,2,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),0,omax,2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmin,2,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmax,2,-1,mSpinBox2->GetValue()-1)) 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),omin,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),omax,-1,mSpinBox2->GetValue()-1) ||
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),cmin,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),cmax,-1,mSpinBox2->GetValue()-1)) 
 			{
 				IERROR_LOW("Unable to query Surface object.");
 				mWidgetHelper->Enable(false);
@@ -397,14 +399,15 @@ namespace iggPageSurface_Private
 
 				if(this->GetShell()->GetControlModule()->CreateObject(iSurfaceViewSubject::Type(),false))
 				{
+					this->GetShell()->GetControlModule()->GetViewModule()->GetViewObjectFamily(_ObjectTypeSurface)->GetCurrentMember()->SetActiveDataTypeIndex(dc);
 					//
 					//  Set the parameters of the new instance
 					//
 					iString ws;
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyDataType(),dc);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyMethod(),m);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyOpacity(),0,o);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyColor(),0,c);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyOpacity(),o);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyColor(),c);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyIsoSurfaceVar(),v);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyIsoSurfaceLevel(),l);
 					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyPosition(true),p,3);
@@ -420,6 +423,31 @@ namespace iggPageSurface_Private
 		ibgWidgetSpinBoxSubject *mSpinBox1, *mSpinBox2, *mSpinBox3;
 		ibgWidgetButtonSubject *mButton;
 	};
+
+
+	class PrintInfoButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		PrintInfoButton(iggFrame *parent) : iggWidgetSimpleButton("Print info",parent)
+		{
+			this->SetBaloonHelp("Print some information about the current surface");
+		}
+
+	protected:
+
+		virtual void Execute()
+		{
+			this->GetMainWindow()->Block(true);
+
+			iString ws;
+			this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyOutputProperties(),true);
+			this->GetShell()->GetControlModule()->Execute(ws,false,this->GetExecuteFlags());
+
+			this->GetMainWindow()->Block(false);
+		}
+	};
 };
 
 
@@ -458,7 +486,11 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iPar
 	mf2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),mf2,false,0));
 	mf2->AddLine(new iggWidgetKeyCheckBox("Flip normals",iSurfaceViewSubject::KeyNormalsFlipped(),mf2));
 	mf->AddLine(mb,mf2);
-	page0top->AddLine(mf,2);
+	mf2 = new iggFrame(page0top);
+	mf2->AddSpace(1);
+	mf2->AddLine(new PrintInfoButton(mf2));
+	mf2->AddSpace(1);
+	page0top->AddLine(mf,2,mf2,1);
 	page0top->AddSpace(2);
 	//
 	//  Opacity
