@@ -499,6 +499,60 @@ namespace iggPageView_Private
 	};
 
 
+	class CopyFromWindowComboBox : public iggWidget
+	{
+
+	public:
+
+		CopyFromWindowComboBox(iggFrame *parent) : iggWidget(parent)
+		{
+			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"Copy settings from...");
+			this->SetBaloonHelp("Copy all internal settings from another window");
+        }
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			mSubject->Clear();
+
+			int i, n = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
+			mSubject->InsertItem("...");
+			if(n > 1)
+			{
+				this->Enable(true);
+				for(i=0; i<n; i++) if(i != this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex())
+				{
+					mSubject->InsertItem("Window "+iString::FromNumber(i+1));
+				}
+			}
+			else this->Enable(false);
+			mSubject->SetValue(0);
+		}
+
+		void OnInt1Body(int v)
+		{
+			if(v > 0)
+			{
+				if(v > this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex()) v++;
+
+				iViewModule *vm1 = this->GetShell()->GetControlModule()->GetViewModule();
+				iViewModule *vm2 = this->GetShell()->GetControlModule()->GetViewModule(v-1);
+				if(vm1!=0 && vm2!=0 && vm1!=vm2)
+				{
+					this->GetMainWindow()->Block(true);
+					vm1->CopySettings(vm2);
+					vm1->Render();
+					this->GetMainWindow()->Block(false);
+				}
+			}
+			mSubject->SetValue(0);
+		}
+
+		ibgWidgetComboBoxSubject *mSubject;
+	};
+
+
 	class DialogWait : public iggDialog
 	{
 
@@ -1486,7 +1540,11 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			sbpage3->AddLine(new ColorBarFrame(acb,"Left bar",iColorBars::KeyBarLeft(),sbpage3),new ColorBarFrame(acb,"Right bar",iColorBars::KeyBarRight(),sbpage3));
 
 			sbpage3->AddSpace(10);
-			sbpage3->AddLine(new iggWidgetKeyFloatSlider(0.01,0.2,19,0,0,"Side offset",iColorBars::KeySideOffset(),_RenderModeUseGlobal,sbpage3),2);
+			iggFrame *tmp = new iggFrame(sbpage3,2);
+			tmp->AddLine(new iggWidgetTextArea("Side offset",tmp),new iggWidgetKeyFloatSlider(0.01,0.3,29,0,0,"",iColorBars::KeySideOffset(),_RenderModeUseGlobal,tmp));
+			tmp->AddLine(new iggWidgetTextArea("Bar size",tmp),new iggWidgetKeyFloatSlider(0.2,1.0,8,0,0,"",iColorBars::KeySize(),_RenderModeUseGlobal,tmp));
+			tmp->SetColStretch(1,10);
+			sbpage3->AddLine(tmp,3);
 
 			sbpage3->SetColStretch(2,10);
 		}
@@ -1891,6 +1949,9 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 
 		page4->AddLine(wfb,wsi);
 
+		page4->AddLine(new CopyFromWindowComboBox(page4));
+		page4->AddSpace(2);
+
 		page4->AddLine(new WidgetsControlAllWindowsCheckBox(page4));
 		page4->AddLine(new WindowUnderFocusCurrentCheckBox(page4));
 		page4->AddLine(new iggWidgetKeyCheckBox("Synchronize window interactors",iControlModule::KeySynchronizeInteractors(),page4));
