@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggpagevolume.h"
 
 
@@ -287,3 +291,4 @@ iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,iParam
 	page4->SetColStretch(2,3);
 }
 
+#endif
