@@ -84,8 +84,6 @@ iggRenderWindow::iggRenderWindow(iViewModule *vm) : mViewModule(vm)
 	mMainWindow = 0;
 	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetViewModule()->GetControlModule()->GetShell());
 	if(s->GetMainWindow() !=0 ) this->AttachToMainWindow(s->GetMainWindow());
-
-	glPolygonOffset(1.0,1.0);
 }
 
 
@@ -159,7 +157,7 @@ void iggRenderWindow::Render()
 		//  This way the magnified image creation do not show in actual window
 		//
 		if(!mSubject->IsReadyForDumpingImage()) return;
-		vtkOpenGLRenderWindow::Render();
+		this->vtkOpenGLRenderWindow::Render();
 		if(mCurStep == 0) 
 		{
 			this->GetViewModule()->GetProgressEventObserver()->Started(iProgressEventObserver::_Rendering);
@@ -179,7 +177,7 @@ void iggRenderWindow::Render()
 	}
 	else
 	{
-		mSubject->Render();
+		this->vtkOpenGLRenderWindow::Render();
 	}
 }
 
@@ -391,7 +389,15 @@ void* iggRenderWindow::GetGenericWindowId()
 
 void iggRenderWindow::SetWindowName(const char *s)
 {
-	mSubject->SetWindowName(s);
+	if(iRequiredCast<iggShell>(INFO,mSubject->GetShell())->CheckCondition(iggParameter::_ConditionSlowRemoteConnection))
+	{
+		iString ws(s);
+		mSubject->SetWindowName(ws+" (click to render)");
+	}
+	else
+	{
+		mSubject->SetWindowName(s);
+	}
 }
 
 
