@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
   
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggrenderwindowinteractor.h"
 
 
@@ -225,3 +229,4 @@ void iggRenderWindowInteractor::UserCallback()
 	iRequiredCast<iggRenderWindow>(INFO,RenderWindow)->GetViewModule()->DumpImages();
 }
 
+#endif
