@@ -191,7 +191,9 @@ iggShell::iggShell(const iString &type, int argc, char **argv) : iShell(type,arg
 	//  Default settings
 	//
 	mShowFlashWindow = true;
-	mAccept8BitDisplay = mStartDocked = mUseOldWindowManager = mSmallDesktop = false;
+	mAccept8BitDisplay = mStartDocked = false;
+
+	mConditionFlags = 0;
 
 	mMainWindow = 0; // very important!!! This tells other components that the main
 					 // window does not exist yet.
@@ -205,16 +207,6 @@ void iggShell::Exit()
 }
 
 
-bool iggShell::IsDesktopSmall(bool vert) const
-{
-	if(mSmallDesktop) return true;
-
-	int w, h;
-	mSubject->GetDesktopDimensions(w,h);
-	if(vert) return (h < 900); else return (w < 1200);
-}
-
-
 void iggShell::GetDesktopDimensions(int &w, int &h) const
 {
 	mSubject->GetDesktopDimensions(w,h);
@@ -230,8 +222,10 @@ void iggShell::DefineSpecificCommandLineOptions()
 	if(mSubject->CanDockWindows()) this->AddCommandLineOption("d",false,"start IFrIT with windows docked");
 	if(mSubject->CanChangeFontSize()) this->AddCommandLineOption("fs",true,"increase/decrease window font size");
 	this->AddCommandLineOption("nf",false,"do not show the splash screen at start-up");
+
 	this->AddCommandLineOption("owm",false,"use old-style window manager");
-	this->AddCommandLineOption("sd",false,"assume the desktop size is small");
+	this->AddCommandLineOption("sds",false,"assume the desktop size is small");
+	this->AddCommandLineOption("src",false,"minimize updates for running on a slow remote connection");
 }
 
 
@@ -502,7 +496,6 @@ void iggShell::RunBody()
 
 bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 {
-
 	if(o.Name == "fs")
 	{
 		int s;
@@ -519,9 +512,9 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 		}
 	} 
 
-	if(o.Name == "sd")
+	if(o.Name == "d")
 	{
-		mSmallDesktop = true;
+		mStartDocked = true;
 		return true;
 	} 
 
@@ -537,25 +530,47 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 		return true;
 	}
 
+	//
+	//  behaviour settings
+	//
 	if(o.Name == "owm")
 	{
-		mUseOldWindowManager = true;
+		mConditionFlags |= _ConditionOldWindowManager;
 		return true;
 	}
 
-	if(o.Name == "d")
+	if(o.Name == "sds")
 	{
-		mStartDocked = true;
+		mConditionFlags |= _ConditionSmallDesktopSize;
 		return true;
 	} 
+
+	if(o.Name == "src")
+	{
+		mConditionFlags |= _ConditionSlowRemoteConnection;
+		return true;
+	}
 	
 	return false;
 }
 
 
-bool iggShell::IsWindowManagerModern() const
+//
+//  Running conditions
+//
+bool iggShell::IsDesktopSmall(bool vert) const
 {
-	if(mUseOldWindowManager) return false; else return mSubject->IsWindowManagerModern();
+	if(this->CheckCondition(_ConditionSmallDesktopSize)) return true;
+
+	int w, h;
+	mSubject->GetDesktopDimensions(w,h);
+	if(vert) return (h < 900); else return (w < 1200);
+}
+
+
+bool iggShell::CheckCondition(int flag) const
+{
+	if((mConditionFlags & flag) != 0) return true; else return mSubject->CheckCondition(flag);
 }
 
 
