@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggwidget.h"
 
 
@@ -358,3 +362,4 @@ int iggWidget::GetExecuteFlags() const
 	return flags;
 }
 
+#endif
