@@ -48,7 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGGWIDGET_H
 
 
-#include "ishellcomponent.h"
+#include "iggelement.h"
 
 
 #include "iarray.h"
@@ -64,7 +64,7 @@ class ibgWidgetHelper;
 class ibgWidgetSubject;
 
 
-class iggWidget : public iShellComponent
+class iggWidget : public iggElement
 {
 
 	friend class iggFrame;
@@ -99,6 +99,11 @@ public:
 	void Emphasize(bool s, bool random = false);
 
 	void UpdateWidget();
+	
+	int GetExecuteFlags() const;
+	void SetExecuteFlags(int f);
+	static void SetGlobalExecuteFlags(int f);
+//	static inline int GetGlobalExecuteFlags(){ return mGlobalExecuteFlags; }
 
 #ifdef I_DEBUG
 	static void EmphasizeLayouts(bool s);
@@ -141,8 +146,8 @@ protected:
 
 private:
 
-	int mId;
-	static int mIdCounter;
+	static int mGlobalExecuteFlags;
+	int mExecuteFlags; // ExecureFlags should be accessed via GetExecuteFlags always
 
 	void Define();
 
