@@ -62,12 +62,6 @@ public:
 	static void SetGlobalRenderMode(int m);
 	static inline int GetGlobalRenderMode(){ return mGlobalRenderMode; }
 
-	void SetExecuteFlags(int f);
-	int GetExecuteFlags() const;
-
-	static void SetGlobalExecuteFlags(int f);
-	static inline int GetGlobalExecuteFlags(){ return mGlobalExecuteFlags; }
-
 	void SetSelfChecking(bool s);
     void SetIndex(int i);
 
@@ -89,8 +83,6 @@ protected:
 	const iObjectKey& Translate(const iObjectKey &key) const;
 	void UpdateHelp();
 
-	static int mGlobalRenderMode, mGlobalExecuteFlags;
-
 	bool mSelfChecking;
 	const int mType;
 	int mIndex;
@@ -115,7 +107,8 @@ protected:
 private:
 
 	const iObjectKey &mKey;  // Main key must be accessed via GetKey() 
-	int mRenderMode, mExecuteFlags; // RenderMode should be accessed via GetRenderMode always
+	int mRenderMode; // RenderMode should be accessed via GetRenderMode always
+	static int mGlobalRenderMode;
 };
 
 
@@ -130,6 +123,8 @@ public:
 	virtual bool ExecuteControl(bool final);
 	virtual bool ExecuteControl(bool final, T val);
 
+	void SetActionKey(bool s){ mActionKey = s; }
+
 protected:
 
 	iggWidgetKeyHandler(int type, const iObjectKey &key, int rm, iggFrame *parent, int index, const iObjectKey *indkey);
@@ -139,6 +134,7 @@ protected:
 	virtual void UpdateValue(T v) = 0;
 
 	T mValue;
+	bool mActionKey;
 };
 
 //
@@ -152,15 +148,12 @@ public:
 
 	iggWidgetKeyDummy(const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey);
 
-	void PushValue(T v);
-	inline T PullValue() const { return mDummyValue; }
+	void SetValue(T v);
 
 protected:
 
 	virtual void QueryValue(T &v) const;
 	virtual void UpdateValue(T v);
-
-	T mDummyValue;
 };
 
 #endif  // IGGWIDGETKEYHANDLER_H
