@@ -45,6 +45,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 template<class T>
 iggWidgetKeyHandler<T>::iggWidgetKeyHandler(int type, const iObjectKey &key, int rm, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandlerBase(type,key,rm,parent,index,indkey)
 {
+	this->mActionKey = false;
 }
 
 
@@ -99,7 +100,7 @@ bool iggWidgetKeyHandler<T>::ExecuteControl(bool final, T val)
 	}
 
 	bool ren = (this->GetRenderMode()==_RenderModeImmediate || (final && this->GetRenderMode()!=_RenderModeNoRender));
-	bool ret = this->GetShell()->GetControlModule()->Execute(ws,ren,this->GetExecuteFlags());
+	bool ret = this->GetShell()->GetControlModule()->Execute(ws,ren && this->GetMainWindow()->IsAutoRender(),this->GetExecuteFlags());
 
 	if(this->mSelfChecking && (final || this->GetRenderMode()==_RenderModeImmediate))
 	{
@@ -128,8 +129,10 @@ void iggWidgetKeyHandler<T>::UpdateWidgetBody()
 		//
 	    if(this->GetShell()->GetControlModule()->QueryValue(key,this->mValue))
 		{
+			if(!this->mActionKey) this->Enable(true);
 			this->UpdateValue(this->mValue);
 		}
+		else if(!this->mActionKey) this->Enable(false);
 	}
 	else
 	{
@@ -144,6 +147,7 @@ void iggWidgetKeyHandler<T>::UpdateWidgetBody()
 		    if(!this->GetShell()->GetControlModule()->QueryValue(*this->mIndexKey,this->mIndex))
 			{
 				this->UpdateFailed();
+				if(!this->mActionKey) this->Enable(false);
 				return;
 			}
 		}
@@ -151,8 +155,10 @@ void iggWidgetKeyHandler<T>::UpdateWidgetBody()
 		{
 			if(this->GetShell()->GetControlModule()->QueryValue(key,this->mIndex,this->mValue,(key.Dimension()==0)?this->mIndex+1:key.Dimension(),-1,-1))
 			{
+				if(!this->mActionKey) this->Enable(true);
 				this->UpdateValue(this->mValue);
 			}
+			else if(!this->mActionKey) this->Enable(false);
 		}
 		else
 		{
@@ -160,8 +166,9 @@ void iggWidgetKeyHandler<T>::UpdateWidgetBody()
 			//  Full vector - this is not implemented
 			//
 //			this->GetShell()->GetControlModule()->QueryValue(this->mKey,this->mValue,this->mKey.Dimension());
-			IERROR_REPORT("iggWidgetKeyHandler with the full vector argument is not implemented.");
+			IERROR_LOW("iggWidgetKeyHandler with the full vector argument is not implemented.");
 			this->UpdateFailed();
+			if(!this->mActionKey) this->Enable(false);
 		}
 	}
 }
@@ -174,7 +181,7 @@ iggWidgetKeyDummy<T>::iggWidgetKeyDummy(const iObjectKey &key, iggFrame *parent,
 {
 	this->mWasLaidOut = true; // a dummy does not need a layout
 	this->mSubjectOwner = false; // a dummy does not own its subject
-	this->mDummyValue = T(0);
+	this->mValue = T(0); //  initialize the value
 	//
 	//  Share the helper and the subject
 	//
@@ -184,22 +191,21 @@ iggWidgetKeyDummy<T>::iggWidgetKeyDummy(const iObjectKey &key, iggFrame *parent,
 
 
 template <class T>
-void iggWidgetKeyDummy<T>::PushValue(T v)
+void iggWidgetKeyDummy<T>::SetValue(T v)
 {
-	this->mDummyValue = v;
-	this->ExecuteControl(true);
+	this->ExecuteControl(true,v);
 }
 
 
 template <class T>
-void iggWidgetKeyDummy<T>::QueryValue(T &v) const
+void iggWidgetKeyDummy<T>::QueryValue(T &) const
 {
-	v = this->mDummyValue;	
+	// nothing to do here
 }
 
 template <class T>
-void iggWidgetKeyDummy<T>::UpdateValue(T v)
+void iggWidgetKeyDummy<T>::UpdateValue(T)
 {
-	this->mDummyValue = v;
+	// nothing to do here
 }
 
