@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_GG)
+
+
 #include "iggwidgetprogressbar.h"
 
 
@@ -92,3 +96,4 @@ void iggWidgetProgressBar::OnSetProgress()
 	//
 }
 
+#endif
