@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtexplicitframesubject.h"
 
 
@@ -227,3 +231,4 @@ void iqtExplicitFrameSubject::paintEvent(QPaintEvent *e)
 #endif
 }
 
+#endif
