@@ -64,7 +64,7 @@ iqtExtensionWindowSubject::iqtExtensionWindowSubject(iggExtensionWindow *ew) :
 #endif
 	ibgExtensionWindowSubject(ew)
 {
-	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1ext.png"),"IFrIT - Extension Window"); IERROR_ASSERT(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1ext.png"),"IFrIT - Extension Window",true); IERROR_ASSERT(mWindowHelper);
 }
 
 
