@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtmenuwindowsubject.h"
 
 
@@ -561,3 +565,4 @@ bool iqtMenuWindowSubject::event(QEvent *e)
 	}
 }
 
+#endif
