@@ -71,7 +71,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 #endif
 	ibgRenderWindowSubject(owner)
 {
-	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1vtk.png"),""); IERROR_ASSERT(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1vtk.png"),"",true); IERROR_ASSERT(mWindowHelper);
 
 	this->setFocusPolicy(QFocus::StrongFocus);
 
@@ -147,15 +147,6 @@ void iqtRenderWindowSubject::Initialize(bool show)
 }
 
 
-//
-//  Render the scene
-//
-void iqtRenderWindowSubject::Render()  
-{
-	this->updateGL();
-}
-
-
 //
 // End the rendering process and display the image. 
 //
@@ -279,8 +270,6 @@ void iqtRenderWindowSubject::initializeGL()
 
 void iqtRenderWindowSubject::paintGL() 
 {
-	if(!mOwner->IsInitialized()) return;
-
 	//
 	//  iqtRenderWindowSubject only works with AutoBufferSwap turned off
 	//
@@ -293,7 +282,7 @@ void iqtRenderWindowSubject::paintGL()
 	//
 	//  Must do it this way so that child Render operations are not called from here
 	//
-	mOwner->vtkOpenGLRenderWindow::Render();
+	this->Render();
 }
 
 
@@ -353,7 +342,13 @@ void iqtRenderWindowSubject::OnTimer()
 
 bool iqtRenderWindowSubject::event(QEvent *e)
 {
-	if(e!=0 && e->spontaneous() && this->IsBlocked()) 
+	//
+	//  I do not remember now why we need to bounce back only spontaneous events. Under at least some X11 servers 
+	//  a non-spontaneous paint event arrives during the new file load, when the window is blocked. It causes the
+	//  execution of the pipeline without the complete data, which causes a seg fault inside some VTK classes.
+	//  hence, a check for the paint event here.
+	//
+	if(e!=0 && (e->spontaneous() || e->type()==QEvent::Paint) && this->IsBlocked()) 
 	{
 		return false;
 	}
