@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgetareasubject.h"
 
 
@@ -469,3 +473,4 @@ void iqtWidgetDrawAreaSubject::mouseReleaseEvent(QMouseEvent *e)
 	QFrame::mouseReleaseEvent(e);
 }
 
+#endif
