@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgetbuttonsubject.h"
 
 
@@ -260,3 +264,4 @@ void iqtWidgetButtonSubject::SetText(const iString &text)
 	mButton->setText(iqtHelper::ConvertWithModifiers(mButton,text));
 }
 
+#endif
