@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgetentrysubject.h"
 
 
@@ -121,7 +125,7 @@ namespace iqtWidgetEntrySubject_Private
 
 		virtual void keyPressEvent(QKeyEvent *e)
 		{
-			if(mDelayed && !this->text().isEmpty())
+			if(mDelayed && !this->text().isEmpty() && e->key()!=Qt::Key_Up && e->key()!=Qt::Key_Down)
 			{
 #ifdef IQT_3
 				this->setPaletteForegroundColor((e->key()== Qt::Key_Return)?mPermanentColor:mTemporaryColor);
@@ -333,7 +337,7 @@ void iqtWidgetEntrySubject::SetDoubleValue(int v, double dv, bool withEdit)
 		if(withEdit && !mEdit->isHidden())
 		{
 			mEdit->blockSignals(true);
-			mEdit->setText(QString::number(dv,'g',2));
+			mEdit->setText(QString::number(dv,'g',mNumDigits));
 			mEdit->setCursorPosition(0);
 			mEdit->blockSignals(false);
 		}
@@ -471,3 +475,4 @@ void iqtWidgetEntrySubject::OnKeyUpDown(bool up)
 	iDynamicCast<iqtWidgetHelper,ibgWidgetHelper>(INFO,mWidgetHelper)->OnBool1(up);
 }
 
+#endif
