@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgetprogressbarsubject.h"
 
 
@@ -125,3 +129,4 @@ QString iqtWidgetProgressBarSubject::text() const
 
 #endif
 
+#endif
