@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgetselectionboxsubject.h"
 
 
@@ -510,3 +514,4 @@ int iqtWidgetRadioBoxSubject::Count()
 #endif
 }
 
+#endif
