@@ -26,6 +26,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconfigure.h"
+#if ISHELL_INCLUDED(ISHELL_QT)
+
+
 #include "iqtwidgettexteditorsubject.h"
 
 
@@ -880,3 +884,4 @@ void iqtWidgetTextEditorSubject::contentsMouseReleaseEvent(QMouseEvent *e)
 //	this->OnMouseReleaseBody(para,index);
 }
 
+#endif
