@@ -47,7 +47,7 @@ class iqtWindowHelper : public ibgWindowHelper
 
 public:
 
-	iqtWindowHelper(QWidget *widget, const iImage *icon, const iString &title);
+	iqtWindowHelper(QWidget *widget, const iImage *icon, const iString &title, bool disableClose = false);
 
 	virtual void SetWindowGeometry(int wg[4], bool force);
 	virtual void GetWindowGeometry(int wg[4], bool force) const;
